@@ -2,8 +2,7 @@
 "Export this ownCloud instance" => "Exportovať túto inštanciu ownCloud",
 "This will create a compressed file that contains the data of this owncloud instance." => "Bude vytvorený komprimovaný archív s dátami owncloud inštancie.",
 "Please choose the export type:" => "Vybrať typ exportu:",
-"ownCloud instance (suitable for import)" => "ownCloud inštancia (vhodná pre import)",
 "ownCloud system files" => "ownCloud systémové súbory",
-"Just user files" => "Iba súbory užívateľov",
+"Just user files" => "Iba súbory používateľov",
 "Export" => "Export"
 );
