@@ -9,8 +9,9 @@
 
 
 if(!OCP\User::isLoggedIn()) {
-	die('<script type="text/javascript">document.location = oc_webroot;</script>');
+	OCP\User::checkLoggedIn();
 }
+
 OCP\JSON::checkAppEnabled('calendar');
 
 $id = $_POST['id'];
@@ -20,30 +21,32 @@ if(!$data) {
 	OCP\JSON::error(array('data' => array('message' => OC_Calendar_App::$l10n->t('Wrong calendar'))));
 	exit;
 }
-$permissions = OC_Calendar_App::getPermissions($id, OC_Calendar_App::EVENT);
 $object = OC_VObject::parse($data['calendardata']);
 $vevent = $object->VEVENT;
+$object = OC_Calendar_Object::cleanByAccessClass($id, $object);
+$accessclass = $vevent->getAsString('CLASS');
+$permissions = OC_Calendar_App::getPermissions($id, OC_Calendar_App::EVENT, $accessclass);
 
 $dtstart = $vevent->DTSTART;
 $dtend = OC_Calendar_Object::getDTEndFromVEvent($vevent);
 switch($dtstart->getDateType()) {
-	case Sabre_VObject_Property_DateTime::UTC:
-		$timeOffset = $_SESSION['timezone']*60;
-		$newDT      = $dtstart->getDateTime();
-		$newDT->add(new DateInterval("PT" . $timeOffset . "M"));
+	case Sabre\VObject\Property\DateTime::UTC:
+		$timezone = new DateTimeZone(OC_Calendar_App::getTimezone());
+		$newDT    = $dtstart->getDateTime();
+		$newDT->setTimezone($timezone);
 		$dtstart->setDateTime($newDT);
-		$newDT      = $dtend->getDateTime();
-		$newDT->add(new DateInterval("PT" . $timeOffset . "M"));
+		$newDT    = $dtend->getDateTime();
+		$newDT->setTimezone($timezone);
 		$dtend->setDateTime($newDT);
-	case Sabre_VObject_Property_DateTime::LOCALTZ:
-	case Sabre_VObject_Property_DateTime::LOCAL:
+	case Sabre\VObject\Property\DateTime::LOCALTZ:
+	case Sabre\VObject\Property\DateTime::LOCAL:
 		$startdate = $dtstart->getDateTime()->format('d-m-Y');
 		$starttime = $dtstart->getDateTime()->format('H:i');
 		$enddate = $dtend->getDateTime()->format('d-m-Y');
 		$endtime = $dtend->getDateTime()->format('H:i');
 		$allday = false;
 		break;
-	case Sabre_VObject_Property_DateTime::DATE:
+	case Sabre\VObject\Property\DateTime::DATE:
 		$startdate = $dtstart->getDateTime()->format('d-m-Y');
 		$starttime = '';
 		$dtend->getDateTime()->modify('-1 day');
@@ -53,10 +56,10 @@ switch($dtstart->getDateType()) {
 		break;
 }
 
-$summary = $vevent->getAsString('SUMMARY');
-$location = $vevent->getAsString('LOCATION');
+$summary = strtr($vevent->getAsString('SUMMARY'), array('\,' => ',', '\;' => ';'));
+$location = strtr($vevent->getAsString('LOCATION'), array('\,' => ',', '\;' => ';'));
 $categories = $vevent->getAsString('CATEGORIES');
-$description = $vevent->getAsString('DESCRIPTION');
+$description = strtr($vevent->getAsString('DESCRIPTION'), array('\,' => ',', '\;' => ';'));
 $last_modified = $vevent->__get('LAST-MODIFIED');
 if ($last_modified) {
 	$lastmodified = $last_modified->getDateTime()->format('U');
@@ -198,6 +201,7 @@ if($data['repeating'] == 1) {
 }
 $calendar_options = OC_Calendar_Calendar::allCalendars(OCP\USER::getUser());
 $category_options = OC_Calendar_App::getCategoryOptions();
+$access_class_options = OC_Calendar_App::getAccessClassOptions();
 $repeat_options = OC_Calendar_App::getRepeatOptions();
 $repeat_end_options = OC_Calendar_App::getEndOptions();
 $repeat_month_options = OC_Calendar_App::getMonthOptions();
@@ -209,16 +213,20 @@ $repeat_bymonth_options = OC_Calendar_App::getByMonthOptions();
 $repeat_byweekno_options = OC_Calendar_App::getByWeekNoOptions();
 $repeat_bymonthday_options = OC_Calendar_App::getByMonthDayOptions();
 
-if($permissions & OCP\Share::PERMISSION_UPDATE) {
+if($permissions & OCP\PERMISSION_UPDATE) {
 	$tmpl = new OCP\Template('calendar', 'part.editevent');
-} elseif($permissions & OCP\Share::PERMISSION_READ) {
+} elseif($permissions & OCP\PERMISSION_READ) {
 	$tmpl = new OCP\Template('calendar', 'part.showevent');
+} elseif($permissions === 0) {
+	OCP\JSON::error(array('data' => array('message' => OC_Calendar_App::$l10n->t('You do not have the permissions to edit this event.'))));
+	exit;
 }
 
 $tmpl->assign('eventid', $id);
 $tmpl->assign('permissions', $permissions);
 $tmpl->assign('lastmodified', $lastmodified);
 $tmpl->assign('calendar_options', $calendar_options);
+$tmpl->assign('access_class_options', $access_class_options);
 $tmpl->assign('repeat_options', $repeat_options);
 $tmpl->assign('repeat_month_options', $repeat_month_options);
 $tmpl->assign('repeat_weekly_options', $repeat_weekly_options);
@@ -231,6 +239,7 @@ $tmpl->assign('repeat_bymonthday_options', $repeat_bymonthday_options);
 $tmpl->assign('repeat_weekofmonth_options', $repeat_weekofmonth_options);
 
 $tmpl->assign('title', $summary);
+$tmpl->assign('accessclass', $accessclass);
 $tmpl->assign('location', $location);
 $tmpl->assign('categories', $categories);
 $tmpl->assign('calendar', $data['calendarid']);
