@@ -13,7 +13,7 @@ if (isset($_POST['progresskey']) && isset($_POST['getprogress'])) {
 	echo OCP\JSON::success(array('percent'=>OC_Cache::get($_POST['progresskey'])));
 	exit;
 }
-$file = OC_Filesystem::file_get_contents($_POST['path'] . '/' . $_POST['file']);
+$file = \OC\Files\Filesystem::file_get_contents($_POST['path'] . '/' . $_POST['file']);
 if(!$file) {
 	OCP\JSON::error(array('error'=>'404'));
 }
@@ -48,6 +48,7 @@ if($_POST['method'] == 'new') {
 		exit();
 	}
 	$id = $_POST['id'];
+	$import->setOverwrite($_POST['overwrite']);
 }
 $import->setCalendarID($id);
 try{
@@ -68,4 +69,4 @@ if($count == 0) {
 	}else{
 		OCP\JSON::success(array('message'=>$count . ' ' . OC_Calendar_App::$l10n->t('events has been saved in your calendar')));
 	}
-}
\ No newline at end of file
+}
