@@ -7,6 +7,62 @@
  */
 
 Calendar={
+	Util:{
+		dateTimeToTimestamp:function(dateString, timeString){
+			dateTuple = dateString.split('-');
+			timeTuple = timeString.split(':');
+			
+			var day, month, year, minute, hour;
+			day = parseInt(dateTuple[0], 10);
+			month = parseInt(dateTuple[1], 10);
+			year = parseInt(dateTuple[2], 10);
+			hour = parseInt(timeTuple[0], 10);
+			minute = parseInt(timeTuple[1], 10);
+			
+			var date = new Date(year, month-1, day, hour, minute);
+			
+			return parseInt(date.getTime(), 10);
+		},
+		formatDate:function(year, month, day){
+			if(day < 10){
+				day = '0' + day;
+			}
+			if(month < 10){
+				month = '0' + month;
+			}
+			return day + '-' + month + '-' + year;
+		},
+		formatTime:function(hour, minute){
+			if(hour < 10){
+				hour = '0' + hour;
+			}
+			if(minute < 10){
+				minute = '0' + minute;
+			}
+			return hour + ':' + minute;
+		}, 
+		adjustDate:function(){
+			var fromTime = $('#fromtime').val();
+			var fromDate = $('#from').val();
+			var fromTimestamp = Calendar.Util.dateTimeToTimestamp(fromDate, fromTime);
+
+			var toTime = $('#totime').val();
+			var toDate = $('#to').val();
+			var toTimestamp = Calendar.Util.dateTimeToTimestamp(toDate, toTime);
+
+			if(fromTimestamp >= toTimestamp){
+				fromTimestamp += 30*60*1000;
+				
+				var date = new Date(fromTimestamp);
+				movedTime = Calendar.Util.formatTime(date.getHours(), date.getMinutes());
+				movedDate = Calendar.Util.formatDate(date.getFullYear(),
+						date.getMonth()+1, date.getDate());
+
+				$('#to').val(movedDate);
+				$('#totime').val(movedTime);
+			}
+		}
+	},
 	UI:{
 		scrollcount: 0,
 		loading: function(isLoading){
@@ -22,16 +78,18 @@ Calendar={
 			$('#fullcalendar').fullCalendar('unselect');
 			Calendar.UI.lockTime();
 			$( "#from" ).datepicker({
-				dateFormat : 'dd-mm-yy'
+				dateFormat : 'dd-mm-yy',
+				onSelect: function(){ Calendar.Util.adjustDate(); }
 			});
 			$( "#to" ).datepicker({
 				dateFormat : 'dd-mm-yy'
 			});
 			$('#fromtime').timepicker({
-			    showPeriodLabels: false
+				showPeriodLabels: false,
+				onSelect: function(){ Calendar.Util.adjustDate(); }
 			});
 			$('#totime').timepicker({
-			    showPeriodLabels: false
+				showPeriodLabels: false
 			});
 			$('#category').multiple_autocomplete({source: categories});
 			Calendar.UI.repeat('init');
@@ -84,10 +142,10 @@ Calendar={
 			}
 		},
 		submitDeleteEventForm:function(url){
-			var post = $( '#event_form' ).serialize();
+			var id = $('input[name="id"]').val();
 			$('#errorbox').empty();
 			Calendar.UI.loading(true);
-			$.post(url, post, function(data){
+			$.post(url, {id:id}, function(data){
 					Calendar.UI.loading(false);
 					if(data.status == 'success'){
 						$('#fullcalendar').fullCalendar('removeEvents', $('#event_form input[name=id]').val());
@@ -106,36 +164,32 @@ Calendar={
 				function(data){
 					Calendar.UI.loading(false);
 					if(data.status == "error"){
-						if(data.message) {
-							$('#errorbox').html(data.data.message);
-						} else {
-							var output = missing_field + ": <br />";
-							if(data.title == "true"){
-								output = output + missing_field_title + "<br />";
-							}
-							if(data.cal == "true"){
-								output = output + missing_field_calendar + "<br />";
-							}
-							if(data.from == "true"){
-								output = output + missing_field_fromdate + "<br />";
-							}
-							if(data.fromtime == "true"){
-								output = output + missing_field_fromtime + "<br />";
-							}
-							if(data.to == "true"){
-								output = output + missing_field_todate + "<br />";
-							}
-							if(data.totime == "true"){
-								output = output + missing_field_totime + "<br />";
-							}
-							if(data.endbeforestart == "true"){
-								output = output + missing_field_startsbeforeends + "!<br/>";
-							}
-							if(data.dberror == "true"){
-								output = "There was a database fail!";
-							}
-							$('#errorbox').html(output);
+						var output = missing_field + ": <br />";
+						if(data.title == "true"){
+							output = output + missing_field_title + "<br />";
 						}
+						if(data.cal == "true"){
+							output = output + missing_field_calendar + "<br />";
+						}
+						if(data.from == "true"){
+							output = output + missing_field_fromdate + "<br />";
+						}
+						if(data.fromtime == "true"){
+							output = output + missing_field_fromtime + "<br />";
+						}
+						if(data.to == "true"){
+							output = output + missing_field_todate + "<br />";
+						}
+						if(data.totime == "true"){
+							output = output + missing_field_totime + "<br />";
+						}
+						if(data.endbeforestart == "true"){
+							output = output + missing_field_startsbeforeends + "!<br/>";
+						}
+						if(data.dberror == "true"){
+							output = "There was a database fail!";
+						}
+						$("#errorbox").html(output);
 					} else
 					if(data.status == 'success'){
 						$('#event').dialog('destroy').remove();
@@ -186,9 +240,9 @@ Calendar={
 		},
 		getEventPopupText:function(event){
 			if (event.allDay){
-				var timespan = $.fullCalendar.formatDates(event.start, event.end, 'ddd d MMMM[ yyyy]{ -[ddd d] MMMM yyyy}', {monthNamesShort: monthNamesShort, monthNames: monthNames, dayNames: dayNames, dayNamesShort: dayNamesShort}); //t('calendar', "ddd d MMMM[ yyyy]{ -[ddd d] MMMM yyyy}")
+				var timespan = $.fullCalendar.formatDates(event.start, event.end, 'ddd d MMMM[ yyyy]{ - [ddd d] MMMM yyyy}', {monthNamesShort: monthNamesShort, monthNames: monthNames, dayNames: dayNames, dayNamesShort: dayNamesShort}); //t('calendar', "ddd d MMMM[ yyyy]{ - [ddd d] MMMM yyyy}")
 			}else{
-				var timespan = $.fullCalendar.formatDates(event.start, event.end, 'ddd d MMMM[ yyyy] ' + defaulttime + '{ -[ ddd d MMMM yyyy]' + defaulttime + '}', {monthNamesShort: monthNamesShort, monthNames: monthNames, dayNames: dayNames, dayNamesShort: dayNamesShort}); //t('calendar', "ddd d MMMM[ yyyy] HH:mm{ -[ ddd d MMMM yyyy] HH:mm}")
+				var timespan = $.fullCalendar.formatDates(event.start, event.end, 'ddd d MMMM[ yyyy] ' + defaulttime + '{ - [ ddd d MMMM yyyy]' + defaulttime + '}', {monthNamesShort: monthNamesShort, monthNames: monthNames, dayNames: dayNames, dayNamesShort: dayNamesShort}); //t('calendar', "ddd d MMMM[ yyyy] HH:mm{ - [ ddd d MMMM yyyy] HH:mm}")
 				// Tue 18 October 2011 08:00 - 16:00
 			}
 			var html =
@@ -475,7 +529,7 @@ Calendar={
 							$('#fullcalendar').fullCalendar('removeEventSource', data.eventSource.url);
 							$('#fullcalendar').fullCalendar('addEventSource', data.eventSource);
 							if (calendarid == 'new'){
-								$('#choosecalendar_dialog > table:first').append('<tr><td colspan="6"><a href="#" onclick="Calendar.UI.Calendar.newCalendar(this);"><input type="button" value="' + newcalendar + '"></a></td></tr>');
+								$('#choosecalendar_dialog > table:first').append('<tr><td colspan="6"><a href="#" id="chooseCalendar"><input type="button" value="' + newcalendar + '"></a></td></tr>');
 							}
 						}else{
 							$("#displayname_"+calendarid).css('background-color', '#FF2626');
@@ -517,7 +571,7 @@ Calendar={
 		},
 		Share:{
 			init:function(){
-				if(OC.Share) {
+				if(typeof OC.Share !== typeof undefined){
 					var itemShares = [OC.Share.SHARE_TYPE_USER, OC.Share.SHARE_TYPE_GROUP];
 					$('#sharewith').autocomplete({minLength: 2, source: function(search, response) {
 						$.get(OC.filePath('core', 'ajax', 'share.php'), { fetch: 'getShareWith', search: search.term, itemShares: itemShares }, function(result) {
@@ -553,7 +607,7 @@ Calendar={
 						return false;
 					}
 					});
-
+	
 					$('.shareactions > input:checkbox').change(function() {
 						var container = $(this).parents('li').first();
 						var permissions = parseInt(container.data('permissions'));
@@ -577,7 +631,7 @@ Calendar={
 						}
 						OC.Share.setPermissions(itemType, itemSource, shareType, shareWith, permissions);
 					});
-
+	
 					$('.shareactions > .delete').click(function() {
 						var container = $(this).parents('li').first();
 						var itemType = container.data('item-type');
@@ -856,6 +910,7 @@ $(document).ready(function(){
 		eventDrop: Calendar.UI.moveEvent,
 		eventResize: Calendar.UI.resizeEvent,
 		eventRender: function(event, element) {
+			element.find('.fc-event-title').text($("<div/>").html(escapeHTML(event.title)).text())
 			element.tipsy({
 				className: 'tipsy-event',
 				opacity: 0.9,
@@ -890,6 +945,7 @@ $(document).ready(function(){
 	fillWindow($('#content'));
 	OCCategories.changed = Calendar.UI.categoriesChanged;
 	OCCategories.app = 'calendar';
+	OCCategories.type = 'event';
 	$('#oneweekview_radio').click(function(){
 		$('#fullcalendar').fullCalendar('changeView', 'agendaWeek');
 	});
@@ -905,6 +961,9 @@ $(document).ready(function(){
 	$('#datecontrol_left').click(function(){
 		$('#fullcalendar').fullCalendar('prev');
 	});
+	$('#datecontrol_today').click(function(){
+		$('#fullcalendar').fullCalendar('today');
+	});
 	$('#datecontrol_right').click(function(){
 		$('#fullcalendar').fullCalendar('next');
 	});
@@ -912,11 +971,7 @@ $(document).ready(function(){
 	Calendar.UI.Drop.init();
 	$('#choosecalendar .generalsettings').on('click keydown', function(event) {
 		event.preventDefault();
-		OC.appSettings({appid:'calendar', loadJS:true, cache:false});
-	});
-	$('#choosecalendar .calendarsettings').on('click keydown', function(event) {
-		event.preventDefault();
-		OC.appSettings({appid:'calendar', loadJS:true, cache:false, scriptName:'calendar.php'});
+		OC.appSettings({appid:'calendar', loadJS:true, cache:false, scriptName:'settingswrapper.php'});
 	});
 	$('#fullcalendar').fullCalendar('option', 'height', $(window).height() - $('#controls').height() - $('#header').height() - 15);
 });
