@@ -4,6 +4,7 @@
 "No calendars found." => "Žádné kalendáře nenalezeny.",
 "No events found." => "Žádné události nenalezeny.",
 "Wrong calendar" => "Nesprávný kalendář",
+"You do not have the permissions to edit this event." => "Nemáte práva upravovat tuto událost.",
 "The file contained either no events or all events are already saved in your calendar." => "Soubor neobsahoval žádné události, nebo jsou všechny události již ve Vašem kalendáři.",
 "events has been saved in the new calendar" => "události byly uloženy v novém kalendáři",
 "Import failed" => "Import selhal",
@@ -13,8 +14,8 @@
 "Invalid request" => "Neplatný požadavek",
 "Calendar" => "Kalendář",
 "Deletion failed" => "Mazání selhalo.",
-"ddd d MMMM[ yyyy]{ -[ddd d] MMMM yyyy}" => "ddd d MMMM[ rrrr]{ -[ddd d] MMMM rrrr}",
-"ddd d MMMM[ yyyy] HH:mm{ -[ ddd d MMMM yyyy] HH:mm}" => "ddd d MMMM[ rrrr] HH:mm{ -[ ddd d MMMM rrrr] HH:mm}",
+"ddd d MMMM[ yyyy]{ - [ddd d] MMMM yyyy}" => "ddd d MMMM[ yyyy]{ - [ddd d] MMMM yyyy}",
+"ddd d MMMM[ yyyy] HH:mm{ - [ ddd d MMMM yyyy] HH:mm}" => "ddd d MMMM[ yyyy] HH:mm{ - [ ddd d MMMM yyyy] HH:mm}",
 "user" => "uživatel",
 "group" => "skupina",
 "Editable" => "Upravitelné",
@@ -23,9 +24,57 @@
 "ddd" => "ddd",
 "ddd M/d" => "ddd M/d",
 "dddd M/d" => "dddd M/d",
-"MMMM yyyy" => "MMMM rrrr",
+"MMMM yyyy" => "MMMM yyyy",
 "MMM d[ yyyy]{ '&#8212;'[ MMM] d yyyy}" => "d. MMM[ yyyy]{ '&#8212;' d.[ MMM] yyyy}",
-"dddd, MMM d, yyyy" => "dddd, MMM d, rrrr",
+"dddd, MMM d, yyyy" => "dddd, MMM d, yyyy",
+"Sunday" => "Neděle",
+"Monday" => "Pondělí",
+"Tuesday" => "Úterý",
+"Wednesday" => "Středa",
+"Thursday" => "Čtvrtek",
+"Friday" => "Pátek",
+"Saturday" => "Sobota",
+"Sun." => "Ne",
+"Mon." => "Po",
+"Tue." => "Út",
+"Wed." => "St",
+"Thu." => "Čt",
+"Fri." => "Pá",
+"Sat." => "So",
+"January" => "Leden",
+"February" => "Únor",
+"March" => "Březen",
+"April" => "Duben",
+"May" => "Květen",
+"June" => "Červen",
+"July" => "Červenec",
+"August" => "Srpen",
+"September" => "Září",
+"October" => "Říjen",
+"November" => "Listopad",
+"December" => "Prosinec",
+"Jan." => "leden",
+"Feb." => "únor",
+"Mar." => "březen",
+"Apr." => "duben",
+"May." => "květen",
+"Jun." => "červen",
+"Jul." => "červenec",
+"Aug." => "srpen",
+"Sep." => "září",
+"Oct." => "říjen",
+"Nov." => "listopad",
+"Dec." => "prosinec",
+"All day" => "Celý den",
+"New Calendar" => "Nový kalendář",
+"Missing or invalid fields" => "Chybějící, nebo neplatná pole",
+"Title" => "Název",
+"From Date" => "Od data",
+"From Time" => "Od",
+"To Date" => "Do data",
+"To Time" => "Do",
+"The event ends before it starts" => "Událost končí před svým zahájením",
+"There was a database fail" => "Chyba v databázi",
 "Birthday" => "Narozeniny",
 "Business" => "Obchodní",
 "Call" => "Hovor",
@@ -46,10 +95,12 @@
 "You do not have the permissions to update this calendar." => "Nemáte práva pro aktualizaci tohoto kalendáře.",
 "You do not have the permissions to delete this calendar." => "Nemáte práva pro smazání tohoto kalendáře.",
 "You do not have the permissions to add to this calendar." => "Nemáte práva pro přidání tohoto kalendáře.",
-"New Calendar" => "Nový kalendář",
 "You do not have the permissions to add events to this calendar." => "Nemáte práva pro přidání událostí do tohoto kalendáře.",
-"You do not have the permissions to edit this event." => "Nemáte práva upravovat tuto událost.",
 "You do not have the permissions to delete this event." => "Nemáte práva smazat tuto událost.",
+"Busy" => "Zaneprázdněná",
+"Public" => "Veřejná",
+"Private" => "Soukromá",
+"Confidential" => "Důvěrná",
 "Does not repeat" => "Neopakuje se",
 "Daily" => "Denně",
 "Weekly" => "Týdně",
@@ -62,13 +113,6 @@
 "by date" => "podle data",
 "by monthday" => "podle dne v měsíci",
 "by weekday" => "podle dne v týdnu",
-"Monday" => "Pondělí",
-"Tuesday" => "Úterý",
-"Wednesday" => "Středa",
-"Thursday" => "Čtvrtek",
-"Friday" => "Pátek",
-"Saturday" => "Sobota",
-"Sunday" => "Neděle",
 "events week of month" => "týdenní události v měsíci",
 "first" => "první",
 "second" => "druhý",
@@ -76,57 +120,16 @@
 "fourth" => "čtvrtý",
 "fifth" => "pátý",
 "last" => "poslední",
-"January" => "Leden",
-"February" => "Únor",
-"March" => "Březen",
-"April" => "Duben",
-"May" => "Květen",
-"June" => "Červen",
-"July" => "Červenec",
-"August" => "Srpen",
-"September" => "Září",
-"October" => "Říjen",
-"November" => "Listopad",
-"December" => "Prosinec",
 "by events date" => "podle data události",
 "by yearday(s)" => "po dni (dnech)",
 "by weeknumber(s)" => "podle čísel týdnů",
 "by day and month" => "podle dne a měsíce",
 "Date" => "Datum",
 "Cal." => "Kal.",
-"Sun." => "Ne",
-"Mon." => "Po",
-"Tue." => "Út",
-"Wed." => "St",
-"Thu." => "Čt",
-"Fri." => "Pá",
-"Sat." => "So",
-"Jan." => "leden",
-"Feb." => "únor",
-"Mar." => "březen",
-"Apr." => "duben",
-"May." => "květen",
-"Jun." => "červen",
-"Jul." => "červenec",
-"Aug." => "srpen",
-"Sep." => "září",
-"Oct." => "říjen",
-"Nov." => "listopad",
-"Dec." => "prosinec",
-"All day" => "Celý den",
-"Missing fields" => "Chybějící pole",
-"Title" => "Název",
-"From Date" => "Od data",
-"From Time" => "Od",
-"To Date" => "Do data",
-"To Time" => "Do",
-"The event ends before it starts" => "Událost končí před svým zahájením",
-"There was a database fail" => "Chyba v databázi",
 "Week" => "Týden",
 "Month" => "Měsíc",
 "List" => "Seznam",
 "Today" => "Dnes",
-"Calendars" => "Kalendáře",
 "Settings" => "Nastavení",
 "Your calendars" => "Vaše kalendáře",
 "CalDav Link" => "Odkaz CalDav",
@@ -134,7 +137,6 @@
 "Download" => "Stáhnout",
 "Edit" => "Upravit",
 "Delete" => "Smazat",
-"shared with you by" => "sdíleno s Vámi uživatelem",
 "New calendar" => "Nový kalendář",
 "Edit calendar" => "Upravit kalendář",
 "Displayname" => "Zobrazované jméno",
@@ -154,6 +156,7 @@
 "Category" => "Kategorie",
 "Separate categories with commas" => "Kategorie oddělené čárkami",
 "Edit categories" => "Upravit kategorie",
+"Access Class" => "Třída přístupu",
 "All Day Event" => "Celodenní událost",
 "From" => "Od",
 "To" => "Do",
@@ -180,6 +183,7 @@
 "Name of new calendar" => "Název nového kalendáře",
 "Take an available name!" => "Použijte dostupný název.",
 "A Calendar with this name already exists. If you continue anyhow, these calendars will be merged." => "Kalendář s tímto názvem již existuje. Pokud název použijete, budou tyto kalendáře sloučeny.",
+"Remove all events from the selected calendar" => "Odebrat všechny události z vybraného kalendáře",
 "Import" => "Importovat",
 "Close Dialog" => "Zavřít dialog",
 "Create a new event" => "Vytvořit novou událost",
