@@ -4,6 +4,7 @@
 "No calendars found." => "No se encontraron calendarios.",
 "No events found." => "No se encontraron eventos.",
 "Wrong calendar" => "Calendario incorrecto",
+"You do not have the permissions to edit this event." => "No tiene permisos para editar este evento.",
 "The file contained either no events or all events are already saved in your calendar." => "El archivo no contiene eventos o ya existen en tu calendario.",
 "events has been saved in the new calendar" => "Los eventos han sido guardados en el nuevo calendario",
 "Import failed" => "Fallo en la importación",
@@ -13,8 +14,8 @@
 "Invalid request" => "Petición no válida",
 "Calendar" => "Calendario",
 "Deletion failed" => "Falló el borrado",
-"ddd d MMMM[ yyyy]{ -[ddd d] MMMM yyyy}" => "ddd d MMMM[ yyyy]{ -[ddd d] MMMM yyyy}",
-"ddd d MMMM[ yyyy] HH:mm{ -[ ddd d MMMM yyyy] HH:mm}" => "ddd d MMMM[ yyyy] HH:mm{ -[ ddd d MMMM yyyy] HH:mm",
+"ddd d MMMM[ yyyy]{ - [ddd d] MMMM yyyy}" => "ddd d MMMM[ yyyy]{ -[ddd d] MMMM yyyy}",
+"ddd d MMMM[ yyyy] HH:mm{ - [ ddd d MMMM yyyy] HH:mm}" => "ddd d MMMM[ yyyy] HH:mm{ -[ ddd d MMMM yyyy] HH:mm}",
 "user" => "usuario",
 "group" => "grupo",
 "Editable" => "Editable",
@@ -26,6 +27,54 @@
 "MMMM yyyy" => "MMMM yyyy",
 "MMM d[ yyyy]{ '&#8212;'[ MMM] d yyyy}" => "MMM d[ yyyy]{ '&#8212;'[ MMM] d yyyy}",
 "dddd, MMM d, yyyy" => "dddd, MMM d, yyyy",
+"Sunday" => "Domingo",
+"Monday" => "Lunes",
+"Tuesday" => "Martes",
+"Wednesday" => "Miércoles",
+"Thursday" => "Jueves",
+"Friday" => "Viernes",
+"Saturday" => "Sábado",
+"Sun." => "Dom.",
+"Mon." => "Lun.",
+"Tue." => "Mar.",
+"Wed." => "Mier.",
+"Thu." => "Jue.",
+"Fri." => "Vie.",
+"Sat." => "Sab.",
+"January" => "Enero",
+"February" => "Febrero",
+"March" => "Marzo",
+"April" => "Abril",
+"May" => "Mayo",
+"June" => "Junio",
+"July" => "Julio",
+"August" => "Agosto",
+"September" => "Septiembre",
+"October" => "Octubre",
+"November" => "Noviembre",
+"December" => "Diciembre",
+"Jan." => "Ene.",
+"Feb." => "Feb.",
+"Mar." => "Mar.",
+"Apr." => "Abr.",
+"May." => "May.",
+"Jun." => "Jun.",
+"Jul." => "Jul.",
+"Aug." => "Ago.",
+"Sep." => "Sep.",
+"Oct." => "Oct.",
+"Nov." => "Nov.",
+"Dec." => "Dic.",
+"All day" => "Todo el día",
+"New Calendar" => "Nuevo calendario",
+"Missing or invalid fields" => "Campos inválidos o faltantes",
+"Title" => "Título",
+"From Date" => "Desde la fecha",
+"From Time" => "Desde la hora",
+"To Date" => "Hasta la fecha",
+"To Time" => "Hasta la hora",
+"The event ends before it starts" => "El evento termina antes de que comience",
+"There was a database fail" => "Se ha producido un error en la base de datos",
 "Birthday" => "Cumpleaños",
 "Business" => "Negocios",
 "Call" => "Llamada",
@@ -46,10 +95,12 @@
 "You do not have the permissions to update this calendar." => "No tiene permisos para actualizar este calendario.",
 "You do not have the permissions to delete this calendar." => "No tiene permisos para eliminar este calendario.",
 "You do not have the permissions to add to this calendar." => "No tiene permisos para añadir a este calendario.",
-"New Calendar" => "Nuevo calendario",
 "You do not have the permissions to add events to this calendar." => "No tiene permisos para añadir eventos a este calendario.",
-"You do not have the permissions to edit this event." => "No tiene permisos para editar este evento.",
 "You do not have the permissions to delete this event." => "No tiene permisos para eliminar este evento.",
+"Busy" => "Ocupado",
+"Public" => "Publico",
+"Private" => "Privado",
+"Confidential" => "Confidencial",
 "Does not repeat" => "No se repite",
 "Daily" => "Diariamente",
 "Weekly" => "Semanalmente",
@@ -62,13 +113,6 @@
 "by date" => "por fecha",
 "by monthday" => "por día del mes",
 "by weekday" => "por día de la semana",
-"Monday" => "Lunes",
-"Tuesday" => "Martes",
-"Wednesday" => "Miércoles",
-"Thursday" => "Jueves",
-"Friday" => "Viernes",
-"Saturday" => "Sábado",
-"Sunday" => "Domingo",
 "events week of month" => "eventos de la semana del mes",
 "first" => "primer",
 "second" => "segundo",
@@ -76,57 +120,16 @@
 "fourth" => "cuarto",
 "fifth" => "quinto",
 "last" => "último",
-"January" => "Enero",
-"February" => "Febrero",
-"March" => "Marzo",
-"April" => "Abril",
-"May" => "Mayo",
-"June" => "Junio",
-"July" => "Julio",
-"August" => "Agosto",
-"September" => "Septiembre",
-"October" => "Octubre",
-"November" => "Noviembre",
-"December" => "Diciembre",
 "by events date" => "por fecha de los eventos",
 "by yearday(s)" => "por día(s) del año",
 "by weeknumber(s)" => "por número(s) de semana",
 "by day and month" => "por día y mes",
 "Date" => "Fecha",
 "Cal." => "Cal.",
-"Sun." => "Dom.",
-"Mon." => "Lun.",
-"Tue." => "Mar.",
-"Wed." => "Mier.",
-"Thu." => "Jue.",
-"Fri." => "Vie.",
-"Sat." => "Sab.",
-"Jan." => "Ene.",
-"Feb." => "Feb.",
-"Mar." => "Mar.",
-"Apr." => "Abr.",
-"May." => "May.",
-"Jun." => "Jun.",
-"Jul." => "Jul.",
-"Aug." => "Ago.",
-"Sep." => "Sep.",
-"Oct." => "Oct.",
-"Nov." => "Nov.",
-"Dec." => "Dic.",
-"All day" => "Todo el día",
-"Missing fields" => "Los campos que faltan",
-"Title" => "Título",
-"From Date" => "Desde la fecha",
-"From Time" => "Desde la hora",
-"To Date" => "Hasta la fecha",
-"To Time" => "Hasta la hora",
-"The event ends before it starts" => "El evento termina antes de que comience",
-"There was a database fail" => "Se ha producido un error en la base de datos",
 "Week" => "Semana",
 "Month" => "Mes",
 "List" => "Lista",
 "Today" => "Hoy",
-"Calendars" => "Calendarios",
 "Settings" => "Ajustes",
 "Your calendars" => "Tus calendarios",
 "CalDav Link" => "Enlace a CalDav",
@@ -134,7 +137,6 @@
 "Download" => "Descargar",
 "Edit" => "Editar",
 "Delete" => "Eliminar",
-"shared with you by" => "compartido contigo por",
 "New calendar" => "Nuevo calendario",
 "Edit calendar" => "Editar calendario",
 "Displayname" => "Nombre",
@@ -154,6 +156,7 @@
 "Category" => "Categoría",
 "Separate categories with commas" => "Separar categorías con comas",
 "Edit categories" => "Editar categorías",
+"Access Class" => "Clase de acceso",
 "All Day Event" => "Todo el día",
 "From" => "Desde",
 "To" => "Hasta",
@@ -180,6 +183,7 @@
 "Name of new calendar" => "Nombre del nuevo calendario",
 "Take an available name!" => "¡Elige un nombre disponible!",
 "A Calendar with this name already exists. If you continue anyhow, these calendars will be merged." => "Ya existe un calendario con este nombre. Si continúas, se combinarán los calendarios.",
+"Remove all events from the selected calendar" => "Eliminar todos los eventos del calendario seleccionado",
 "Import" => "Importar",
 "Close Dialog" => "Cerrar diálogo",
 "Create a new event" => "Crear un nuevo evento",
