@@ -4,6 +4,7 @@
 "No calendars found." => "Ez da egutegirik aurkitu.",
 "No events found." => "Ez da gertaerarik aurkitu.",
 "Wrong calendar" => "Egutegi okerra",
+"You do not have the permissions to edit this event." => "Gertaera hau editatzeko baimenik ez daukazu.",
 "The file contained either no events or all events are already saved in your calendar." => "Fitxategiak ez zuen gertaerarik edo gertaera guztiak dagoeneko egutegian gordeta zeuden.",
 "events has been saved in the new calendar" => "gertaerak egutegi berrian gorde dira",
 "Import failed" => "Inportazioak huts egin du",
@@ -13,8 +14,8 @@
 "Invalid request" => "Baliogabeko eskaera",
 "Calendar" => "Egutegia",
 "Deletion failed" => "Ezabaketak huts egin du",
-"ddd d MMMM[ yyyy]{ -[ddd d] MMMM yyyy}" => "[ yyyy]  MMMM ddd d{ - yyyy MMMM [ddd d] }",
-"ddd d MMMM[ yyyy] HH:mm{ -[ ddd d MMMM yyyy] HH:mm}" => "[ yyyy]  MMMM ddd d HH:mm{ - yyyy MMMM [ddd d] HH:mm}",
+"ddd d MMMM[ yyyy]{ - [ddd d] MMMM yyyy}" => "[ yyyy]  MMMM ddd d{ - yyyy MMMM [ddd d] }",
+"ddd d MMMM[ yyyy] HH:mm{ - [ ddd d MMMM yyyy] HH:mm}" => "[ yyyy]  MMMM ddd d HH:mm{ - yyyy MMMM [ddd d] HH:mm}",
 "user" => "erabiltzailea",
 "group" => "taldea",
 "Editable" => "Editagarria",
@@ -26,6 +27,54 @@
 "MMMM yyyy" => "yyyy MMMM",
 "MMM d[ yyyy]{ '&#8212;'[ MMM] d yyyy}" => "[ yyyy] MMM d{ '&#8212;'yyyy [ MMM] d}",
 "dddd, MMM d, yyyy" => "yyyy, MMM d, dddd",
+"Sunday" => "Igandea",
+"Monday" => "Astelehena",
+"Tuesday" => "Asteartea",
+"Wednesday" => "Asteazkena",
+"Thursday" => "Osteguna",
+"Friday" => "Ostirala",
+"Saturday" => "Larunbata",
+"Sun." => "ig.",
+"Mon." => "al.",
+"Tue." => "ar.",
+"Wed." => "az.",
+"Thu." => "og.",
+"Fri." => "ol.",
+"Sat." => "lr.",
+"January" => "Urtarrila",
+"February" => "Otsaila",
+"March" => "Martxoa",
+"April" => "Apirila",
+"May" => "Maiatza",
+"June" => "Ekaina",
+"July" => "Uztaila",
+"August" => "Abuztua",
+"September" => "Iraila",
+"October" => "Urria",
+"November" => "Azaroa",
+"December" => "Abendua",
+"Jan." => "urt.",
+"Feb." => "ots.",
+"Mar." => "mar.",
+"Apr." => "api.",
+"May." => "mai.",
+"Jun." => "eka.",
+"Jul." => "uzt.",
+"Aug." => "abu.",
+"Sep." => "ira.",
+"Oct." => "urr.",
+"Nov." => "aza.",
+"Dec." => "abe.",
+"All day" => "Egun guztia",
+"New Calendar" => "Egutegi berria",
+"Missing or invalid fields" => "Eremuak falta dira edo gaizki daude",
+"Title" => "Izenburua",
+"From Date" => "Hasierako Data",
+"From Time" => "Hasierako Ordua",
+"To Date" => "Bukaerako Data",
+"To Time" => "Bukaerako Ordua",
+"The event ends before it starts" => "Gertaera hasi baino lehen bukatzen da",
+"There was a database fail" => "Datu-baseak huts egin du",
 "Birthday" => "Jaioteguna",
 "Business" => "Negozioa",
 "Call" => "Deia",
@@ -45,10 +94,12 @@
 "You do not have the permissions to update this calendar." => "Egutegi hau eguneratzeko baimenik ez daukazu.",
 "You do not have the permissions to delete this calendar." => "Egutegi hau ezabatzeko baimenik ez daukazu.",
 "You do not have the permissions to add to this calendar." => "Egutegi honetan gehitzeko baimenik ez daukazu.",
-"New Calendar" => "Egutegi berria",
 "You do not have the permissions to add events to this calendar." => "Egutegi honetan gertaerak gehitzeko baimenik ez daukazu.",
-"You do not have the permissions to edit this event." => "Gertaera hau editatzeko baimenik ez daukazu.",
 "You do not have the permissions to delete this event." => "Gertaera hau ezabatzeko baimenik ez daukazu.",
+"Busy" => "Lanpetuta",
+"Public" => "Publikoa",
+"Private" => "Pribatua",
+"Confidential" => "Konfidentziala",
 "Does not repeat" => "Ez da errepikatzen",
 "Daily" => "Egunero",
 "Weekly" => "Astero",
@@ -61,13 +112,6 @@
 "by date" => "dataren arabera",
 "by monthday" => "hileko egunaren arabera",
 "by weekday" => "asteko egunaren arabera",
-"Monday" => "Astelehena",
-"Tuesday" => "Asteartea",
-"Wednesday" => "Asteazkena",
-"Thursday" => "Osteguna",
-"Friday" => "Ostirala",
-"Saturday" => "Larunbata",
-"Sunday" => "Igandea",
 "events week of month" => "gertaeraren hilabeteko astea",
 "first" => "lehenengoa",
 "second" => "bigarrean",
@@ -75,57 +119,16 @@
 "fourth" => "laugarrena",
 "fifth" => "bostgarrena",
 "last" => "azkena",
-"January" => "Urtarrila",
-"February" => "Otsaila",
-"March" => "Martxoa",
-"April" => "Apirila",
-"May" => "Maiatza",
-"June" => "Ekaina",
-"July" => "Uztaila",
-"August" => "Abuztua",
-"September" => "Iraila",
-"October" => "Urria",
-"November" => "Azaroa",
-"December" => "Abendua",
 "by events date" => "gertaeren dataren arabera",
 "by yearday(s)" => "urteko egunaren arabera",
 "by weeknumber(s)" => "aste zenbaki(ar)en arabera",
 "by day and month" => "eguna eta hilabetearen arabera",
 "Date" => "Data",
 "Cal." => "Eg.",
-"Sun." => "ig.",
-"Mon." => "al.",
-"Tue." => "ar.",
-"Wed." => "az.",
-"Thu." => "og.",
-"Fri." => "ol.",
-"Sat." => "lr.",
-"Jan." => "urt.",
-"Feb." => "ots.",
-"Mar." => "mar.",
-"Apr." => "api.",
-"May." => "mai.",
-"Jun." => "eka.",
-"Jul." => "uzt.",
-"Aug." => "abu.",
-"Sep." => "ira.",
-"Oct." => "urr.",
-"Nov." => "aza.",
-"Dec." => "abe.",
-"All day" => "Egun guztia",
-"Missing fields" => "Eremuak faltan",
-"Title" => "Izenburua",
-"From Date" => "Hasierako Data",
-"From Time" => "Hasierako Ordua",
-"To Date" => "Bukaerako Data",
-"To Time" => "Bukaerako Ordua",
-"The event ends before it starts" => "Gertaera hasi baino lehen bukatzen da",
-"There was a database fail" => "Datu-baseak huts egin du",
 "Week" => "Astea",
 "Month" => "Hilabetea",
 "List" => "Zerrenda",
 "Today" => "Gaur",
-"Calendars" => "Egutegiak",
 "Settings" => "Ezarpenak",
 "Your calendars" => "Zure egutegiak",
 "CalDav Link" => "CalDav lotura",
@@ -133,7 +136,6 @@
 "Download" => "Deskargatu",
 "Edit" => "Editatu",
 "Delete" => "Ezabatu",
-"shared with you by" => "honek zurekin elkarbanatu du",
 "New calendar" => "Egutegi berria",
 "Edit calendar" => "Editatu egutegia",
 "Displayname" => "Bistaratzeko izena",
@@ -153,6 +155,7 @@
 "Category" => "Kategoria",
 "Separate categories with commas" => "Banatu kategoriak komekin",
 "Edit categories" => "Editatu kategoriak",
+"Access Class" => "Sarrera mota",
 "All Day Event" => "Egun osoko gertaera",
 "From" => "Hasiera",
 "To" => "Bukaera",
@@ -179,17 +182,19 @@
 "Name of new calendar" => "Egutegi berriaren izena",
 "Take an available name!" => "Hartu eskuragarri dagoen izen bat!",
 "A Calendar with this name already exists. If you continue anyhow, these calendars will be merged." => "Izen hau duen egutegi bat dagoeneko existitzen da. Hala ere jarraitzen baduzu, egutegi hauek elkartuko dira.",
+"Remove all events from the selected calendar" => "Ezabatu hautatutako egutegiko gertaera guztiak",
 "Import" => "Importatu",
 "Close Dialog" => "Itxi lehioa",
 "Create a new event" => "Sortu gertaera berria",
-"Share with:" => "Partekatu honekin:",
-"Shared with" => "Hauekin partekatuta:",
-"Unshare" => "Ez partekatu",
+"Share with:" => "elkarbanatu honekin:",
+"Shared with" => "Hauekin elkarbanatuta:",
+"Unshare" => "Ez elkarbanatu",
 "Nobody" => "Inor",
-"Shared via calendar" => "Egutegiaren bidez partekatuta",
-"NOTE: Actions on events shared via calendar will affect the entire calendar sharing." => "OHARRA: Egutegiaren bidez partekatutako gertaeren gaineko ekintzak egutegi osoaren partekatzean izango dute eragina.",
+"Shared via calendar" => "Egutegiaren bidez elkarbanatuta",
+"NOTE: Actions on events shared via calendar will affect the entire calendar sharing." => "OHARRA: Egutegiaren bidez elkarbanatutako gertaeren gaineko ekintzak egutegi osoaren elkarbanatzean izango dute eragina.",
 "View an event" => "Ikusi gertaera bat",
 "No categories selected" => "Ez da kategoriarik hautatu",
+"at" => "ordua",
 "General" => "Orokorra",
 "Timezone" => "Ordu-zonaldea",
 "Update timezone automatically" => "Eguneratu ordu-zonaldea automatikoki",
