@@ -6,6 +6,7 @@
 "Timezone changed" => "Zon waktu diubah",
 "Invalid request" => "Permintaan tidak sah",
 "Calendar" => "Kalendar",
+"Deletion failed" => "Pemadaman gagal",
 "Editable" => "Boleh disunting",
 "ddd" => "ddd",
 "ddd M/d" => "dd M/d",
@@ -13,6 +14,53 @@
 "MMMM yyyy" => "MMMM yyyy",
 "MMM d[ yyyy]{ '&#8212;'[ MMM] d yyyy}" => "MMM d[ yyyy]{ '&#8212;'[ MMM] d yyyy}",
 "dddd, MMM d, yyyy" => "dddd, MMM d, yyy",
+"Sunday" => "Ahad",
+"Monday" => "Isnin",
+"Tuesday" => "Selasa",
+"Wednesday" => "Rabu",
+"Thursday" => "Khamis",
+"Friday" => "Jumaat",
+"Saturday" => "Sabtu",
+"Sun." => "Ahad",
+"Mon." => "Isnin",
+"Tue." => "Selasa",
+"Wed." => "Rabu ",
+"Thu." => "Khamis",
+"Fri." => "Jumaat",
+"Sat." => "Sabtu",
+"January" => "Januari",
+"February" => "Februari",
+"March" => "Mac",
+"April" => "April",
+"May" => "Mei",
+"June" => "Jun",
+"July" => "Julai",
+"August" => "Ogos",
+"September" => "September",
+"October" => "Oktober",
+"November" => "November",
+"December" => "Disember",
+"Jan." => "Jan.",
+"Feb." => "Feb.",
+"Mar." => "Mac.",
+"Apr." => "Apr.",
+"May." => "May.",
+"Jun." => "Jun.",
+"Jul." => "Jul.",
+"Aug." => "Ogos.",
+"Sep." => "Sept.",
+"Oct." => "Okt.",
+"Nov." => "Nov.",
+"Dec." => "Dis.",
+"All day" => "Sepanjang hari",
+"New Calendar" => "Kalendar baru",
+"Title" => "Tajuk",
+"From Date" => "Dari tarikh",
+"From Time" => "Masa Dari",
+"To Date" => "Sehingga kini",
+"To Time" => "Semasa",
+"The event ends before it starts" => "Peristiwa berakhir sebelum bermula",
+"There was a database fail" => "Terdapat kegagalan pada pengkalan data",
 "Birthday" => "Hari lahir",
 "Business" => "Perniagaan",
 "Call" => "Panggilan",
@@ -29,7 +77,6 @@
 "Questions" => "Soalan",
 "Work" => "Kerja",
 "unnamed" => "tiada nama",
-"New Calendar" => "Kalendar baru",
 "Does not repeat" => "Tidak berulang",
 "Daily" => "Harian",
 "Weekly" => "Mingguan",
@@ -42,13 +89,6 @@
 "by date" => "dari tarikh",
 "by monthday" => "dari haribulan",
 "by weekday" => "dari hari minggu",
-"Monday" => "Isnin",
-"Tuesday" => "Selasa",
-"Wednesday" => "Rabu",
-"Thursday" => "Khamis",
-"Friday" => "Jumaat",
-"Saturday" => "Sabtu",
-"Sunday" => "Ahad",
 "events week of month" => "event minggu dari bulan",
 "first" => "pertama",
 "second" => "kedua",
@@ -56,44 +96,23 @@
 "fourth" => "keempat",
 "fifth" => "kelima",
 "last" => "akhir",
-"January" => "Januari",
-"February" => "Februari",
-"March" => "Mac",
-"April" => "April",
-"May" => "Mei",
-"June" => "Jun",
-"July" => "Julai",
-"August" => "Ogos",
-"September" => "September",
-"October" => "Oktober",
-"November" => "November",
-"December" => "Disember",
 "by events date" => "dari tarikh event",
 "by yearday(s)" => "dari tahun",
 "by weeknumber(s)" => "dari nombor minggu",
 "by day and month" => "dari hari dan bulan",
 "Date" => "Tarikh",
 "Cal." => "Kalendar",
-"All day" => "Sepanjang hari",
-"Missing fields" => "Ruangan tertinggal",
-"Title" => "Tajuk",
-"From Date" => "Dari tarikh",
-"From Time" => "Masa Dari",
-"To Date" => "Sehingga kini",
-"To Time" => "Semasa",
-"The event ends before it starts" => "Peristiwa berakhir sebelum bermula",
-"There was a database fail" => "Terdapat kegagalan pada pengkalan data",
 "Week" => "Minggu",
 "Month" => "Bulan",
 "List" => "Senarai",
 "Today" => "Hari ini",
+"Settings" => "Tetapan",
 "Your calendars" => "Kalendar anda",
 "CalDav Link" => "Pautan CalDav",
 "Share Calendar" => "Kongsi Kalendar",
 "Download" => "Muat turun",
 "Edit" => "Edit",
 "Delete" => "Hapus",
-"shared with you by" => "dikongsi dengan kamu oleh",
 "New calendar" => "Kalendar baru",
 "Edit calendar" => "Edit kalendar",
 "Displayname" => "Paparan nama",
@@ -143,7 +162,11 @@
 "No categories selected" => "Tiada kategori dipilih",
 "of" => "dari",
 "at" => "di",
+"General" => "Umum",
 "Timezone" => "Zon waktu",
 "24h" => "24h",
-"12h" => "12h"
+"12h" => "12h",
+"more info" => "maklumat lanjut",
+"Primary address (Kontact et al)" => "Alamat utama",
+"iOS/OS X" => "iOS/OS X"
 );
