@@ -1,81 +1,46 @@
 <?php $TRANSLATIONS = array(
 "Not all calendars are completely cached" => "Nie wszystkie kalendarze są całkowicie buforowane",
 "Everything seems to be completely cached" => "Wszystko wydaje się być całkowicie buforowane",
-"No calendars found." => "Brak kalendarzy",
-"No events found." => "Brak wydzarzeń",
+"No calendars found." => "Nie znaleziono kalendarzy.",
+"No events found." => "Nie znaleziono wydarzeń.",
 "Wrong calendar" => "Nieprawidłowy kalendarz",
-"The file contained either no events or all events are already saved in your calendar." => "Plik nie zawierał żadne zdarzeń lub wszystkie zdarzenia są już zapisane w kalendarzu.",
+"You do not have the permissions to edit this event." => "Nie masz uprawnień, aby edytować to wydarzenie.",
+"The file contained either no events or all events are already saved in your calendar." => "Plik nie zawierał żadnych wydarzeń lub wszystkie wydarzenia są już zapisane w kalendarzu.",
 "events has been saved in the new calendar" => "zdarzenia zostały zapisane w nowym kalendarzu",
-"Import failed" => "Import nieudany",
-"events has been saved in your calendar" => "zdarzenie zostało zapisane w twoim kalendarzu",
+"Import failed" => "Importowanie nieudane",
+"events has been saved in your calendar" => "wydarzenia zostały zapisane w twoim kalendarzu",
 "New Timezone:" => "Nowa strefa czasowa:",
 "Timezone changed" => "Zmieniono strefę czasową",
 "Invalid request" => "Nieprawidłowe żądanie",
 "Calendar" => "Kalendarz",
-"Deletion failed" => "Skasowanie nie powiodło się",
-"ddd d MMMM[ yyyy]{ -[ddd d] MMMM yyyy}" => "ddd d MMMM[ rrrr]{ -[ddd d] MMMM rrrr}",
-"ddd d MMMM[ yyyy] HH:mm{ -[ ddd d MMMM yyyy] HH:mm}" => "ddd d MMMM[ rrrr] HH:mm{ -[ ddd d MMMM rrrr] HH:mm}",
-"user" => "Użytkownik",
-"group" => "Grupa",
+"Deletion failed" => "Usunięcie nie powiodło się",
+"ddd d MMMM[ yyyy]{ - [ddd d] MMMM yyyy}" => "ddd d MMMM[ rrrr]{ - [ddd d] MMMM rrrr}",
+"ddd d MMMM[ yyyy] HH:mm{ - [ ddd d MMMM yyyy] HH:mm}" => "ddd d MMMM[ rrrr] GG:mm{ - [ ddd d MMMM rrrr] GG:mm}",
+"user" => "użytkownik",
+"group" => "grupa",
 "Editable" => "Edytowalne",
-"Shareable" => "Współdzielone",
+"Shareable" => "Możliwe do udostępniania",
 "Deletable" => "Usuwalne",
 "ddd" => "ddd",
 "ddd M/d" => "ddd M/d",
 "dddd M/d" => "dddd M/d",
-"MMMM yyyy" => "MMMM rrrr",
+"MMMM yyyy" => "MMMM yyyy",
 "MMM d[ yyyy]{ '&#8212;'[ MMM] d yyyy}" => "MMM d[ yyyy]{ '&#8212;'[ MMM] d yyyy}",
-"dddd, MMM d, yyyy" => "dddd, MMM d, rrrr",
-"Birthday" => "Urodziny",
-"Business" => "Interesy",
-"Call" => "Rozmowy",
-"Clients" => "Klienci",
-"Deliverer" => "Dostawcy",
-"Holidays" => "Święta",
-"Ideas" => "Pomysły",
-"Journey" => "Podróże",
-"Jubilee" => "Jubileusze",
-"Meeting" => "Spotkania",
-"Other" => "Inne",
-"Personal" => "Osobiste",
-"Projects" => "Projekty",
-"Questions" => "Pytania",
-"Work" => "Zawodowe",
-"by" => "przez",
-"unnamed" => "nienazwany",
-"You do not have the permissions to update this calendar." => "Nie masz uprawnień do aktualizacji tego kalendarza.",
-"You do not have the permissions to delete this calendar." => "Nie masz uprawnień, aby usunąć ten kalendarz.",
-"You do not have the permissions to add to this calendar." => "Nie masz uprawnień, aby dodawać do tego kalendarza.",
-"New Calendar" => "Nowy kalendarz",
-"You do not have the permissions to add events to this calendar." => "Nie masz uprawnień, aby dodać wydarzenia do tego kalendarza.",
-"You do not have the permissions to edit this event." => "Nie masz uprawnień, aby edytować to wydarzenie.",
-"You do not have the permissions to delete this event." => "Nie masz uprawnień, aby skasować to wydarzenie.",
-"Does not repeat" => "Brak",
-"Daily" => "Codziennie",
-"Weekly" => "Tygodniowo",
-"Every Weekday" => "Każdego dnia tygodnia",
-"Bi-Weekly" => "Dwa razy w tygodniu",
-"Monthly" => "Miesięcznie",
-"Yearly" => "Rocznie",
-"never" => "nigdy",
-"by occurrences" => "przez wydarzenia",
-"by date" => "po dacie",
-"by monthday" => "miesięcznie",
-"by weekday" => "tygodniowo",
+"dddd, MMM d, yyyy" => "dddd, MMM d, yyyy",
+"Sunday" => "Niedziela",
 "Monday" => "Poniedziałek",
 "Tuesday" => "Wtorek",
 "Wednesday" => "Środa",
 "Thursday" => "Czwartek",
 "Friday" => "Piątek",
 "Saturday" => "Sobota",
-"Sunday" => "Niedziela",
-"events week of month" => "wydarzenia miesiąca",
-"first" => "pierwszy",
-"second" => "drugi",
-"third" => "trzeci",
-"fourth" => "czwarty",
-"fifth" => "piąty",
-"last" => "ostatni",
+"Sun." => "N.",
+"Mon." => "Pn.",
+"Tue." => "Wt.",
+"Wed." => "Śr.",
+"Thu." => "Cz.",
+"Fri." => "Pt.",
+"Sat." => "S.",
 "January" => "Styczeń",
 "February" => "Luty",
 "March" => "Marzec",
@@ -88,19 +53,6 @@
 "October" => "Październik",
 "November" => "Listopad",
 "December" => "Grudzień",
-"by events date" => "po datach wydarzeń",
-"by yearday(s)" => "po dniach roku",
-"by weeknumber(s)" => "po tygodniach",
-"by day and month" => "przez dzień i miesiąc",
-"Date" => "Data",
-"Cal." => "Kal.",
-"Sun." => "N.",
-"Mon." => "Pn.",
-"Tue." => "Wt.",
-"Wed." => "Śr.",
-"Thu." => "Cz.",
-"Fri." => "Pt.",
-"Sat." => "S.",
 "Jan." => "Sty.",
 "Feb." => "Lut.",
 "Mar." => "Mar.",
@@ -114,46 +66,97 @@
 "Nov." => "Lis.",
 "Dec." => "Gru.",
 "All day" => "Cały dzień",
-"Missing fields" => "Brakujące pola",
-"Title" => "Nazwa",
+"New Calendar" => "Nowy kalendarz",
+"Missing or invalid fields" => "Brak lub niewłaściwe pola",
+"Title" => "Tytuł",
 "From Date" => "Od daty",
 "From Time" => "Od czasu",
 "To Date" => "Do daty",
 "To Time" => "Do czasu",
 "The event ends before it starts" => "Wydarzenie kończy się przed rozpoczęciem",
 "There was a database fail" => "Awaria bazy danych",
+"Birthday" => "Urodziny",
+"Business" => "Biznesowe",
+"Call" => "Zadzwoń",
+"Clients" => "Klienci",
+"Deliverer" => "Dostawca",
+"Holidays" => "Święta",
+"Ideas" => "Pomysły",
+"Journey" => "Podróż",
+"Jubilee" => "Jubileusz",
+"Meeting" => "Spotkanie",
+"Other" => "Inne",
+"Personal" => "Osobiste",
+"Projects" => "Projekty",
+"Questions" => "Pytania",
+"Work" => "Zawodowe",
+"by" => "przez",
+"unnamed" => "nienazwany",
+"You do not have the permissions to update this calendar." => "Nie masz uprawnień do aktualizacji tego kalendarza.",
+"You do not have the permissions to delete this calendar." => "Nie masz uprawnień, aby usunąć ten kalendarz.",
+"You do not have the permissions to add to this calendar." => "Nie masz uprawnień, aby dodawać do tego kalendarza.",
+"You do not have the permissions to add events to this calendar." => "Nie masz uprawnień, aby dodać wydarzenia do tego kalendarza.",
+"You do not have the permissions to delete this event." => "Nie masz uprawnień, aby usunąć to wydarzenie.",
+"Busy" => "Zajęty",
+"Public" => "Publiczne",
+"Private" => "Prywatny",
+"Confidential" => "Poufne",
+"Does not repeat" => "Nie powtarza się",
+"Daily" => "Codziennie",
+"Weekly" => "Cotygodniowo",
+"Every Weekday" => "Każdego dnia tygodnia",
+"Bi-Weekly" => "Co dwa tygodnie",
+"Monthly" => "Comiesięcznie",
+"Yearly" => "Corocznie",
+"never" => "nigdy",
+"by occurrences" => "po wystąpieniach",
+"by date" => "po dacie",
+"by monthday" => "po dniu miesiąca",
+"by weekday" => "po dniu tygodnia",
+"events week of month" => "wydarzenia miesiąca",
+"first" => "pierwszy",
+"second" => "drugi",
+"third" => "trzeci",
+"fourth" => "czwarty",
+"fifth" => "piąty",
+"last" => "ostatni",
+"by events date" => "po datach wydarzeń",
+"by yearday(s)" => "po dniach roku",
+"by weeknumber(s)" => "po tygodniach",
+"by day and month" => "po dniu i miesiącu",
+"Date" => "Data",
+"Cal." => "Kal.",
 "Week" => "Tydzień",
 "Month" => "Miesiąc",
 "List" => "Lista",
-"Today" => "Dzisiaj",
-"Calendars" => "Kalendarze",
+"Today" => "Dziś",
 "Settings" => "Ustawienia",
 "Your calendars" => "Twoje kalendarze",
-"CalDav Link" => "Wyświetla odnośnik CalDAV",
+"CalDav Link" => "Odnośnik CalDAV",
 "Share Calendar" => "Współdziel kalendarz",
-"Download" => "Pobiera kalendarz",
-"Edit" => "Edytuje kalendarz",
-"Delete" => "Usuwa kalendarz",
-"shared with you by" => "współdzielisz z",
+"Download" => "Pobierz",
+"Edit" => "Edytuj",
+"Delete" => "Usuń",
 "New calendar" => "Nowy kalendarz",
-"Edit calendar" => "Edytowanie kalendarza",
+"Edit calendar" => "Edytuj kalendarz",
 "Displayname" => "Wyświetlana nazwa",
 "Active" => "Aktywny",
-"Calendar color" => "Kolor",
+"Calendar color" => "Kolor kalendarza",
 "Save" => "Zapisz",
 "Submit" => "Prześlij",
 "Cancel" => "Anuluj",
-"Edit an event" => "Edytowanie wydarzenia",
+"Edit an event" => "Edytuj wydarzenie",
 "Export" => "Wyeksportuj",
-"Eventinfo" => "Informacja o wydarzeniach",
-"Repeating" => "Powtarzanie",
+"Eventinfo" => "Informacja o wydarzeniu",
+"Repeating" => "Powtarzające się",
 "Alarm" => "Alarm",
 "Attendees" => "Uczestnicy",
-"Share" => "Współdziel",
+"Share" => "Udostępnij",
 "Title of the Event" => "Nazwa wydarzenia",
 "Category" => "Kategoria",
 "Separate categories with commas" => "Oddziel kategorie przecinkami",
 "Edit categories" => "Edytuj kategorie",
+"Access Class" => "Klasa dostępu",
 "All Day Event" => "Wydarzenie całodniowe",
 "From" => "Od",
 "To" => "Do",
@@ -162,50 +165,51 @@
 "Location of the Event" => "Lokalizacja wydarzenia",
 "Description" => "Opis",
 "Description of the Event" => "Opis wydarzenia",
-"Repeat" => "Powtarzanie",
+"Repeat" => "Powtarzaj",
 "Advanced" => "Zaawansowane",
-"Select weekdays" => "Wybierz dni powszechne",
+"Select weekdays" => "Wybierz dni powszednie",
 "Select days" => "Wybierz dni",
-"and the events day of year." => "oraz wydarzenia roku",
-"and the events day of month." => "oraz wydarzenia miesiąca",
+"and the events day of year." => "oraz wydarzenia w trakcie roku.",
+"and the events day of month." => "oraz wydarzenia w trakcie miesiąca.",
 "Select months" => "Wybierz miesiące",
 "Select weeks" => "Wybierz tygodnie",
-"and the events week of year." => "oraz wydarzenia roku.",
-"Interval" => "Interwał",
+"and the events week of year." => "oraz wydarzenia w trakcie roku.",
+"Interval" => "Odstęp",
 "End" => "Koniec",
 "occurrences" => "wystąpienia",
 "create a new calendar" => "stwórz nowy kalendarz",
 "Import a calendar file" => "Zaimportuj plik kalendarza",
-"Please choose a calendar" => "Proszę wybierz kalendarz",
-"Name of new calendar" => "Nazwa kalendarza",
-"Take an available name!" => "Pobierz dostępne nazwy!",
-"A Calendar with this name already exists. If you continue anyhow, these calendars will be merged." => "Kalendarz o tej nazwie już istnieje. Jeśli kontynuujesz wtedy te kalendarze zostaną scalone.",
-"Import" => "Import",
+"Please choose a calendar" => "Wybierz kalendarz",
+"Name of new calendar" => "Nazwa nowego kalendarza",
+"Take an available name!" => "Wybierz dostępną nazwę!",
+"A Calendar with this name already exists. If you continue anyhow, these calendars will be merged." => "Kalendarz o tej nazwie już istnieje. Jeśli będziesz kontynuować, kalendarze zostaną scalone.",
+"Remove all events from the selected calendar" => "Usuń wszystkie wydarzenia z wybranego kalendarza.",
+"Import" => "Importuj",
 "Close Dialog" => "Zamknij okno",
-"Create a new event" => "Tworzenie nowego wydarzenia",
-"Share with:" => "Dzielić z:",
+"Create a new event" => "Utwórz nowe wydarzenie",
+"Share with:" => "Współdziel z:",
 "Shared with" => "Współdzielone z:",
-"Unshare" => "Nie udostępnione",
+"Unshare" => "Zatrzymaj współdzielenie",
 "Nobody" => "Nikt",
 "Shared via calendar" => "Udostępnione za pośrednictwem kalendarza",
-"NOTE: Actions on events shared via calendar will affect the entire calendar sharing." => "UWAGA: Czynności dotyczące wydarzeń dodanych za pośrednictwem kalendarza mają wpływ na współdzielenie kalendarza.",
-"View an event" => "Zobacz wydarzenie",
-"No categories selected" => "nie zaznaczono kategorii",
+"NOTE: Actions on events shared via calendar will affect the entire calendar sharing." => "UWAGA: Czynności wykonane na wydarzeniach udostępnianych poprzez kalendarz mają wpływ na współdzielenie całego kalendarza.",
+"View an event" => "Wyświetl wydarzenie",
+"No categories selected" => "Nie zaznaczono kategorii",
 "of" => "z",
 "at" => "w",
 "General" => "Ogólne",
 "Timezone" => "Strefa czasowa",
-"Update timezone automatically" => "Automatyczne aktualizowanie stref czasowych",
+"Update timezone automatically" => "Automatyczne aktualizuj strefę czasową",
 "Time format" => "Format czasu",
-"24h" => "24h",
-"12h" => "12h",
-"Start week on" => "Zaczynaj tygodzień od",
+"24h" => "24-godzinny",
+"12h" => "12-godzinny",
+"Start week on" => "Zaczynaj tydzień od",
 "Cache" => "Pamięć podręczna",
-"Clear cache for repeating events" => "Wyczyść pamięć podręczną dla powtarzanych zdarzeń",
-"URLs" => "URL-e",
-"Calendar CalDAV syncing addresses" => "Kalendarz CalDAV synchronizacja adresów",
+"Clear cache for repeating events" => "Wyczyść pamięć podręczną dla powtarzających się zdarzeń",
+"URLs" => "Adresy URL",
+"Calendar CalDAV syncing addresses" => "Adres synchronizacji kalendarza CalDAV",
 "more info" => "więcej informacji",
 "Primary address (Kontact et al)" => "Podstawowy adres",
 "iOS/OS X" => "iOS/OS X",
-"Read only iCalendar link(s)" => "Odczytać tylko linki iCalendar"
+"Read only iCalendar link(s)" => "Odnośniki iCalendar tylko do odczytu"
 );
