@@ -4,6 +4,7 @@
 "No calendars found." => "Nenhum calendário encontrado.",
 "No events found." => "Nenhum evento encontrado.",
 "Wrong calendar" => "Calendário incorreto",
+"You do not have the permissions to edit this event." => "Você não tem permissões para editar esse evento.",
 "The file contained either no events or all events are already saved in your calendar." => "O arquivo não continha nenhum evento ou todos os eventos já estão guardados no seu calendário.",
 "events has been saved in the new calendar" => "os eventos foram salvos no novo calendário",
 "Import failed" => "Falha na importação",
@@ -13,8 +14,8 @@
 "Invalid request" => "Pedido inválido",
 "Calendar" => "Calendário",
 "Deletion failed" => "Remoção falhou",
-"ddd d MMMM[ yyyy]{ -[ddd d] MMMM yyyy}" => "ddd d MMMM[ yyyy]{ -[ddd d] MMMM yyyy}",
-"ddd d MMMM[ yyyy] HH:mm{ -[ ddd d MMMM yyyy] HH:mm}" => "ddd d MMMM[ yyyy] HH:mm{ -[ ddd d MMMM yyyy] HH:mm}",
+"ddd d MMMM[ yyyy]{ - [ddd d] MMMM yyyy}" => "ddd d MMMM[ yyyy]{ -[ddd d] MMMM yyyy}",
+"ddd d MMMM[ yyyy] HH:mm{ - [ ddd d MMMM yyyy] HH:mm}" => "ddd d MMMM[ yyyy] HH:mm{ - [ ddd d MMMM yyyy] HH:mm}",
 "user" => "usuário",
 "group" => "grupo",
 "Editable" => "Editável",
@@ -26,6 +27,54 @@
 "MMMM yyyy" => "MMMM yyyy",
 "MMM d[ yyyy]{ '&#8212;'[ MMM] d yyyy}" => "MMM d[ yyyy]{ '&#8212;'[ MMM] d yyyy}",
 "dddd, MMM d, yyyy" => "dddd, MMM d, yyyy",
+"Sunday" => "Domingo",
+"Monday" => "Segunda-feira",
+"Tuesday" => "Terça-feira",
+"Wednesday" => "Quarta-feira",
+"Thursday" => "Quinta-feira",
+"Friday" => "Sexta-feira",
+"Saturday" => "Sábado",
+"Sun." => "Dom.",
+"Mon." => "Seg.",
+"Tue." => "Ter.",
+"Wed." => "Qua.",
+"Thu." => "Qui.",
+"Fri." => "Sex.",
+"Sat." => "Sáb.",
+"January" => "Janeiro",
+"February" => "Fevereiro",
+"March" => "Março",
+"April" => "Abril",
+"May" => "Maio",
+"June" => "Junho",
+"July" => "Julho",
+"August" => "Agosto",
+"September" => "Setembro",
+"October" => "Outubro",
+"November" => "Novembro",
+"December" => "Dezembro",
+"Jan." => "Jan.",
+"Feb." => "Fev.",
+"Mar." => "Mar.",
+"Apr." => "Abr.",
+"May." => "Mai.",
+"Jun." => "Jun.",
+"Jul." => "Jul.",
+"Aug." => "Ago.",
+"Sep." => "Set.",
+"Oct." => "Out.",
+"Nov." => "Nov.",
+"Dec." => "Dez.",
+"All day" => "Todo o dia",
+"New Calendar" => "Novo Calendário",
+"Missing or invalid fields" => "Campos faltando ou inválidos",
+"Title" => "Título",
+"From Date" => "Desde a Data",
+"From Time" => "Desde a Hora",
+"To Date" => "Até a Data",
+"To Time" => "Até a Hora",
+"The event ends before it starts" => "O evento termina antes de começar",
+"There was a database fail" => "Houve uma falha de banco de dados",
 "Birthday" => "Aniversário",
 "Business" => "Negócio",
 "Call" => "Chamada",
@@ -46,10 +95,12 @@
 "You do not have the permissions to update this calendar." => "Você não tem permissões para atualizar esse calendário.",
 "You do not have the permissions to delete this calendar." => "Você não tem permissões para remover esse calendário.",
 "You do not have the permissions to add to this calendar." => "Você não tem permissões para adicionar esse calendário.",
-"New Calendar" => "Novo Calendário",
 "You do not have the permissions to add events to this calendar." => "Você não tem permissões para adicionar eventos nesse calendário.",
-"You do not have the permissions to edit this event." => "Você não tem permissões para editar esse evento.",
 "You do not have the permissions to delete this event." => "Você não tem permissões para remover esse evento.",
+"Busy" => "Ocupado",
+"Public" => "Público",
+"Private" => "Privado",
+"Confidential" => "Confidencial",
 "Does not repeat" => "Não repetir",
 "Daily" => "Diariamente",
 "Weekly" => "Semanal",
@@ -62,13 +113,6 @@
 "by date" => "por data",
 "by monthday" => "por dia do mês",
 "by weekday" => "por dia da semana",
-"Monday" => "Segunda-feira",
-"Tuesday" => "Terça-feira",
-"Wednesday" => "Quarta-feira",
-"Thursday" => "Quinta-feira",
-"Friday" => "Sexta-feira",
-"Saturday" => "Sábado",
-"Sunday" => "Domingo",
 "events week of month" => "semana do evento no mês",
 "first" => "primeiro",
 "second" => "segundo",
@@ -76,57 +120,16 @@
 "fourth" => "quarto",
 "fifth" => "quinto",
 "last" => "último",
-"January" => "Janeiro",
-"February" => "Fevereiro",
-"March" => "Março",
-"April" => "Abril",
-"May" => "Maio",
-"June" => "Junho",
-"July" => "Julho",
-"August" => "Agosto",
-"September" => "Setembro",
-"October" => "Outubro",
-"November" => "Novembro",
-"December" => "Dezembro",
 "by events date" => "eventos por data",
 "by yearday(s)" => "por dia(s) do ano",
 "by weeknumber(s)" => "por número(s) da semana",
 "by day and month" => "por dia e mês",
 "Date" => "Data",
 "Cal." => "Cal.",
-"Sun." => "Dom.",
-"Mon." => "Seg.",
-"Tue." => "Ter.",
-"Wed." => "Qua.",
-"Thu." => "Qui.",
-"Fri." => "Sex.",
-"Sat." => "Sáb.",
-"Jan." => "Jan.",
-"Feb." => "Fev.",
-"Mar." => "Mar.",
-"Apr." => "Abr.",
-"May." => "Mai.",
-"Jun." => "Jun.",
-"Jul." => "Jul.",
-"Aug." => "Ago.",
-"Sep." => "Set.",
-"Oct." => "Out.",
-"Nov." => "Nov.",
-"Dec." => "Dez.",
-"All day" => "Todo o dia",
-"Missing fields" => "Campos incompletos",
-"Title" => "Título",
-"From Date" => "Desde a Data",
-"From Time" => "Desde a Hora",
-"To Date" => "Até a Data",
-"To Time" => "Até a Hora",
-"The event ends before it starts" => "O evento termina antes de começar",
-"There was a database fail" => "Houve uma falha de banco de dados",
 "Week" => "Semana",
 "Month" => "Mês",
 "List" => "Lista",
 "Today" => "Hoje",
-"Calendars" => "Calendários",
 "Settings" => "Ajustes",
 "Your calendars" => "Meus Calendários",
 "CalDav Link" => "Link para CalDav",
@@ -134,7 +137,6 @@
 "Download" => "Baixar",
 "Edit" => "Editar",
 "Delete" => "Excluir",
-"shared with you by" => "compartilhado com você por",
 "New calendar" => "Novo calendário",
 "Edit calendar" => "Editar calendário",
 "Displayname" => "Mostrar Nome",
@@ -154,6 +156,7 @@
 "Category" => "Categoria",
 "Separate categories with commas" => "Separe as categorias por vírgulas",
 "Edit categories" => "Editar categorias",
+"Access Class" => "Classe de Acesso",
 "All Day Event" => "Evento de dia inteiro",
 "From" => "De",
 "To" => "Para",
@@ -180,6 +183,7 @@
 "Name of new calendar" => "Nome do novo calendário",
 "Take an available name!" => "Use um nome disponível!",
 "A Calendar with this name already exists. If you continue anyhow, these calendars will be merged." => "Um calendário com este nome já existe. Se de qualquer forma você continuar, estes calendários serão fundidos.",
+"Remove all events from the selected calendar" => "Remover todos os eventos do calendário selecionado",
 "Import" => "Importar",
 "Close Dialog" => "Fechar caixa de diálogo",
 "Create a new event" => "Criar um novo evento",
