@@ -4,6 +4,7 @@
 "No calendars found." => "Nenhum calendário encontrado.",
 "No events found." => "Nenhum evento encontrado.",
 "Wrong calendar" => "Calendário errado",
+"You do not have the permissions to edit this event." => "Não tem permissões para alterar este evento.",
 "The file contained either no events or all events are already saved in your calendar." => "O ficheiro não continha nenhuns eventos ou então todos os eventos já estavam carregados no seu calendário",
 "events has been saved in the new calendar" => "Os eventos foram guardados no novo calendário",
 "Import failed" => "Falha na importação",
@@ -13,11 +14,11 @@
 "Invalid request" => "Pedido inválido",
 "Calendar" => "Calendário",
 "Deletion failed" => "Erro ao apagar",
-"ddd d MMMM[ yyyy]{ -[ddd d] MMMM yyyy}" => "ddd d MMMM[ yyyy]{ -[ddd d] MMMM yyyy}",
-"ddd d MMMM[ yyyy] HH:mm{ -[ ddd d MMMM yyyy] HH:mm}" => "ddd d MMMM[ yyyy] HH:mm{ -[ ddd d MMMM yyyy] HH:mm}",
+"ddd d MMMM[ yyyy]{ - [ddd d] MMMM yyyy}" => "ddd d MMMM[ yyyy]{ - [ddd d] MMMM yyyy}",
+"ddd d MMMM[ yyyy] HH:mm{ - [ ddd d MMMM yyyy] HH:mm}" => "ddd d MMMM[ yyyy] HH:mm{ - [ ddd d MMMM yyyy] HH:mm}",
 "user" => "utilizador",
 "group" => "grupo",
-"Editable" => "Editavel",
+"Editable" => "Editável",
 "Shareable" => "Partilhável",
 "Deletable" => "Apagável",
 "ddd" => "ddd",
@@ -26,56 +27,20 @@
 "MMMM yyyy" => "MMMM yyyy",
 "MMM d[ yyyy]{ '&#8212;'[ MMM] d yyyy}" => "MMM d[ yyyy]{ '&#8212;'[ MMM] d yyyy}",
 "dddd, MMM d, yyyy" => "dddd, MMM d, yyyy",
-"Birthday" => "Aniversário",
-"Business" => "Negócio",
-"Call" => "Telefonar",
-"Clients" => "Clientes",
-"Deliverer" => "Entregar",
-"Holidays" => "Férias",
-"Ideas" => "Ideias",
-"Journey" => "Jornada",
-"Jubilee" => "Jublieu",
-"Meeting" => "Reunião",
-"Other" => "Outro",
-"Personal" => "Pessoal",
-"Projects" => "Projetos",
-"Questions" => "Perguntas",
-"Work" => "Trabalho",
-"by" => "por",
-"unnamed" => "não definido",
-"You do not have the permissions to update this calendar." => "Não tem permissões para alterar este calendário.",
-"You do not have the permissions to delete this calendar." => "Não tem permissões para apagar este calendário.",
-"You do not have the permissions to add to this calendar." => "Não tem permissões para acrescentar a este calendário.",
-"New Calendar" => "Novo calendário",
-"You do not have the permissions to add events to this calendar." => "Não tem permissões para acrescentar eventos a este calendário.",
-"You do not have the permissions to edit this event." => "Não tem permissões para alterar este evento.",
-"You do not have the permissions to delete this event." => "Não tem permissões para apagar este evento.",
-"Does not repeat" => "Não repete",
-"Daily" => "Diário",
-"Weekly" => "Semanal",
-"Every Weekday" => "Todos os dias da semana",
-"Bi-Weekly" => "Bi-semanal",
-"Monthly" => "Mensal",
-"Yearly" => "Anual",
-"never" => "nunca",
-"by occurrences" => "por ocorrências",
-"by date" => "por data",
-"by monthday" => "por dia do mês",
-"by weekday" => "por dia da semana",
+"Sunday" => "Domingo",
 "Monday" => "Segunda",
 "Tuesday" => "Terça",
 "Wednesday" => "Quarta",
 "Thursday" => "Quinta",
 "Friday" => "Sexta",
 "Saturday" => "Sábado",
-"Sunday" => "Domingo",
-"events week of month" => "Eventos da semana do mês",
-"first" => "primeiro",
-"second" => "segundo",
-"third" => "terçeiro",
-"fourth" => "quarto",
-"fifth" => "quinto",
-"last" => "último",
+"Sun." => "Dom.",
+"Mon." => "Seg.",
+"Tue." => "ter.",
+"Wed." => "Qua.",
+"Thu." => "Qui.",
+"Fri." => "Sex.",
+"Sat." => "Sáb.",
 "January" => "Janeiro",
 "February" => "Fevereiro",
 "March" => "Março",
@@ -88,19 +53,6 @@
 "October" => "Outubro",
 "November" => "Novembro",
 "December" => "Dezembro",
-"by events date" => "por data de evento",
-"by yearday(s)" => "por dia(s) do ano",
-"by weeknumber(s)" => "por número(s) da semana",
-"by day and month" => "por dia e mês",
-"Date" => "Data",
-"Cal." => "Cal.",
-"Sun." => "Dom.",
-"Mon." => "Seg.",
-"Tue." => "ter.",
-"Wed." => "Qua.",
-"Thu." => "Qui.",
-"Fri." => "Sex.",
-"Sat." => "Sáb.",
 "Jan." => "Jan.",
 "Feb." => "Fev,",
 "Mar." => "Mar.",
@@ -114,19 +66,70 @@
 "Nov." => "Nov.",
 "Dec." => "Dez.",
 "All day" => "Todo o dia",
-"Missing fields" => "Falta campos",
+"New Calendar" => "Novo Calendário",
+"Missing or invalid fields" => "Campos em falta, ou inválidos!",
 "Title" => "Título",
-"From Date" => "Da data",
-"From Time" => "Da hora",
-"To Date" => "Para data",
-"To Time" => "Para hora",
+"From Date" => "Da Data",
+"From Time" => "Da Hora",
+"To Date" => "Para Data",
+"To Time" => "Para Hora",
 "The event ends before it starts" => "O evento acaba antes de começar",
 "There was a database fail" => "Houve uma falha de base de dados",
+"Birthday" => "Aniversário",
+"Business" => "Negócio",
+"Call" => "Telefonar",
+"Clients" => "Clientes",
+"Deliverer" => "Entregar",
+"Holidays" => "Férias",
+"Ideas" => "Ideias",
+"Journey" => "Jornada",
+"Jubilee" => "Jublieu",
+"Meeting" => "Reunião",
+"Other" => "Outro",
+"Personal" => "Pessoal",
+"Projects" => "Projectos",
+"Questions" => "Perguntas",
+"Work" => "Trabalho",
+"by" => "por",
+"unnamed" => "não definido",
+"You do not have the permissions to update this calendar." => "Não tem permissões para alterar este calendário.",
+"You do not have the permissions to delete this calendar." => "Não tem permissões para apagar este calendário.",
+"You do not have the permissions to add to this calendar." => "Não tem permissões para acrescentar a este calendário.",
+"You do not have the permissions to add events to this calendar." => "Não tem permissões para acrescentar eventos a este calendário.",
+"You do not have the permissions to delete this event." => "Não tem permissões para apagar este evento.",
+"Busy" => "Ocupado",
+"Public" => "Público",
+"Private" => "Privado",
+"Confidential" => "Confidencial",
+"Does not repeat" => "Não repete",
+"Daily" => "Diário",
+"Weekly" => "Semanal",
+"Every Weekday" => "Todos os dias da semana",
+"Bi-Weekly" => "Bi-semanal",
+"Monthly" => "Mensal",
+"Yearly" => "Anual",
+"never" => "nunca",
+"by occurrences" => "por ocorrências",
+"by date" => "por data",
+"by monthday" => "por dia do mês",
+"by weekday" => "por dia da semana",
+"events week of month" => "Eventos da semana do mês",
+"first" => "primeiro",
+"second" => "segundo",
+"third" => "terçeiro",
+"fourth" => "quarto",
+"fifth" => "quinto",
+"last" => "último",
+"by events date" => "por data de evento",
+"by yearday(s)" => "por dia(s) do ano",
+"by weeknumber(s)" => "por número(s) da semana",
+"by day and month" => "por dia e mês",
+"Date" => "Data",
+"Cal." => "Cal.",
 "Week" => "Semana",
 "Month" => "Mês",
 "List" => "Lista",
 "Today" => "Hoje",
-"Calendars" => "Calendários",
 "Settings" => "Configurações",
 "Your calendars" => "Os seus calendários",
 "CalDav Link" => "Endereço CalDav",
@@ -134,7 +137,6 @@
 "Download" => "Transferir",
 "Edit" => "Editar",
 "Delete" => "Apagar",
-"shared with you by" => "Partilhado consigo por",
 "New calendar" => "Novo calendário",
 "Edit calendar" => "Editar calendário",
 "Displayname" => "Nome de exibição",
@@ -154,6 +156,7 @@
 "Category" => "Categoria",
 "Separate categories with commas" => "Separe categorias por virgulas",
 "Edit categories" => "Editar categorias",
+"Access Class" => "Classe de Acesso",
 "All Day Event" => "Evento de dia inteiro",
 "From" => "De",
 "To" => "Para",
@@ -168,8 +171,8 @@
 "Select days" => "Seleciona os dias",
 "and the events day of year." => "e o dia de eventos do ano.",
 "and the events day of month." => "e o dia de eventos do mês.",
-"Select months" => "Seleciona os meses",
-"Select weeks" => "Seleciona as semanas",
+"Select months" => "Selecciona os meses",
+"Select weeks" => "Selecciona as semanas",
 "and the events week of year." => "e a semana de eventos do ano.",
 "Interval" => "Intervalo",
 "End" => "Fim",
@@ -179,7 +182,8 @@
 "Please choose a calendar" => "Escolha um calendário por favor",
 "Name of new calendar" => "Nome do novo calendário",
 "Take an available name!" => "Escolha um nome disponível!",
-"A Calendar with this name already exists. If you continue anyhow, these calendars will be merged." => "Já existe um Calendário com esse nome. Se mesmo assim continuar, esses calendários serão fundidos.",
+"A Calendar with this name already exists. If you continue anyhow, these calendars will be merged." => "Já existe um Calendário com esse nome. Se mesmo assim continuar, estes calendários serão fundidos.",
+"Remove all events from the selected calendar" => "Remover todos os eventos do calendário seleccionado",
 "Import" => "Importar",
 "Close Dialog" => "Fechar diálogo",
 "Create a new event" => "Criar novo evento",
@@ -205,7 +209,7 @@
 "URLs" => "Endereço(s) web",
 "Calendar CalDAV syncing addresses" => "Endereços de sincronização de calendários CalDAV",
 "more info" => "mais informação",
-"Primary address (Kontact et al)" => "Endereço principal (contactos et al.)",
+"Primary address (Kontact et al)" => "Endereço principal (Kontact et al.)",
 "iOS/OS X" => "iOS/OS X",
 "Read only iCalendar link(s)" => "Ligaç(ão/ões) só de leitura do iCalendar"
 );
