@@ -12,7 +12,7 @@
  * The following SQL statement is just a help for developers and will not be
  * executed!
  *
- * CREATE TABLE calendar_objects (
+ * CREATE TABLE clndr_objects (
  *     id INTEGER UNSIGNED NOT NULL PRIMARY KEY AUTO_INCREMENT,
  *     calendarid INTEGER UNSIGNED NOT NULL,
  *     objecttype VARCHAR(40) NOT NULL,
@@ -40,7 +40,7 @@ class OC_Calendar_Object{
 	 * ['calendardata']
 	 */
 	public static function all($id) {
-		$stmt = OCP\DB::prepare( 'SELECT * FROM `*PREFIX*calendar_objects` WHERE `calendarid` = ?' );
+		$stmt = OCP\DB::prepare( 'SELECT * FROM `*PREFIX*clndr_objects` WHERE `calendarid` = ?' );
 		$result = $stmt->execute(array($id));
 
 		$calendarobjects = array();
@@ -62,7 +62,7 @@ class OC_Calendar_Object{
 	 * in ['calendardata']
 	 */
 	public static function allInPeriod($id, $start, $end) {
-		$stmt = OCP\DB::prepare( 'SELECT * FROM `*PREFIX*calendar_objects` WHERE `calendarid` = ?'
+		$stmt = OCP\DB::prepare( 'SELECT * FROM `*PREFIX*clndr_objects` WHERE `calendarid` = ?'
 		.' AND ((`startdate` >= ? AND `startdate` <= ? AND `repeating` = 0)'
 		.' OR (`enddate` >= ? AND `enddate` <= ? AND `repeating` = 0)'
 		.' OR (`startdate` <= ? AND `repeating` = 1))' );
@@ -84,16 +84,12 @@ class OC_Calendar_Object{
 	/**
 	 * @brief Returns an object
 	 * @param integer $id
-	 * @return associative array or false if entry isn't found.
+	 * @return associative array
 	 */
 	public static function find($id) {
-		$stmt = OCP\DB::prepare( 'SELECT * FROM `*PREFIX*calendar_objects` WHERE `id` = ?' );
+		$stmt = OCP\DB::prepare( 'SELECT * FROM `*PREFIX*clndr_objects` WHERE `id` = ?' );
 		$result = $stmt->execute(array($id));
 
-		if($result->numRows() == 0) {
-			return false;
-		}
-
 		return $result->fetchRow();
 	}
 
@@ -104,7 +100,7 @@ class OC_Calendar_Object{
 	 * @return associative array
 	 */
 	public static function findWhereDAVDataIs($cid,$uri) {
-		$stmt = OCP\DB::prepare( 'SELECT * FROM `*PREFIX*calendar_objects` WHERE `calendarid` = ? AND `uri` = ?' );
+		$stmt = OCP\DB::prepare( 'SELECT * FROM `*PREFIX*clndr_objects` WHERE `calendarid` = ? AND `uri` = ?' );
 		$result = $stmt->execute(array($cid,$uri));
 
 		return $result->fetchRow();
@@ -120,7 +116,7 @@ class OC_Calendar_Object{
 		$calendar = OC_Calendar_Calendar::find($id);
 		if ($calendar['userid'] != OCP\User::getUser()) {
 			$sharedCalendar = OCP\Share::getItemSharedWithBySource('calendar', $id);
-			if (!$sharedCalendar || !($sharedCalendar['permissions'] & OCP\Share::PERMISSION_CREATE)) {
+			if (!$sharedCalendar || !($sharedCalendar['permissions'] & OCP\PERMISSION_CREATE)) {
 				throw new Exception(
 					OC_Calendar_App::$l10n->t(
 						'You do not have the permissions to add events to this calendar.'
@@ -129,7 +125,6 @@ class OC_Calendar_Object{
 			}
 		}
 		$object = OC_VObject::parse($data);
-		OC_Calendar_App::loadCategoriesFromVCalendar($object);
 		list($type,$startdate,$enddate,$summary,$repeating,$uid) = self::extractData($object);
 
 		if(is_null($uid)) {
@@ -139,9 +134,11 @@ class OC_Calendar_Object{
 
 		$uri = 'owncloud-'.md5($data.rand().time()).'.ics';
 
-		$stmt = OCP\DB::prepare( 'INSERT INTO `*PREFIX*calendar_objects` (`calendarid`,`objecttype`,`startdate`,`enddate`,`repeating`,`summary`,`calendardata`,`uri`,`lastmodified`) VALUES(?,?,?,?,?,?,?,?,?)' );
+		$stmt = OCP\DB::prepare( 'INSERT INTO `*PREFIX*clndr_objects` (`calendarid`,`objecttype`,`startdate`,`enddate`,`repeating`,`summary`,`calendardata`,`uri`,`lastmodified`) VALUES(?,?,?,?,?,?,?,?,?)' );
 		$stmt->execute(array($id,$type,$startdate,$enddate,$repeating,$summary,$data,$uri,time()));
-		$object_id = OCP\DB::insertid('*PREFIX*calendar_objects');
+		$object_id = OCP\DB::insertid('*PREFIX*clndr_objects');
+
+		OC_Calendar_App::loadCategoriesFromVCalendar($object_id, $object);
 
 		OC_Calendar_Calendar::touchCalendar($id);
 		OCP\Util::emitHook('OC_Calendar', 'addEvent', $object_id);
@@ -159,7 +156,7 @@ class OC_Calendar_Object{
 		$calendar = OC_Calendar_Calendar::find($id);
 		if ($calendar['userid'] != OCP\User::getUser()) {
 			$sharedCalendar = OCP\Share::getItemSharedWithBySource('calendar', $id);
-			if (!$sharedCalendar || !($sharedCalendar['permissions'] & OCP\Share::PERMISSION_CREATE)) {
+			if (!$sharedCalendar || !($sharedCalendar['permissions'] & OCP\PERMISSION_CREATE)) {
 				throw new Sabre_DAV_Exception_Forbidden(
 					OC_Calendar_App::$l10n->t(
 						'You do not have the permissions to add events to this calendar.'
@@ -170,9 +167,9 @@ class OC_Calendar_Object{
 		$object = OC_VObject::parse($data);
 		list($type,$startdate,$enddate,$summary,$repeating,$uid) = self::extractData($object);
 
-		$stmt = OCP\DB::prepare( 'INSERT INTO `*PREFIX*calendar_objects` (`calendarid`,`objecttype`,`startdate`,`enddate`,`repeating`,`summary`,`calendardata`,`uri`,`lastmodified`) VALUES(?,?,?,?,?,?,?,?,?)' );
+		$stmt = OCP\DB::prepare( 'INSERT INTO `*PREFIX*clndr_objects` (`calendarid`,`objecttype`,`startdate`,`enddate`,`repeating`,`summary`,`calendardata`,`uri`,`lastmodified`) VALUES(?,?,?,?,?,?,?,?,?)' );
 		$stmt->execute(array($id,$type,$startdate,$enddate,$repeating,$summary,$data,$uri,time()));
-		$object_id = OCP\DB::insertid('*PREFIX*calendar_objects');
+		$object_id = OCP\DB::insertid('*PREFIX*clndr_objects');
 
 		OC_Calendar_Calendar::touchCalendar($id);
 		OCP\Util::emitHook('OC_Calendar', 'addEvent', $object_id);
@@ -187,11 +184,14 @@ class OC_Calendar_Object{
 	 */
 	public static function edit($id, $data) {
 		$oldobject = self::find($id);
-
-		$calendar = OC_Calendar_Calendar::find($oldobject['calendarid']);
+		$calid = self::getCalendarid($id);
+		
+		$calendar = OC_Calendar_Calendar::find($calid);
+		$oldvobject = OC_VObject::parse($oldobject['calendardata']);
 		if ($calendar['userid'] != OCP\User::getUser()) {
-			$sharedCalendar = OCP\Share::getItemSharedWithBySource('calendar', $oldobject['calendarid']);
-			if (!$sharedCalendar || !($sharedCalendar['permissions'] & OCP\Share::PERMISSION_UPDATE)) {
+			$sharedCalendar = OCP\Share::getItemSharedWithBySource('calendar', $calid); //calid, not objectid !!!! 1111 one one one eleven
+			$sharedAccessClassPermissions = OC_Calendar_Object::getAccessClassPermissions($oldvobject);
+			if (!$sharedCalendar || !($sharedCalendar['permissions'] & OCP\PERMISSION_UPDATE) || !($sharedAccessClassPermissions & OCP\PERMISSION_UPDATE)) {
 				throw new Exception(
 					OC_Calendar_App::$l10n->t(
 						'You do not have the permissions to edit this event.'
@@ -200,10 +200,10 @@ class OC_Calendar_Object{
 			}
 		}
 		$object = OC_VObject::parse($data);
-		OC_Calendar_App::loadCategoriesFromVCalendar($object);
+		OC_Calendar_App::loadCategoriesFromVCalendar($id, $object);
 		list($type,$startdate,$enddate,$summary,$repeating,$uid) = self::extractData($object);
 
-		$stmt = OCP\DB::prepare( 'UPDATE `*PREFIX*calendar_objects` SET `objecttype`=?,`startdate`=?,`enddate`=?,`repeating`=?,`summary`=?,`calendardata`=?,`lastmodified`= ? WHERE `id` = ?' );
+		$stmt = OCP\DB::prepare( 'UPDATE `*PREFIX*clndr_objects` SET `objecttype`=?,`startdate`=?,`enddate`=?,`repeating`=?,`summary`=?,`calendardata`=?,`lastmodified`= ? WHERE `id` = ?' );
 		$stmt->execute(array($type,$startdate,$enddate,$repeating,$summary,$data,time(),$id));
 
 		OC_Calendar_Calendar::touchCalendar($oldobject['calendarid']);
@@ -223,9 +223,11 @@ class OC_Calendar_Object{
 		$oldobject = self::findWhereDAVDataIs($cid,$uri);
 
 		$calendar = OC_Calendar_Calendar::find($cid);
+		$oldvobject = OC_VObject::parse($oldobject['calendardata']);
 		if ($calendar['userid'] != OCP\User::getUser()) {
 			$sharedCalendar = OCP\Share::getItemSharedWithBySource('calendar', $cid);
-			if (!$sharedCalendar || !($sharedCalendar['permissions'] & OCP\Share::PERMISSION_UPDATE)) {
+			$sharedAccessClassPermissions = OC_Calendar_Object::getAccessClassPermissions($oldvobject);
+			if (!$sharedCalendar || !($sharedCalendar['permissions'] & OCP\PERMISSION_UPDATE) || !($sharedAccessClassPermissions & OCP\PERMISSION_UPDATE)) {
 				throw new Sabre_DAV_Exception_Forbidden(
 					OC_Calendar_App::$l10n->t(
 						'You do not have the permissions to edit this event.'
@@ -236,7 +238,7 @@ class OC_Calendar_Object{
 		$object = OC_VObject::parse($data);
 		list($type,$startdate,$enddate,$summary,$repeating,$uid) = self::extractData($object);
 
-		$stmt = OCP\DB::prepare( 'UPDATE `*PREFIX*calendar_objects` SET `objecttype`=?,`startdate`=?,`enddate`=?,`repeating`=?,`summary`=?,`calendardata`=?,`lastmodified`= ? WHERE `id` = ?' );
+		$stmt = OCP\DB::prepare( 'UPDATE `*PREFIX*clndr_objects` SET `objecttype`=?,`startdate`=?,`enddate`=?,`repeating`=?,`summary`=?,`calendardata`=?,`lastmodified`= ? WHERE `id` = ?' );
 		$stmt->execute(array($type,$startdate,$enddate,$repeating,$summary,$data,time(),$oldobject['id']));
 
 		OC_Calendar_Calendar::touchCalendar($oldobject['calendarid']);
@@ -252,10 +254,14 @@ class OC_Calendar_Object{
 	 */
 	public static function delete($id) {
 		$oldobject = self::find($id);
-		$calendar = OC_Calendar_Calendar::find($oldobject['calendarid']);
+		$calid = self::getCalendarid($id);
+		
+		$calendar = OC_Calendar_Calendar::find($calid);
+		$oldvobject = OC_VObject::parse($oldobject['calendardata']);
 		if ($calendar['userid'] != OCP\User::getUser()) {
-			$sharedCalendar = OCP\Share::getItemSharedWithBySource('calendar', $oldobject['calendarid']);
-			if (!$sharedCalendar || !($sharedCalendar['permissions'] & OCP\Share::PERMISSION_DELETE)) {
+			$sharedCalendar = OCP\Share::getItemSharedWithBySource('calendar',  $calid);
+			$sharedAccessClassPermissions = OC_Calendar_Object::getAccessClassPermissions($oldvobject);
+			if (!$sharedCalendar || !($sharedCalendar['permissions'] & OCP\PERMISSION_DELETE) || !($sharedAccessClassPermissions & OCP\PERMISSION_DELETE)) {
 				throw new Exception(
 					OC_Calendar_App::$l10n->t(
 						'You do not have the permissions to delete this event.'
@@ -263,7 +269,7 @@ class OC_Calendar_Object{
 				);
 			}
 		}
-		$stmt = OCP\DB::prepare( 'DELETE FROM `*PREFIX*calendar_objects` WHERE `id` = ?' );
+		$stmt = OCP\DB::prepare( 'DELETE FROM `*PREFIX*clndr_objects` WHERE `id` = ?' );
 		$stmt->execute(array($id));
 		OC_Calendar_Calendar::touchCalendar($oldobject['calendarid']);
 
@@ -271,6 +277,8 @@ class OC_Calendar_Object{
 
 		OCP\Util::emitHook('OC_Calendar', 'deleteEvent', $id);
 
+		OC_Calendar_App::getVCategories()->purgeObject($id);
+
 		return true;
 	}
 
@@ -285,7 +293,7 @@ class OC_Calendar_Object{
 		$calendar = OC_Calendar_Calendar::find($cid);
 		if ($calendar['userid'] != OCP\User::getUser()) {
 			$sharedCalendar = OCP\Share::getItemSharedWithBySource('calendar', $cid);
-			if (!$sharedCalendar || !($sharedCalendar['permissions'] & OCP\Share::PERMISSION_DELETE)) {
+			if (!$sharedCalendar || !($sharedCalendar['permissions'] & OCP\PERMISSION_DELETE)) {
 				throw new Sabre_DAV_Exception_Forbidden(
 					OC_Calendar_App::$l10n->t(
 						'You do not have the permissions to delete this event.'
@@ -293,7 +301,7 @@ class OC_Calendar_Object{
 				);
 			}
 		}
-		$stmt = OCP\DB::prepare( 'DELETE FROM `*PREFIX*calendar_objects` WHERE `calendarid`= ? AND `uri`=?' );
+		$stmt = OCP\DB::prepare( 'DELETE FROM `*PREFIX*clndr_objects` WHERE `calendarid`= ? AND `uri`=?' );
 		$stmt->execute(array($cid,$uri));
 		OC_Calendar_Calendar::touchCalendar($cid);
 		OCP\Util::emitHook('OC_Calendar', 'deleteEvent', $oldobject['id']);
@@ -305,7 +313,7 @@ class OC_Calendar_Object{
 		$calendar = OC_Calendar_Calendar::find($calendarid);
 		if ($calendar['userid'] != OCP\User::getUser()) {
 			$sharedCalendar = OCP\Share::getItemSharedWithBySource('calendar', $calendarid);
-			if (!$sharedCalendar || !($sharedCalendar['permissions'] & OCP\Share::PERMISSION_CREATE)) {
+			if (!$sharedCalendar || !($sharedCalendar['permissions'] & OCP\PERMISSION_DELETE)) {
 				throw new Exception(
 					OC_Calendar_App::$l10n->t(
 						'You do not have the permissions to add events to this calendar.'
@@ -313,10 +321,10 @@ class OC_Calendar_Object{
 				);
 			}
 		}
-		$stmt = OCP\DB::prepare( 'UPDATE `*PREFIX*calendar_objects` SET `calendarid`=? WHERE `id`=?' );
+		$stmt = OCP\DB::prepare( 'UPDATE `*PREFIX*clndr_objects` SET `calendarid`=? WHERE `id`=?' );
 		$stmt->execute(array($calendarid,$id));
 
-		OC_Calendar_Calendar::touchCalendar($id);
+		OC_Calendar_Calendar::touchCalendar($calendarid);
 		OCP\Util::emitHook('OC_Calendar', 'moveEvent', $id);
 
 		return true;
@@ -447,6 +455,87 @@ class OC_Calendar_Object{
 		return $dtend;
 	}
 
+	/**
+	 * @brief Remove all properties which should not be exported for the AccessClass Confidential
+	 * @param string $id Event ID
+	 * @param Sabre_VObject $vobject Sabre VObject
+	 * @return object
+	 */
+	public static function cleanByAccessClass($id, $vobject) {
+
+		// Do not clean your own calendar
+		if(OC_Calendar_Object::getowner($id) === OCP\USER::getUser()) {
+			return $vobject;
+		}
+
+		if(isset($vobject->VEVENT)) {
+			$velement = $vobject->VEVENT;
+		}
+		elseif(isset($vobject->VJOURNAL)) {
+			$velement = $vobject->VJOURNAL;
+		}
+		elseif(isset($vobject->VTODO)) {
+			$velement = $vobject->VTODO;
+		}
+
+		if(isset($velement->CLASS) && $velement->CLASS->value == 'CONFIDENTIAL') {
+			foreach ($velement->children as &$property) {
+				switch($property->name) {
+					case 'CREATED':
+					case 'DTSTART':
+					case 'RRULE':
+					case 'DURATION':
+					case 'DTEND':
+					case 'CLASS':
+					case 'UID':
+						break;
+					case 'SUMMARY':
+						$property->value = OC_Calendar_App::$l10n->t('Busy');
+						break;
+					default:
+						$velement->__unset($property->name);
+						unset($property);
+						break;
+				}
+			}
+		}
+		return $vobject;
+	}
+
+	/**
+	 * @brief Get the permissions determined by the access class of an event/todo/journal
+	 * @param Sabre_VObject $vobject Sabre VObject
+	 * @return (int) $permissions - CRUDS permissions
+	 * @see OCP\Share
+	 */
+	public static function getAccessClassPermissions($vobject) {
+		if(isset($vobject->VEVENT)) {
+			$velement = $vobject->VEVENT;
+		}
+		elseif(isset($vobject->VJOURNAL)) {
+			$velement = $vobject->VJOURNAL;
+		}
+		elseif(isset($vobject->VTODO)) {
+			$velement = $vobject->VTODO;
+		}
+
+		$accessclass = $velement->getAsString('CLASS');
+
+		return OC_Calendar_App::getAccessClassPermissions($accessclass);
+	}
+
+	/**
+	 * @brief returns the options for the access class of an event
+	 * @return array - valid inputs for the access class of an event
+	 */
+	public static function getAccessClassOptions($l10n) {
+		return array(
+			'PUBLIC'       => (string)$l10n->t('Public'),
+			'PRIVATE'      => (string)$l10n->t('Private'),
+			'CONFIDENTIAL' => (string)$l10n->t('Confidential')
+		);
+	}
+
 	/**
 	 * @brief returns the options for the repeat rule of an repeating event
 	 * @return array - valid inputs for the repeat rule of an repeating event
@@ -764,7 +853,7 @@ class OC_Calendar_Object{
 		$vevent = new OC_VObject('VEVENT');
 		$vcalendar->add($vevent);
 
-		$vevent->setDateTime('CREATED', 'now', Sabre_VObject_Property_DateTime::UTC);
+		$vevent->setDateTime('CREATED', 'now', Sabre\VObject\Property\DateTime::UTC);
 
 		$vevent->setUID();
 		return self::updateVCalendarFromRequest($request, $vcalendar);
@@ -777,6 +866,7 @@ class OC_Calendar_Object{
 	 * @return object updated $vcalendar
 	 */
 	public static function updateVCalendarFromRequest($request, $vcalendar) {
+		$accessclass = $request["accessclass"];
 		$title = $request["title"];
 		$location = $request["location"];
 		$categories = $request["categories"];
@@ -933,25 +1023,28 @@ class OC_Calendar_Object{
 		}
 
 
-		$vevent->setDateTime('LAST-MODIFIED', 'now', Sabre_VObject_Property_DateTime::UTC);
-		$vevent->setDateTime('DTSTAMP', 'now', Sabre_VObject_Property_DateTime::UTC);
+		$vevent->setDateTime('LAST-MODIFIED', 'now', Sabre\VObject\Property\DateTime::UTC);
+		$vevent->setDateTime('DTSTAMP', 'now', Sabre\VObject\Property\DateTime::UTC);
 		$vevent->setString('SUMMARY', $title);
 
 		if($allday) {
 			$start = new DateTime($from);
 			$end = new DateTime($to.' +1 day');
-			$vevent->setDateTime('DTSTART', $start, Sabre_VObject_Property_DateTime::DATE);
-			$vevent->setDateTime('DTEND', $end, Sabre_VObject_Property_DateTime::DATE);
+			$vevent->setDateTime('DTSTART', $start, Sabre\VObject\Property\DateTime::DATE);
+			$vevent->setDateTime('DTEND', $end, Sabre\VObject\Property\DateTime::DATE);
 		}else{
 			$timezone = OC_Calendar_App::getTimezone();
 			$timezone = new DateTimeZone($timezone);
 			$start = new DateTime($from.' '.$fromtime, $timezone);
+			$start->setTimezone(new DateTimeZone('UTC'));
 			$end = new DateTime($to.' '.$totime, $timezone);
-			$vevent->setDateTime('DTSTART', $start, Sabre_VObject_Property_DateTime::LOCALTZ);
-			$vevent->setDateTime('DTEND', $end, Sabre_VObject_Property_DateTime::LOCALTZ);
+			$end->setTimezone(new DateTimeZone('UTC'));
+			$vevent->setDateTime('DTSTART', $start, Sabre\VObject\Property\DateTime::UTC);
+			$vevent->setDateTime('DTEND', $end, Sabre\VObject\Property\DateTime::UTC);
 		}
 		unset($vevent->DURATION);
 
+		$vevent->setString('CLASS', $accessclass);
 		$vevent->setString('LOCATION', $location);
 		$vevent->setString('DESCRIPTION', $description);
 		$vevent->setString('CATEGORIES', $categories);
@@ -971,7 +1064,14 @@ class OC_Calendar_Object{
 	public static function getowner($id) {
 		$event = self::find($id);
 		$cal = OC_Calendar_Calendar::find($event['calendarid']);
-		return $cal['userid'];
+		if($cal === false || is_array($cal) === false){
+			return null;
+		}
+		if(array_key_exists('userid', $cal)){
+			return $cal['userid'];
+		}else{
+			return null;
+		}
 	}
 
 	/**
