@@ -2,24 +2,24 @@
 "Error (de)activating addressbook." => "Σφάλμα (απ)ενεργοποίησης βιβλίου διευθύνσεων",
 "id is not set." => "δεν ορίστηκε id",
 "Cannot update addressbook with an empty name." => "Δε μπορεί να γίνει αλλαγή βιβλίου διευθύνσεων χωρίς όνομα",
+"No category name given." => "Δεν δόθηκε όνομα κατηγορίας.",
+"Error adding group." => "Σφάλμα κατά την προσθήκη ομάδας.",
+"Group ID missing from request." => "Το ID ομάδας λείπει από το αίτημα.",
+"Contact ID missing from request." => "Το ID επαφής λείπει από το αίτημα.",
 "No ID provided" => "Δε δόθηκε ID",
 "Error setting checksum." => "Λάθος κατά τον ορισμό checksum ",
 "No categories selected for deletion." => "Δε επελέγησαν κατηγορίες για διαγραφή",
 "No address books found." => "Δε βρέθηκε βιβλίο διευθύνσεων",
 "No contacts found." => "Δεν βρέθηκαν επαφές",
 "element name is not set." => "δεν ορίστηκε όνομα στοιχείου",
-"Could not parse contact: " => "Δε αναγνώστηκε η επαφή",
-"Cannot add empty property." => "Αδύνατη προσθήκη κενής ιδιότητας.",
-"At least one of the address fields has to be filled out." => "Πρέπει να συμπληρωθεί τουλάχιστον ένα από τα παιδία διεύθυνσης.",
-"Trying to add duplicate property: " => "Προσπάθεια προσθήκης διπλότυπης ιδιότητας:",
-"Missing IM parameter." => "Λείπει IM παράμετρος.",
-"Unknown IM: " => "Άγνωστο IM:",
-"Information about vCard is incorrect. Please reload the page." => "Οι πληροφορίες σχετικά με vCard είναι εσφαλμένες. Παρακαλώ επαναφορτώστε τη σελίδα.",
-"Missing ID" => "Λείπει ID",
-"Error parsing VCard for ID: \"" => "Σφάλμα κατά την ανάγνωση του VCard για το ID:\"",
 "checksum is not set." => "δε ορίστηκε checksum ",
+"Information about vCard is incorrect. Please reload the page." => "Οι πληροφορίες σχετικά με vCard είναι εσφαλμένες. Παρακαλώ επαναφορτώστε τη σελίδα.",
+"Couldn't find vCard for %d." => "Δεν βρέθηκε vCard για %d.",
 "Information about vCard is incorrect. Please reload the page: " => "Οι πληροφορίες για τη vCard είναι λανθασμένες.Παρακαλώ ξαναφορτώστε τη σελίδα: ",
 "Something went FUBAR. " => "Κάτι χάθηκε στο άγνωστο. ",
+"Cannot save property of type \"%s\" as array" => "Αδυναμία αποθήκευσης  ιδιότητας του τύπου \"%s\" ως σειρά",
+"Missing IM parameter." => "Λείπει IM παράμετρος.",
+"Unknown IM: " => "Άγνωστο IM:",
 "No contact ID was submitted." => "Δε υπεβλήθει ID επαφής",
 "Error reading contact photo." => "Σφάλμα ανάγνωσης εικόνας επαφής",
 "Error saving temporary file." => "Σφάλμα αποθήκευσης προσωρινού αρχείου",
@@ -35,6 +35,9 @@
 "Error cropping image" => "Σφάλμα κατά την περικοπή εικόνας",
 "Error creating temporary image" => "Σφάλμα κατά την δημιουργία προσωρινής εικόνας",
 "Error finding image: " => "Σφάλμα κατά την εύρεση της εικόνας: ",
+"Key is not set for: " => "Δεν έχει ορισθεί πλήκτρο για το:",
+"Value is not set for: " => "Δεν έχει ορισθεί τιμή για το:",
+"Could not set preference: " => "Αδυναμία ορισμού προτίμησης:",
 "Error uploading contacts to storage." => "Σφάλμα κατά την αποθήκευση επαφών",
 "There is no error, the file uploaded with success" => "Δεν υπάρχει σφάλμα, το αρχείο ανέβηκε με επιτυχία ",
 "The uploaded file exceeds the upload_max_filesize directive in php.ini" => "Το μέγεθος του αρχείου ξεπερνάει το upload_max_filesize του php.ini",
@@ -46,43 +49,54 @@
 "Couldn't load temporary image: " => "Δεν ήταν δυνατή η φόρτωση της προσωρινής εικόνας: ",
 "No file was uploaded. Unknown error" => "Δεν ανέβηκε κάποιο αρχείο. Άγνωστο σφάλμα",
 "Contacts" => "Επαφές",
-"Sorry, this functionality has not been implemented yet" => "Λυπούμαστε, αυτή η λειτουργία δεν έχει υλοποιηθεί ακόμα",
-"Not implemented" => "Δεν έχει υλοποιηθεί",
-"Couldn't get a valid address." => "Αδυναμία λήψης έγκυρης διεύθυνσης",
-"Error" => "Σφάλμα",
-"Please enter an email address." => "Παρακαλώ εισάγεται μια διεύθυνση ηλ. ταχυδρομείου",
-"Enter name" => "Εισαγωγή ονόματος",
-"Format custom, Short name, Full name, Reverse or Reverse with comma" => "Format custom, Όνομα, Επώνυμο, Αντίστροφο ή Αντίστροφο με κόμμα",
-"Select type" => "Επιλογή τύπου",
+"%d_selected_contacts" => "%d_επιλεγμένες_επαφές",
+"Add to..." => "Προσθήκη στο...",
+"Remove from..." => "Αφαίρεση από το...",
+"Add group..." => "Προσθήκη ομάδας...",
+"Indexing contacts" => "Εύρεση επαφών ",
 "Select photo" => "Επέλεξε φωτογραφία",
-"You do not have permission to add contacts to " => "Δεν έχετε επαρκή δικαιώματα για προσθέσετε επαφές στο ",
-"Please select one of your own address books." => "Παρακαλούμε επιλέξτε ένα από τα δικάς σας βιβλία διευθύνσεων.",
-"Permission error" => "Σφάλμα δικαιωμάτων",
-"Click to undo deletion of \"" => "Επιλογή για αναίρεση της διαγραφής του \"",
-"Cancelled deletion of: \"" => "Ακύρωση διαγραφής του: \"",
-"This property has to be non-empty." => "Το πεδίο δεν πρέπει να είναι άδειο.",
-"Couldn't serialize elements." => "Αδύνατο να μπουν σε σειρά τα στοιχεία",
-"Unknown error. Please check logs." => "Άγνωστο σφάλμα.Παρακαλώ έλεγξε το αρχείο καταγραφής.",
-"'deleteProperty' called without type argument. Please report at bugs.owncloud.org" => "το 'deleteProperty' καλέστηκε χωρίς  without type argument. Παρακαλώ αναφέρατε στο bugs.owncloud.org",
-"Edit name" => "Αλλαγή ονόματος",
-"No files selected for upload." => "Δεν επιλέχτηκαν αρχεία για μεταφόρτωση",
-"The file you are trying to upload exceed the maximum size for file uploads on this server." => "Το αρχείο που προσπαθείτε να ανεβάσετε υπερβαίνει το μέγιστο μέγεθος για τις προσθήκες αρχείων σε αυτόν τον server.",
-"Error loading profile picture." => "Σφάλμα στην φόρτωση εικόνας προφίλ.",
-"Some contacts are marked for deletion, but not deleted yet. Please wait for them to be deleted." => "Κάποιες επαφές σημειώθηκαν προς διαγραφή,δεν έχουν διαγραφεί ακόμα. Παρακαλώ περιμένετε μέχρι να διαγραφούν.",
-"Do you want to merge these address books?" => "Επιθυμείτε να συγχωνεύσετε αυτά τα δύο βιβλία διευθύνσεων?",
-"Shared by " => "Μοιράστηκε από",
-"Upload too large" => "Πολύ μεγάλο αρχείο για μεταφόρτωση",
-"Only image files can be used as profile picture." => "Μόνο αρχεία εικόνας μπορούν να χρησιμοποιηθούν σαν εικόνα προφίλ.",
-"Wrong file type" => "Λάθος τύπος αρχείου",
-"Your browser doesn't support AJAX upload. Please click on the profile picture to select a photo to upload." => "Ο περιηγητής σας δεν υποστηρίζει μεταφόρτωση σε AJAX. Παρακαλώ κάντε κλικ πάνω στην εικόνα προφίλ για να επιλέξετε μια φωτογραφία για να την ανεβάσετε.",
-"Unable to upload your file as it is a directory or has 0 bytes" => "Αδυναμία μεταφόρτωσης του αρχείου σας διότι είναι κατάλογος ή έχει μέγεθος 0 bytes",
-"Upload Error" => "Σφάλμα Μεταφόρτωσης",
-"Pending" => "Εκκρεμεί",
-"Import done" => "Η εισαγωγή ολοκληρώθηκε",
+"Network or server error. Please inform administrator." => "Σφάλμα δικτύου ή διακομιστή. Παρακαλώ ενημερώστε το διαχειριστή.",
+"Error adding to group." => "Σφάλμα κατά την προσθήκη σε ομάδα.",
+"Error removing from group." => "Σφάλμα κατά την αφαίρεση από ομάδα.",
+"There was an error opening a mail composer." => "Υπήρχε ένα σφάλμα στο άνοιγμα μίας σύνθεσης μηνύματος.",
+"Deleting done. Click here to cancel reloading." => "Η διαγραφή ολοκληρώθηκε. Κλικ εδώ για να ακυρώσετε την επαναφόρτωση.",
+"Add address book" => "Προσθήκη βιβλίου διευθύνσεων",
+"Import done. Click here to cancel reloading." => "Η εισαγωγή ολοκληρώθηκε. Κλικ εδώ για να ακυρώσετε την επαναφόρτωση.",
 "Not all files uploaded. Retrying..." => "Δεν μεταφορτώθηκαν όλα τα αρχεία. Προσπάθεια ξανά...",
 "Something went wrong with the upload, please retry." => "Κάτι πήγε στραβά με την μεταφόρτωση, παρακαλώ προσπαθήστε ξανά.",
+"Error" => "Σφάλμα",
+"Importing from {filename}..." => "Εισαγωγή από {filename}...",
+"{success} imported, {failed} failed." => "{success} έγινε εισαγωγή, {failed} απέτυχε.",
 "Importing..." => "Γίνεται εισαγωγή...",
+"Unable to upload your file as it is a directory or has 0 bytes" => "Αδυναμία στην αποστολή του αρχείου σας αφού είναι φάκελος ή έχει 0 bytes",
+"Upload Error" => "Σφάλμα Αποστολής",
+"The file you are trying to upload exceed the maximum size for file uploads on this server." => "Το αρχείο που προσπαθείτε να ανεβάσετε υπερβαίνει το μέγιστο μέγεθος για τις προσθήκες αρχείων σε αυτόν τον server.",
+"Upload too large" => "Πολύ μεγάλο αρχείο προς αποστολή",
+"Pending" => "Εκκρεμεί",
+"Add group" => "Προσθήκη ομάδας",
+"No files selected for upload." => "Δεν επιλέχτηκαν αρχεία για μεταφόρτωση",
+"Edit profile picture" => "Επεξεργασία εικόνας προφίλ",
+"Error loading profile picture." => "Σφάλμα στην φόρτωση εικόνας προφίλ.",
+"Enter name" => "Εισαγωγή ονόματος",
+"Enter description" => "Εισαγωγή περιγραφής",
+"Select addressbook" => "Επιλογή βιβλίου επαφών",
 "The address book name cannot be empty." => "Το όνομα του βιβλίου διευθύνσεων δεν πρέπει να είναι κενό.",
+"Is this correct?" => "Είναι σωστό;",
+"There was an unknown error when trying to delete this contact" => "Παρουσιάστηκε άγνωστο σφάλμα κατά τη διαγραφή αυτής της επαφής",
+"# groups" => "# ομάδες",
+"Some contacts are marked for deletion, but not deleted yet. Please wait for them to be deleted." => "Κάποιες επαφές σημειώθηκαν προς διαγραφή,δεν έχουν διαγραφεί ακόμα. Παρακαλώ περιμένετε μέχρι να διαγραφούν.",
+"Click to undo deletion of {num} contacts" => "Κλικ για να αναιρέσετε τη διαγραφή {num} επαφών",
+"Cancelled deletion of {num}" => "Αναιρέθηκε η διαγραφή {num}",
+"Contact is already in this group." => "Η επαφή είναι ήδη σε αυτήν την ομάδα.",
+"Contacts are already in this group." => "Οι επαφές είναι ήδη σε αυτήν την ομάδα.",
+"Couldn't get contact list." => "Αδυναμία λήψης λίστας επαφών.",
+"Contact is not in this group." => "Η επαφή δεν είναι σε αυτή την ομάδα",
+"Contacts are not in this group." => "Οι επαφές δεν είναι σε αυτή την ομάδα.",
+"A group named {group} already exists" => "Υπάρχει ήδη μια ομάδα με όνομα {group}",
+"You can drag groups to\narrange them as you like." => "Μπορείτε να σύρετε τις ομάδες για να⏎τις τακτοποιήσετε όπως θέλετε.",
+"All" => "Όλες",
+"Favorites" => "Αγαπημένες",
+"Shared by {owner}" => "Διαμοιράστηκε από τον {owner}",
 "Result: " => "Αποτέλεσμα: ",
 " imported, " => " εισάγεται,",
 " failed." => " απέτυχε.",
@@ -100,9 +114,6 @@
 "There was an error updating the addressbook." => "Υπήρξε σφάλμα κατά την ενημέρωση του βιβλίου διευθύνσεων.",
 "You do not have the permissions to delete this addressbook." => "Δεν έχετε δικαιώματα να διαγράψετε αυτό το βιβλίο διευθύνσεων.",
 "There was an error deleting this addressbook." => "Υπήρξε σφάλμα κατά την διαγραφή αυτού του βιβλίου διευθύνσεων",
-"Addressbook not found: " => "Το βιβλίο διευθύνσεων δεν βρέθηκε:",
-"This is not your addressbook." => "Αυτό δεν είναι το βιβλίο διευθύνσεων σας.",
-"Contact could not be found." => "Η επαφή δεν μπόρεσε να βρεθεί.",
 "Jabber" => "Jabber",
 "AIM" => "AIM",
 "MSN" => "MSN",
@@ -126,19 +137,9 @@
 "Video" => "Βίντεο",
 "Pager" => "Βομβητής",
 "Internet" => "Διαδίκτυο",
-"Birthday" => "Γενέθλια",
-"Business" => "Επιχείρηση",
-"Call" => "Κάλεσε",
-"Clients" => "Πελάτες",
-"Deliverer" => "Προμηθευτής",
-"Holidays" => "Διακοπές",
-"Ideas" => "Ιδέες",
-"Journey" => "Ταξίδι",
-"Jubilee" => "Ιωβηλαίο",
-"Meeting" => "Συνάντηση",
-"Personal" => "Προσωπικό",
-"Projects" => "Έργα",
-"Questions" => "Ερωτήσεις",
+"Friends" => "Φίλοι",
+"Family" => "Οικογένεια",
+"There was an error deleting properties for this contact." => "Παρουσιάστηκε σφάλμα κατά τη διαγραφή των ιδιοτήτων αυτής της επαφής.",
 "{name}'s Birthday" => "Τα Γεννέθλια του/της {name}",
 "Contact" => "Επαφή",
 "You do not have the permissions to add contacts to this addressbook." => "Δεν έχετε δικαιώματα να προσθέσετε επαφές σε αυτό το βιβλίο διευθύνσεων.",
@@ -148,9 +149,22 @@
 "Could not find the Addressbook with ID: " => "Αδυναμία εύρεσης της Βιβλίου Διευθύνσεων με το ID:",
 "You do not have the permissions to delete this contact." => "Δεν διαθέτε επαρκή δικαιώματα για την διαγραφή αυτής της επαφής.",
 "There was an error deleting this contact." => "Υπήρξε σφάλμα κατά την διαγραφή αυτής της επαφής.",
-"Add Contact" => "Προσθήκη επαφής",
-"Import" => "Εισαγωγή",
+"Contact not found." => "Δεν βρέθηκε επαφή.",
+"HomePage" => "Αρχική Σελίδα",
+"New Group" => "Νέα Ομάδα",
 "Settings" => "Ρυθμίσεις",
+"Address books" => "Βιβλία διευθύνσεων",
+"Import" => "Εισαγωγή",
+"Select files to import" => "Επιλογή αρχείων για εισαγωγή",
+"Select files" => "Επιλογή αρχείων",
+"Import into:" => "Εισαγωγή από:",
+"OK" => "ΟΚ",
+"(De-)select all" => "(Απο-)επιλογή όλων",
+"New Contact" => "Νέα επαφή",
+"Download Contact(s)" => "Λήψη Επαφής(-ών)",
+"Groups" => "Ομάδες",
+"Favorite" => "Αγαπημένο",
+"Delete Contact" => "Διαγραφή επαφής",
 "Close" => "Κλείσιμο  ",
 "Keyboard shortcuts" => "Συντομεύσεις πλητρολογίου",
 "Navigation" => "Πλοήγηση",
@@ -164,91 +178,67 @@
 "Add new contact" => "Προσθήκη νέας επαφής",
 "Add new addressbook" => "Προσθήκη νέου βιβλίου επαφών",
 "Delete current contact" => "Διαγραφή τρέχουσας επαφής",
-"Drop photo to upload" => "Ρίξε μια φωτογραφία για ανέβασμα",
+"<h3>You have no contacts in your addressbook.</h3><p>Add a new contact or import existing contacts from a VCF file.</p>" => "<h3>Δεν έχετε επαφές στο βιβλίο διευθύνσεων.</h3><p>Προσθέστε μία νέα επαφή ή εισάγετε τις υπάρχουσες επαφές σας από ένα αρχείο VCF.</p>",
+"Add contact" => "Προσθήκη επαφής",
+"Compose mail" => "Σύνθεση μηνύματος",
+"Delete group" => "Διαγραφή ομάδας",
 "Delete current photo" => "Διαγραφή τρέχουσας φωτογραφίας",
 "Edit current photo" => "Επεξεργασία τρέχουσας φωτογραφίας",
 "Upload new photo" => "Ανέβασε νέα φωτογραφία",
 "Select photo from ownCloud" => "Επέλεξε φωτογραφία από το ownCloud",
-"Edit name details" => "Αλλάξτε τις λεπτομέρειες ονόματος",
-"Organization" => "Οργανισμός",
+"First name" => "Όνομα",
+"Additional names" => "Επιπλέον ονόματα",
+"Last name" => "Επώνυμο",
+"Select groups" => "Επιλέξτε ομάδες",
 "Nickname" => "Παρατσούκλι",
 "Enter nickname" => "Εισάγετε παρατσούκλι",
-"Web site" => "Ιστότοπος",
-"http://www.somesite.com" => "http://www.somesite.com",
-"Go to web site" => "Πήγαινε στον ιστότοπο",
-"dd-mm-yyyy" => "ΗΗ-ΜΜ-ΕΕΕΕ",
-"Groups" => "Ομάδες",
-"Separate groups with commas" => "Διαχώρισε τις ομάδες με κόμμα ",
-"Edit groups" => "Επεξεργασία ομάδων",
-"Preferred" => "Προτιμώμενο",
-"Please specify a valid email address." => "Παρακαλώ εισήγαγε μια έγκυρη διεύθυνση ηλεκτρονικού ταχυδρομείου",
-"Enter email address" => "Εισήγαγε  διεύθυνση ηλεκτρονικού ταχυδρομείου",
-"Mail to address" => "Αποστολή σε διεύθυνση",
-"Delete email address" => "Διαγραφή διεύθυνση email",
-"Enter phone number" => "Εισήγαγε αριθμό τηλεφώνου",
-"Delete phone number" => "Διέγραψε αριθμό τηλεφώνου",
-"Instant Messenger" => "Instant Messenger",
-"Delete IM" => "Διαγραφή IM",
-"View on map" => "Προβολή στο χάρτη",
-"Edit address details" => "Επεξεργασία λεπτομερειών διεύθυνσης",
-"Add notes here." => "Πρόσθεσε τις σημειώσεις εδώ",
-"Add field" => "Προσθήκη πεδίου",
+"Title" => "Τίτλος",
+"Enter title" => "Εισάγετε τίτλο",
+"Organization" => "Οργανισμός",
+"Enter organization" => "Εισάγετε οργάνωση",
+"Birthday" => "Γενέθλια",
+"Notes go here..." => "Σημειώσεις...",
+"Export as VCF" => "Εξαγωγή ως VCF",
+"Add" => "Προσθήκη",
 "Phone" => "Τηλέφωνο",
 "Email" => "Email",
 "Instant Messaging" => "Άμεσα μυνήματα",
 "Address" => "Διεύθυνση",
 "Note" => "Σημείωση",
-"Download contact" => "Λήψη επαφής",
+"Web site" => "Ιστότοπος",
 "Delete contact" => "Διαγραφή επαφής",
-"The temporary image has been removed from cache." => "Η προσωρινή εικόνα αφαιρέθηκε από την κρυφή μνήμη.",
-"Edit address" => "Επεξεργασία διεύθυνσης",
-"Type" => "Τύπος",
-"PO Box" => "Ταχ. Θυρίδα",
+"Preferred" => "Προτιμώμενο",
+"Please specify a valid email address." => "Παρακαλώ εισήγαγε μια έγκυρη διεύθυνση ηλεκτρονικού ταχυδρομείου",
+"someone@example.com" => "someone@example.com",
+"Mail to address" => "Αποστολή σε διεύθυνση",
+"Delete email address" => "Διαγραφή διεύθυνση email",
+"Enter phone number" => "Εισήγαγε αριθμό τηλεφώνου",
+"Delete phone number" => "Διέγραψε αριθμό τηλεφώνου",
+"Go to web site" => "Πήγαινε στον ιστότοπο",
+"Delete URL" => "Διαγραφή URL",
+"View on map" => "Προβολή στο χάρτη",
+"Delete address" => "Διαγραφή διεύθυνσης",
+"1 Main Street" => "Κεντρική Οδός  αρ.1",
 "Street address" => "Διεύθυνση οδού",
-"Street and number" => "Οδός και αριθμός",
-"Extended" => "Εκτεταμένη",
-"Apartment number etc." => "Αριθμός διαμερίσματος",
-"City" => "Πόλη",
-"Region" => "Περιοχή",
-"E.g. state or province" => "Π.χ. Πολιτεία ή επαρχεία",
-"Zipcode" => "Τ.Κ.",
+"12345" => "12345",
 "Postal code" => "Ταχυδρομικός Κωδικός",
+"Your city" => "Η πόλη σας",
+"City" => "Πόλη",
+"Some region" => "Κάποια περιοχή",
+"State or province" => "Πολιτεία ή επαρχία",
+"Your country" => "Η χώρα σας",
 "Country" => "Χώρα",
-"Addressbook" => "Βιβλίο διευθύνσεων",
-"Hon. prefixes" => "προθέματα",
-"Miss" => "Δις",
-"Ms" => "Κα",
-"Mr" => "Κα",
-"Sir" => "Σερ",
-"Mrs" => "Κα",
-"Dr" => "Δρ.",
-"Given name" => "Όνομα",
-"Additional names" => "Επιπλέον ονόματα",
-"Family name" => "Επώνυμο",
-"Hon. suffixes" => "καταλήξεις",
-"J.D." => "J.D.",
-"M.D." => "M.D.",
-"D.O." => "D.O.",
-"D.C." => "D.C.",
-"Ph.D." => "Ph.D.",
-"Esq." => "Esq.",
-"Jr." => "Jr.",
-"Sn." => "Sn.",
-"Import a contacts file" => "Εισαγωγή αρχείου επαφών",
-"Please choose the addressbook" => "Παρακαλώ επέλεξε βιβλίο διευθύνσεων",
-"create a new addressbook" => "Δημιουργία νέου βιβλίου διευθύνσεων",
-"Name of new addressbook" => "Όνομα νέου βιβλίου διευθύνσεων",
-"Importing contacts" => "Εισαγωγή επαφών",
-"<h3>You have no contacts in your addressbook.</h3><p>You can import VCF files by dragging them to the contacts list and either drop them on an addressbook to import into it, or on an empty spot to create a new addressbook and import into that.<br />You can also import by clicking on the import button at the bottom of the list.</p>" => "<h3>Δεν έχετε επαφές στο βιβλίο διευθύνσεων.</h3><p>Μπορείτε να εισάγετε αρχεία VCF σύροντάς τα στην λίστα επαφών και είτε αφήνοντάς τα στο βιβλίο διευθύνσεων ώστε να εισαχθούν σε αυτό, είτε σε κάποιο κενό σημείο ώστε να δημιουργηθεί νέο βιβλίο διευθύνσεων και να εισαχθούν σε αυτό.<br />Μπορείτε επίσης να τα εισάγετε κάνοντας κλικ στο κουμπί εισαγωγής στο κάτω μέρος της λίστας.</p>",
-"Add contact" => "Προσθήκη επαφής",
-"Select Address Books" => "Επέλεξε βιβλίο διευθύνσεων",
-"Enter description" => "Εισαγωγή περιγραφής",
+"Instant Messenger" => "Instant Messenger",
+"Delete IM" => "Διαγραφή IM",
+"Share" => "Μοιράσου",
+"Export" => "Εξαγωγή",
+"CardDAV link" => "Σύνδεσμος CardDAV",
+"The temporary image has been removed from cache." => "Η προσωρινή εικόνα αφαιρέθηκε από την κρυφή μνήμη.",
 "CardDAV syncing addresses" => "συγχρονισμός διευθύνσεων μέσω CardDAV ",
 "more info" => "περισσότερες πληροφορίες",
 "Primary address (Kontact et al)" => "Κύρια διεύθυνση",
 "iOS/OS X" => "iOS/OS X",
 "Addressbooks" => "Βιβλία διευθύνσεων",
-"Share" => "Μοιράσου",
 "New Address Book" => "Νέο βιβλίο διευθύνσεων",
 "Name" => "Όνομα",
 "Description" => "Περιγραφή",
