@@ -8,13 +8,8 @@
 "No address books found." => "هیچ کتابچه نشانی پیدا نشد",
 "No contacts found." => "هیچ شخصی پیدا نشد",
 "element name is not set." => "نام اصلی تنظیم نشده است",
-"Cannot add empty property." => "نمیتوان یک  خاصیت خالی ایجاد کرد",
-"At least one of the address fields has to be filled out." => "At least one of the address fields has to be filled out. ",
-"Trying to add duplicate property: " => "امتحان کردن برای وارد کردن مشخصات تکراری",
-"Information about vCard is incorrect. Please reload the page." => "اطلاعات درمورد vCard شما اشتباه است لطفا صفحه را دوباره بار گذاری کنید",
-"Missing ID" => "نشانی گم شده",
-"Error parsing VCard for ID: \"" => "خطا در تجزیه کارت ویزا برای شناسه:",
 "checksum is not set." => "checksum تنظیم شده نیست",
+"Information about vCard is incorrect. Please reload the page." => "اطلاعات درمورد vCard شما اشتباه است لطفا صفحه را دوباره بار گذاری کنید",
 "Information about vCard is incorrect. Please reload the page: " => "اطلاعات کارت ویزا شما غلط است لطفا صفحه را دوباره بارگزاری کنید",
 "Something went FUBAR. " => "چند چیز به FUBAR رفتند",
 "No contact ID was submitted." => "هیچ اطلاعاتی راجع به شناسه ارسال نشده",
@@ -43,29 +38,25 @@
 "Couldn't load temporary image: " => "قابلیت بارگذاری تصویر  موقت وجود ندارد:",
 "No file was uploaded. Unknown error" => "هیچ فایلی آپلود نشد.خطای ناشناس",
 "Contacts" => "اشخاص",
-"Sorry, this functionality has not been implemented yet" => "با عرض پوزش،این قابلیت هنوز اجرا نشده است",
-"Not implemented" => "انجام نشد",
-"Couldn't get a valid address." => "Couldn't get a valid address.",
+"Select photo" => "تصویر را انتخاب کنید",
 "Error" => "خطا",
-"Format custom, Short name, Full name, Reverse or Reverse with comma" => "Format custom, Short name, Full name, Reverse or Reverse with comma",
-"Select type" => "نوع را انتخاب کنید",
-"This property has to be non-empty." => "این ویژگی باید به صورت غیر تهی عمل کند",
-"Couldn't serialize elements." => "قابلیت مرتب سازی عناصر وجود ندارد",
-"'deleteProperty' called without type argument. Please report at bugs.owncloud.org" => "پاک کردن ویژگی بدون استدلال انجام شده.لطفا این مورد را گزارش دهید:bugs.owncloud.org",
-"Edit name" => "نام تغییر",
-"No files selected for upload." => "هیچ فایلی برای آپلود انتخاب نشده است",
+"Unable to upload your file as it is a directory or has 0 bytes" => "ناتوان در بارگذاری یا فایل یک پوشه است یا 0بایت دارد",
+"Upload Error" => "خطا در بار گذاری",
 "The file you are trying to upload exceed the maximum size for file uploads on this server." => "حجم فایل بسیار بیشتر از حجم تنظیم شده در تنظیمات سرور است",
+"Upload too large" => "سایز فایل برای آپلود زیاد است(م.تنظیمات در php.ini)",
+"Pending" => "در انتظار",
+"No files selected for upload." => "هیچ فایلی برای آپلود انتخاب نشده است",
 "Result: " => "نتیجه:",
 " imported, " => "وارد شد،",
 " failed." => "ناموفق",
+"Displayname cannot be empty." => "اسم نمایشی نمی تواند خالی باشد",
 "Download" => "بارگیری",
 "Edit" => "ویرایش",
 "Delete" => "پاک کردن",
 "Cancel" => "انصراف",
-"This is not your addressbook." => "این کتابچه ی نشانه های شما نیست",
-"Contact could not be found." => "اتصال ویا تماسی یافت نشد",
 "Work" => "کار",
 "Home" => "خانه",
+"Other" => "دیگر",
 "Mobile" => "موبایل",
 "Text" => "متن",
 "Voice" => "صدا",
@@ -74,82 +65,48 @@
 "Video" => "رسانه تصویری",
 "Pager" => "صفحه",
 "Internet" => "اینترنت",
-"Birthday" => "روزتولد",
 "{name}'s Birthday" => "روز تولد {name} است",
 "Contact" => "اشخاص",
-"Add Contact" => "افزودن اطلاعات شخص مورد نظر",
+"Settings" => "تنظیمات",
 "Import" => "وارد کردن",
+"OK" => "باشه",
+"Groups" => "گروه ها",
 "Close" => "بستن",
-"Drop photo to upload" => "تصویر را به اینجا بکشید تا بار گذازی شود",
+"Add contact" => "افزودن اطلاعات شخص مورد نظر",
 "Delete current photo" => "پاک کردن تصویر کنونی",
 "Edit current photo" => "ویرایش تصویر کنونی",
 "Upload new photo" => "بار گذاری یک تصویر جدید",
 "Select photo from ownCloud" => "انتخاب یک تصویر از ابر های شما",
-"Edit name details" => "ویرایش نام جزئیات",
-"Organization" => "نهاد(ارگان)",
+"Additional names" => "نام های دیگر",
 "Nickname" => "نام مستعار",
 "Enter nickname" => "یک نام مستعار وارد کنید",
-"dd-mm-yyyy" => "dd-mm-yyyy",
-"Groups" => "گروه ها",
-"Separate groups with commas" => "جدا کردن گروه ها به وسیله درنگ نما",
-"Edit groups" => "ویرایش گروه ها",
+"Title" => "عنوان",
+"Organization" => "نهاد(ارگان)",
+"Birthday" => "روزتولد",
+"Add" => "افزودن",
+"Phone" => "شماره تلفن",
+"Email" => "نشانی پست الکترنیک",
+"Address" => "نشانی",
+"Note" => "یادداشت",
+"Delete contact" => "پاک کردن  اطلاعات شخص مورد نظر",
 "Preferred" => "مقدم",
 "Please specify a valid email address." => "لطفا یک پست الکترونیکی معتبر وارد کنید",
-"Enter email address" => "یک  پست الکترونیکی وارد کنید",
 "Mail to address" => "به نشانی  ارسال شد",
 "Delete email address" => "پاک کردن نشانی پست الکترونیکی",
 "Enter phone number" => "شماره تلفن راوارد کنید",
 "Delete phone number" => "پاک کردن شماره تلفن",
 "View on map" => "دیدن روی نقشه",
-"Edit address details" => "ویرایش جزئیات نشانی ها",
-"Add notes here." => "اینجا یادداشت ها را بیافزایید",
-"Add field" => "اضافه کردن فیلد",
-"Phone" => "شماره تلفن",
-"Email" => "نشانی پست الکترنیک",
-"Address" => "نشانی",
-"Note" => "یادداشت",
-"Download contact" => "دانلود مشخصات اشخاص",
-"Delete contact" => "پاک کردن  اطلاعات شخص مورد نظر",
-"The temporary image has been removed from cache." => "تصویر موقت از کش پاک شد.",
-"Edit address" => "ویرایش نشانی",
-"Type" => "نوع",
-"PO Box" => "صندوق پستی",
-"Extended" => "تمدید شده",
 "City" => "شهر",
-"Region" => "ناحیه",
-"Zipcode" => "کد پستی",
 "Country" => "کشور",
-"Addressbook" => "کتابچه ی نشانی ها",
-"Hon. prefixes" => "پیشوند های محترمانه",
-"Miss" => "خانم",
-"Ms" => "خانم",
-"Mr" => "آقا",
-"Sir" => "آقا",
-"Mrs" => "خانم",
-"Dr" => "دکتر",
-"Given name" => "نام معلوم",
-"Additional names" => "نام های دیگر",
-"Family name" => "نام خانوادگی",
-"Hon. suffixes" => "پسوند های محترم",
-"J.D." => "J.D.",
-"M.D." => "M.D.",
-"D.O." => "D.O.",
-"D.C." => "D.C.",
-"Ph.D." => "دکتری",
-"Esq." => "Esq.",
-"Jr." => "Jr.",
-"Sn." => "Sn.",
-"Import a contacts file" => "وارد کردن پرونده حاوی اطلاعات",
-"Please choose the addressbook" => "لطفا یک کتابچه نشانی انتخاب کنید",
-"create a new addressbook" => "یک کتابچه نشانی بسازید",
-"Name of new addressbook" => "نام کتابچه نشانی جدید",
-"Importing contacts" => "وارد کردن اشخاص",
-"Add contact" => "افزودن اطلاعات شخص مورد نظر",
+"Share" => "اشتراک‌گزاری",
+"Export" => "خروجی گرفتن",
+"The temporary image has been removed from cache." => "تصویر موقت از کش پاک شد.",
 "CardDAV syncing addresses" => "CardDAV syncing addresses ",
 "more info" => "اطلاعات بیشتر",
 "Primary address (Kontact et al)" => "نشانی اولیه",
 "iOS/OS X" => "iOS/OS X ",
 "Addressbooks" => "کتابچه ی نشانی ها",
 "New Address Book" => "کتابچه نشانه های جدید",
+"Name" => "نام",
 "Save" => "ذخیره سازی"
 );
