@@ -2,24 +2,24 @@
 "Error (de)activating addressbook." => "アドレス帳の有効／無効化に失敗しました。",
 "id is not set." => "idが設定されていません。",
 "Cannot update addressbook with an empty name." => "空白の名前でアドレス帳を更新することはできません。",
+"No category name given." => "カテゴリ名が指定されていません。",
+"Error adding group." => "グループの追加エラー。",
+"Group ID missing from request." => "リクエストにはグループIDがありません。",
+"Contact ID missing from request." => "リクエストには連絡先IDがありません。",
 "No ID provided" => "IDが提供されていません",
 "Error setting checksum." => "チェックサムの設定エラー。",
 "No categories selected for deletion." => "削除するカテゴリが選択されていません。",
 "No address books found." => "アドレス帳が見つかりません。",
 "No contacts found." => "連絡先が見つかりません。",
 "element name is not set." => "要素名が設定されていません。",
-"Could not parse contact: " => "連絡先を解析できませんでした:",
-"Cannot add empty property." => "項目の新規追加に失敗しました。",
-"At least one of the address fields has to be filled out." => "住所の項目のうち１つは入力して下さい。",
-"Trying to add duplicate property: " => "重複する属性を追加: ",
-"Missing IM parameter." => "IMのパラメータが不足しています。",
-"Unknown IM: " => "不明なIM:",
-"Information about vCard is incorrect. Please reload the page." => "vCardの情報に誤りがあります。ページをリロードして下さい。",
-"Missing ID" => "IDが見つかりません",
-"Error parsing VCard for ID: \"" => "VCardからIDの抽出エラー: \"",
 "checksum is not set." => "チェックサムが設定されていません。",
+"Information about vCard is incorrect. Please reload the page." => "vCardの情報に誤りがあります。ページをリロードして下さい。",
+"Couldn't find vCard for %d." => "%d のvCardが見つかりませんでした。",
 "Information about vCard is incorrect. Please reload the page: " => "vCardの情報が正しくありません。ページを再読み込みしてください: ",
 "Something went FUBAR. " => "何かがFUBARへ移動しました。",
+"Cannot save property of type \"%s\" as array" => "\"%s\" タイプのプロパティを配列として保存できません",
+"Missing IM parameter." => "IMのパラメータが不足しています。",
+"Unknown IM: " => "不明なIM:",
 "No contact ID was submitted." => "連絡先IDは登録されませんでした。",
 "Error reading contact photo." => "連絡先写真の読み込みエラー。",
 "Error saving temporary file." => "一時ファイルの保存エラー。",
@@ -35,6 +35,9 @@
 "Error cropping image" => "画像の切り抜きエラー",
 "Error creating temporary image" => "一時画像の生成エラー",
 "Error finding image: " => "画像検索エラー: ",
+"Key is not set for: " => "キーが未設定:",
+"Value is not set for: " => "値が未設定:",
+"Could not set preference: " => "優先度を設定出来ません: ",
 "Error uploading contacts to storage." => "ストレージへの連絡先のアップロードエラー。",
 "There is no error, the file uploaded with success" => "エラーはありません。ファイルのアップロードは成功しました",
 "The uploaded file exceeds the upload_max_filesize directive in php.ini" => "アップロードファイルは php.ini 内の upload_max_filesize の制限を超えています",
@@ -46,43 +49,54 @@
 "Couldn't load temporary image: " => "一時的な画像の読み込みができませんでした: ",
 "No file was uploaded. Unknown error" => "ファイルは何もアップロードされていません。不明なエラー",
 "Contacts" => "連絡先",
-"Sorry, this functionality has not been implemented yet" => "申し訳ありません。この機能はまだ実装されていません",
-"Not implemented" => "未実装",
-"Couldn't get a valid address." => "有効なアドレスを取得できませんでした。",
-"Error" => "エラー",
-"Please enter an email address." => "メールアドレスを入力してください。",
-"Enter name" => "名前を入力",
-"Format custom, Short name, Full name, Reverse or Reverse with comma" => "編集フォーマット、ショートネーム、フルネーム、逆順、カンマ区切りの逆順",
-"Select type" => "タイプを選択",
+"%d_selected_contacts" => "%d個の選択された連絡先",
+"Add to..." => "追加...",
+"Remove from..." => "削除...",
+"Add group..." => "グループを追加...",
+"Indexing contacts" => "連絡先のインデックスを作成中",
 "Select photo" => "写真を選択",
-"You do not have permission to add contacts to " => "連絡先を追加する権限がありません",
-"Please select one of your own address books." => "アドレス帳を一つ選択してください",
-"Permission error" => "権限エラー",
-"Click to undo deletion of \"" => "削除の取り消すためにクリックしてください: \"",
-"Cancelled deletion of: \"" => "キャンセルされた削除: \"",
-"This property has to be non-empty." => "この属性は空にできません。",
-"Couldn't serialize elements." => "要素をシリアライズできませんでした。",
-"Unknown error. Please check logs." => "不明なエラーです。ログを確認して下さい。",
-"'deleteProperty' called without type argument. Please report at bugs.owncloud.org" => "'deleteProperty' は型の引数無しで呼び出されました。bugs.owncloud.org へ報告してください。",
-"Edit name" => "名前を編集",
-"No files selected for upload." => "アップロードするファイルが選択されていません。",
-"The file you are trying to upload exceed the maximum size for file uploads on this server." => "アップロードしようとしているファイルは、このサーバの最大ファイルアップロードサイズを超えています。",
-"Error loading profile picture." => "プロファイルの画像の読み込みエラー",
-"Some contacts are marked for deletion, but not deleted yet. Please wait for them to be deleted." => "いくつかの連絡先が削除とマークされていますが、まだ削除されていません。削除するまでお待ちください。",
-"Do you want to merge these address books?" => "これらのアドレス帳をマージしてもよろしいですか？",
-"Shared by " => "共有",
-"Upload too large" => "アップロードには大きすぎます。",
-"Only image files can be used as profile picture." => "画像ファイルのみがプロファイル写真として使用することができます。",
-"Wrong file type" => "誤ったファイルタイプ",
-"Your browser doesn't support AJAX upload. Please click on the profile picture to select a photo to upload." => "あなたのブラウザはAJAXのアップロードをサポートしていません。プロファイル写真をクリックしてアップロードする写真を選択してください。",
-"Unable to upload your file as it is a directory or has 0 bytes" => "ディレクトリや0バイトのファイルはアップロードできません。",
-"Upload Error" => "アップロードエラー",
-"Pending" => "中断",
-"Import done" => "インポート完了",
+"Network or server error. Please inform administrator." => "ネットワークもしくはサーバエラーです。管理者に連絡してください。",
+"Error adding to group." => "グループに追加エラー。",
+"Error removing from group." => "グループから削除エラー。",
+"There was an error opening a mail composer." => "メールコンポーザの起動エラーが発生しました。",
+"Deleting done. Click here to cancel reloading." => "削除完了。再読込みをキャンセルする場合はここをクリック。",
+"Add address book" => "アドレスブックを追加",
+"Import done. Click here to cancel reloading." => "インポート完了。再読込みをキャンセルする場合はここをクリック。",
 "Not all files uploaded. Retrying..." => "ファイルがアップロード出来ませんでした。再実行中...。",
 "Something went wrong with the upload, please retry." => "アップロード中に不具合が発生しました、再実行してください。",
+"Error" => "エラー",
+"Importing from {filename}..." => "{filename} からインポート中...",
+"{success} imported, {failed} failed." => "{success} をインポート､{failed} は失敗しました。",
 "Importing..." => "インポート中...",
+"Unable to upload your file as it is a directory or has 0 bytes" => "ディレクトリもしくは0バイトのファイルはアップロードできません",
+"Upload Error" => "アップロードエラー",
+"The file you are trying to upload exceed the maximum size for file uploads on this server." => "アップロードしようとしているファイルは、このサーバの最大ファイルアップロードサイズを超えています。",
+"Upload too large" => "アップロードには大きすぎます。",
+"Pending" => "中断",
+"Add group" => "グループを追加",
+"No files selected for upload." => "アップロードするファイルが選択されていません。",
+"Edit profile picture" => "プロフィール写真を編集",
+"Error loading profile picture." => "プロファイルの画像の読み込みエラー",
+"Enter name" => "名前を入力",
+"Enter description" => "説明を入力してください",
+"Select addressbook" => "アドレスブックを選択",
 "The address book name cannot be empty." => "アドレス帳名は空に出来ません。",
+"Is this correct?" => "これは正しいですか？",
+"There was an unknown error when trying to delete this contact" => "この連絡先の削除時に不明なエラーが発生しました",
+"# groups" => "グループ数",
+"Some contacts are marked for deletion, but not deleted yet. Please wait for them to be deleted." => "いくつかの連絡先が削除対象としてマークされていますが、まだ削除されていません。削除するまでお待ちください。",
+"Click to undo deletion of {num} contacts" => "{num} 個の連絡先の削除を元に戻す",
+"Cancelled deletion of {num}" => "{num} 個の削除をキャンセルしました",
+"Contact is already in this group." => "連絡先はすでにこのグループに存在します。",
+"Contacts are already in this group." => "連絡先はすでにこのグループに存在します。",
+"Couldn't get contact list." => "連絡先リストを取得できませんでした。",
+"Contact is not in this group." => "連絡先はこのグループに存在しません。",
+"Contacts are not in this group." => "連絡先はこのグループに存在しません。",
+"A group named {group} already exists" => "{group} のグループはすでに存在します",
+"You can drag groups to\narrange them as you like." => "グループをドラックすることで好きな\nように並べ替えることができます。",
+"All" => "すべて",
+"Favorites" => "お気に入り",
+"Shared by {owner}" => "{owner} と共有中",
 "Result: " => "結果: ",
 " imported, " => " をインポート、 ",
 " failed." => " は失敗しました。",
@@ -96,13 +110,10 @@
 "More..." => "もっと...",
 "Less..." => "簡略...",
 "You do not have the permissions to read this addressbook." => "このアドレス帳を見る権限がありません。",
-"You do not have the permissions to update this addressbook." => "アドレスブックを更新する権限がありません",
-"There was an error updating the addressbook." => "アドレスブックを更新中にエラーが発生しました。",
+"You do not have the permissions to update this addressbook." => "アドレス帳を更新する権限がありません",
+"There was an error updating the addressbook." => "アドレス帳を更新中にエラーが発生しました。",
 "You do not have the permissions to delete this addressbook." => "アドレス帳を削除する権限がありません。",
 "There was an error deleting this addressbook." => "アドレス帳を削除するときにエラーが発生しました。",
-"Addressbook not found: " => "アドレス帳が見つかりません:",
-"This is not your addressbook." => "これはあなたの電話帳ではありません。",
-"Contact could not be found." => "連絡先を見つける事ができません。",
 "Jabber" => "Jabber",
 "AIM" => "AIM",
 "MSN" => "MSN",
@@ -126,19 +137,9 @@
 "Video" => "テレビ電話",
 "Pager" => "ポケベル",
 "Internet" => "インターネット",
-"Birthday" => "誕生日",
-"Business" => "ビジネス",
-"Call" => "電話",
-"Clients" => "顧客",
-"Deliverer" => "運送会社",
-"Holidays" => "休日",
-"Ideas" => "アイデア",
-"Journey" => "旅行",
-"Jubilee" => "記念祭",
-"Meeting" => "打ち合わせ",
-"Personal" => "個人",
-"Projects" => "プロジェクト",
-"Questions" => "質問",
+"Friends" => "友達",
+"Family" => "家族",
+"There was an error deleting properties for this contact." => "この連絡先のプロパティの削除エラーが発生しました。",
 "{name}'s Birthday" => "{name}の誕生日",
 "Contact" => "連絡先",
 "You do not have the permissions to add contacts to this addressbook." => "アドレスブックに連絡先を追加する権限がありません",
@@ -148,9 +149,22 @@
 "Could not find the Addressbook with ID: " => "そのIDのアドレス帳が見つかりませんでした：",
 "You do not have the permissions to delete this contact." => "この連絡先を削除する権限がありません",
 "There was an error deleting this contact." => "連絡先を削除するときにエラーが発生しました。",
-"Add Contact" => "連絡先の追加",
-"Import" => "インポート",
+"Contact not found." => "連絡先が見つかりません。",
+"HomePage" => "ホームページ",
+"New Group" => "新しいグループ",
 "Settings" => "設定",
+"Address books" => "アドレスブック",
+"Import" => "インポート",
+"Select files to import" => "インポートするファイルを選択",
+"Select files" => "ファイルを選択",
+"Import into:" => "インポート情報:",
+"OK" => "OK",
+"(De-)select all" => "すべての選択を解除",
+"New Contact" => "新しい連絡先",
+"Download Contact(s)" => "連絡先をダウンロード",
+"Groups" => "グループ",
+"Favorite" => "お気に入り",
+"Delete Contact" => "連絡先を削除",
 "Close" => "閉じる",
 "Keyboard shortcuts" => "キーボードショートカット",
 "Navigation" => "ナビゲーション",
@@ -164,91 +178,67 @@
 "Add new contact" => "新しい連絡先を追加",
 "Add new addressbook" => "新しいアドレス帳を追加",
 "Delete current contact" => "現在の連絡先を削除",
-"Drop photo to upload" => "写真をドロップしてアップロード",
+"<h3>You have no contacts in your addressbook.</h3><p>Add a new contact or import existing contacts from a VCF file.</p>" => "<h3>アドレスブックに連絡先がありません。</h3><p>新しい連絡先を追加、もしくは既存の連絡先をVCFファイルからインポートしてください。</p>",
+"Add contact" => "連絡先を追加",
+"Compose mail" => "メールを作成",
+"Delete group" => "グループを削除",
 "Delete current photo" => "現在の写真を削除",
 "Edit current photo" => "現在の写真を編集",
 "Upload new photo" => "新しい写真をアップロード",
 "Select photo from ownCloud" => "ownCloudから写真を選択",
-"Edit name details" => "名前の詳細を編集",
-"Organization" => "所属",
+"First name" => "名",
+"Additional names" => "ミドルネーム",
+"Last name" => "姓",
+"Select groups" => "グループを選択",
 "Nickname" => "ニックネーム",
 "Enter nickname" => "ニックネームを入力",
-"Web site" => "ウェブサイト",
-"http://www.somesite.com" => "http://www.somesite.com",
-"Go to web site" => "Webサイトへ移動",
-"dd-mm-yyyy" => "yyyy-mm-dd",
-"Groups" => "グループ",
-"Separate groups with commas" => "コンマでグループを分割",
-"Edit groups" => "グループを編集",
-"Preferred" => "推奨",
-"Please specify a valid email address." => "有効なメールアドレスを指定してください。",
-"Enter email address" => "メールアドレスを入力",
-"Mail to address" => "アドレスへメールを送る",
-"Delete email address" => "メールアドレスを削除",
-"Enter phone number" => "電話番号を入力",
-"Delete phone number" => "電話番号を削除",
-"Instant Messenger" => "インスタントメッセンジャー",
-"Delete IM" => "IMを削除",
-"View on map" => "地図で表示",
-"Edit address details" => "住所の詳細を編集",
-"Add notes here." => "ここにメモを追加。",
-"Add field" => "項目を追加",
+"Title" => "タイトル",
+"Enter title" => "タイトルを入力",
+"Organization" => "所属",
+"Enter organization" => "組織を入力",
+"Birthday" => "誕生日",
+"Notes go here..." => "メモはここに...",
+"Export as VCF" => "VCFとしてエクスポート",
+"Add" => "追加",
 "Phone" => "電話番号",
 "Email" => "メールアドレス",
 "Instant Messaging" => "インスタントメッセージ",
 "Address" => "住所",
 "Note" => "メモ",
-"Download contact" => "連絡先のダウンロード",
+"Web site" => "ウェブサイト",
 "Delete contact" => "連絡先の削除",
-"The temporary image has been removed from cache." => "一時画像はキャッシュから削除されました。",
-"Edit address" => "住所を編集",
-"Type" => "種類",
-"PO Box" => "私書箱",
+"Preferred" => "推奨",
+"Please specify a valid email address." => "有効なメールアドレスを指定してください。",
+"someone@example.com" => "someone@example.com",
+"Mail to address" => "アドレスへメールを送る",
+"Delete email address" => "メールアドレスを削除",
+"Enter phone number" => "電話番号を入力",
+"Delete phone number" => "電話番号を削除",
+"Go to web site" => "Webサイトへ移動",
+"Delete URL" => "URLを削除",
+"View on map" => "地図で表示",
+"Delete address" => "住所を削除",
+"1 Main Street" => "番地",
 "Street address" => "住所1",
-"Street and number" => "番地",
-"Extended" => "住所2",
-"Apartment number etc." => "アパート名等",
-"City" => "都市",
-"Region" => "都道府県",
-"E.g. state or province" => "例：東京都、大阪府",
-"Zipcode" => "郵便番号",
+"12345" => "12345",
 "Postal code" => "郵便番号",
+"Your city" => "市",
+"City" => "都市",
+"Some region" => "都道府県",
+"State or province" => "州／県",
+"Your country" => "国",
 "Country" => "国名",
-"Addressbook" => "アドレス帳",
-"Hon. prefixes" => "敬称",
-"Miss" => "Miss",
-"Ms" => "Ms",
-"Mr" => "Mr",
-"Sir" => "Sir",
-"Mrs" => "Mrs",
-"Dr" => "Dr",
-"Given name" => "名",
-"Additional names" => "ミドルネーム",
-"Family name" => "姓",
-"Hon. suffixes" => "称号",
-"J.D." => "J.D.",
-"M.D." => "M.D.",
-"D.O." => "D.O.",
-"D.C." => "D.C.",
-"Ph.D." => "Ph.D.",
-"Esq." => "Esq.",
-"Jr." => "Jr.",
-"Sn." => "Sn.",
-"Import a contacts file" => "連絡先ファイルをインポート",
-"Please choose the addressbook" => "アドレス帳を選択してください",
-"create a new addressbook" => "新しいアドレス帳を作成",
-"Name of new addressbook" => "新しいアドレスブックの名前",
-"Importing contacts" => "連絡先をインポート",
-"<h3>You have no contacts in your addressbook.</h3><p>You can import VCF files by dragging them to the contacts list and either drop them on an addressbook to import into it, or on an empty spot to create a new addressbook and import into that.<br />You can also import by clicking on the import button at the bottom of the list.</p>" => "<h3>アドレス帳に連絡先がありません。</h3><p>連絡リストにVCFファイルをドラッグするとインポートできます。もしくは、アドレス帳にドラッグしてもインポートできます。空いているところの場合は新しいアドレス帳が作成されインポートされます。<br />リストの一番下のインポートボタンをクリックしてもインポートできます。</p>",
-"Add contact" => "連絡先を追加",
-"Select Address Books" => "アドレス帳を選択してください",
-"Enter description" => "説明を入力してください",
+"Instant Messenger" => "インスタントメッセンジャー",
+"Delete IM" => "IMを削除",
+"Share" => "共有",
+"Export" => "エクスポート",
+"CardDAV link" => "CardDAVリンク",
+"The temporary image has been removed from cache." => "一時画像はキャッシュから削除されました。",
 "CardDAV syncing addresses" => "CardDAV同期アドレス",
 "more info" => "詳細情報",
 "Primary address (Kontact et al)" => "プライマリアドレス（Kontact 他）",
 "iOS/OS X" => "iOS/OS X",
 "Addressbooks" => "アドレス帳",
-"Share" => "共有",
 "New Address Book" => "新規のアドレス帳",
 "Name" => "名前",
 "Description" => "説明",
