@@ -3,14 +3,15 @@
 "id is not set." => "id er ikke satt.",
 "Cannot update addressbook with an empty name." => "Kan ikke oppdatere adressebøker uten navn.",
 "No ID provided" => "Ingen ID angitt",
+"Error setting checksum." => "Feil under skriving av sjekksum",
 "No categories selected for deletion." => "Ingen kategorier valgt for sletting.",
 "No address books found." => "Ingen adressebok funnet.",
 "No contacts found." => "Ingen kontakter funnet.",
-"Cannot add empty property." => "Kan ikke legge til tomt felt.",
-"At least one of the address fields has to be filled out." => "Minst en av adressefeltene må oppgis.",
+"element name is not set." => "navn på elementet er ikke satt.",
+"checksum is not set." => "sjekksumm er ikke satt.",
 "Information about vCard is incorrect. Please reload the page." => "Informasjonen om vCard-filen er ikke riktig. Last inn siden på nytt.",
-"Missing ID" => "Manglende ID",
 "Something went FUBAR. " => "Noe gikk fryktelig galt.",
+"No contact ID was submitted." => "Ingen kontakt ID ble gitt",
 "Error reading contact photo." => "Klarte ikke å lese kontaktbilde.",
 "Error saving temporary file." => "Klarte ikke å lagre midlertidig fil.",
 "The loading photo is not valid." => "Bildet som lastes inn er ikke gyldig.",
@@ -18,6 +19,8 @@
 "No photo path was submitted." => "Ingen filsti ble lagt inn.",
 "File doesn't exist:" => "Filen eksisterer ikke:",
 "Error loading image." => "Klarte ikke å laste bilde.",
+"Error getting contact object." => "Feil ved henting av kontakt objektet.",
+"Error getting PHOTO property." => "Feil ved henting av foto verdi.",
 "Error saving contact." => "Klarte ikke å lagre kontakt.",
 "Error resizing image" => "Klarte ikke å endre størrelse på bildet",
 "Error cropping image" => "Klarte ikke å beskjære bildet",
@@ -34,11 +37,16 @@
 "Couldn't load temporary image: " => "Kunne ikke laste midlertidig bilde:",
 "No file was uploaded. Unknown error" => "Ingen filer ble lastet opp. Ukjent feil.",
 "Contacts" => "Kontakter",
+"Select photo" => "Velg bilde",
 "Error" => "Feil",
-"Select type" => "Velg type",
-"Edit name" => "Endre navn",
-"No files selected for upload." => "Ingen filer valgt for opplasting.",
+"Importing..." => "Importerer...",
+"Unable to upload your file as it is a directory or has 0 bytes" => "Kan ikke laste opp filen din siden det er en mappe eller den har 0 bytes",
+"Upload Error" => "Opplasting feilet",
 "The file you are trying to upload exceed the maximum size for file uploads on this server." => "Filen du prøver å laste opp er for stor.",
+"Upload too large" => "Filen er for stor",
+"Pending" => "Ventende",
+"No files selected for upload." => "Ingen filer valgt for opplasting.",
+"Favorites" => "Favoritter",
 "Result: " => "Resultat:",
 " imported, " => "importert,",
 " failed." => "feilet.",
@@ -46,10 +54,25 @@
 "Edit" => "Rediger",
 "Delete" => "Slett",
 "Cancel" => "Avbryt",
-"This is not your addressbook." => "Dette er ikke dine adressebok.",
-"Contact could not be found." => "Kontakten ble ikke funnet.",
+"More..." => "Mer...",
+"Less..." => "Mindre...",
+"You do not have the permissions to delete this addressbook." => "Du har ikke tilgang til å slette denne adresseboken",
+"There was an error deleting this addressbook." => "Det oppstod en feil under sletting av denne adresseboken",
+"Jabber" => "Jabber",
+"AIM" => "AIM",
+"MSN" => "MSN",
+"Twitter" => "Twitter",
+"GoogleTalk" => "GoogleTalk",
+"Facebook" => "Facebook",
+"XMPP" => "XMPP",
+"ICQ" => "ICQ",
+"Yahoo" => "Yahoo",
+"Skype" => "Skype",
+"QQ" => "QQ",
+"GaduGadu" => "GaduGadu",
 "Work" => "Arbeid",
 "Home" => "Hjem",
+"Other" => "Annet",
 "Mobile" => "Mobil",
 "Text" => "Tekst",
 "Voice" => "Svarer",
@@ -58,74 +81,69 @@
 "Video" => "Video",
 "Pager" => "Pager",
 "Internet" => "Internett",
-"Birthday" => "Bursdag",
 "{name}'s Birthday" => "{name}s bursdag",
 "Contact" => "Kontakt",
-"Add Contact" => "Ny kontakt",
+"Could not find the vCard with ID." => "Kunne ikke finne vCard med denne IDen",
+"You do not have the permissions to edit this contact." => "Du har ikke tilgang til å endre denne kontakten.",
+"Could not find the vCard with ID: " => "Kunne ikke finne vCard med denne IDen:",
+"You do not have the permissions to delete this contact." => "Du har ikke tilgang til å slette denne kontakten.",
+"There was an error deleting this contact." => "Det oppstod en feil ved sletting av denne kontakten",
+"New Group" => "Ny gruppe",
+"Settings" => "Innstillinger",
 "Import" => "Importer",
+"Select files" => "Velg filer",
+"OK" => "OK",
+"New Contact" => "Ny kontakt",
+"Groups" => "Grupper",
+"Delete Contact" => "Slett kontakt",
 "Close" => "Lukk",
-"Drop photo to upload" => "Dra bilder hit for å laste opp",
+"Keyboard shortcuts" => "Tastatur snarveier",
+"Navigation" => "Navigasjon",
+"Next contact in list" => "Neste kontakt i listen",
+"Previous contact in list" => "Forrige kontakt i listen",
+"Expand/collapse current addressbook" => "Vis/skjul adresseboken",
+"Add new contact" => "Legg til ny kontakt",
+"Add new addressbook" => "Legg til ny adressebok",
+"Delete current contact" => "Slett kontakten",
+"Add contact" => "Ny kontakt",
 "Delete current photo" => "Fjern nåværende bilde",
 "Edit current photo" => "Rediger nåværende bilde",
 "Upload new photo" => "Last opp nytt bilde",
 "Select photo from ownCloud" => "Velg bilde fra ownCloud",
-"Edit name details" => "Endre detaljer rundt navn",
-"Organization" => "Organisasjon",
+"First name" => "Fornavn",
+"Additional names" => "Ev. mellomnavn",
+"Last name" => "Etternavn",
 "Nickname" => "Kallenavn",
 "Enter nickname" => "Skriv inn kallenavn",
-"dd-mm-yyyy" => "dd-mm-åååå",
-"Groups" => "Grupper",
-"Separate groups with commas" => "Skill gruppene med komma",
-"Edit groups" => "Endre grupper",
+"Title" => "Tittel",
+"Organization" => "Organisasjon",
+"Birthday" => "Bursdag",
+"Add" => "Legg til",
+"Phone" => "Telefon",
+"Email" => "E-post",
+"Address" => "Adresse",
+"Note" => "Notat",
+"Web site" => "Hjemmeside",
+"Delete contact" => "Slett kontakt",
 "Preferred" => "Foretrukket",
 "Please specify a valid email address." => "Vennligst angi en gyldig e-postadresse.",
-"Enter email address" => "Skriv inn e-postadresse",
 "Mail to address" => "Send e-post til adresse",
 "Delete email address" => "Fjern e-postadresse",
 "Enter phone number" => "Skriv inn telefonnummer",
 "Delete phone number" => "Fjern telefonnummer",
 "View on map" => "Se på kart",
-"Edit address details" => "Endre detaljer rundt adresse",
-"Add notes here." => "Legg inn notater her.",
-"Add field" => "Legg til felt",
-"Phone" => "Telefon",
-"Email" => "E-post",
-"Address" => "Adresse",
-"Note" => "Notat",
-"Download contact" => "Hend ned kontakten",
-"Delete contact" => "Slett kontakt",
-"The temporary image has been removed from cache." => "Det midlertidige bildet er fjernet fra cache.",
-"Edit address" => "Endre adresse",
-"Type" => "Type",
-"PO Box" => "Postboks",
-"Extended" => "Utvidet",
 "City" => "By",
-"Region" => "Området",
-"Zipcode" => "Postnummer",
 "Country" => "Land",
-"Addressbook" => "Adressebok",
-"Hon. prefixes" => "Ærestitler",
-"Miss" => "Frøken",
-"Mr" => "Herr",
-"Mrs" => "Fru",
-"Dr" => "Dr",
-"Given name" => "Fornavn",
-"Additional names" => "Ev. mellomnavn",
-"Family name" => "Etternavn",
-"Hon. suffixes" => "Titler",
-"Ph.D." => "Stipendiat",
-"Jr." => "Jr.",
-"Sn." => "Sr.",
-"Import a contacts file" => "Importer en fil med kontakter.",
-"Please choose the addressbook" => "Vennligst velg adressebok",
-"create a new addressbook" => "Lag ny adressebok",
-"Name of new addressbook" => "Navn på ny adressebok",
-"Importing contacts" => "Importerer kontakter",
-"Add contact" => "Ny kontakt",
+"Share" => "Del",
+"Export" => "Eksporter",
+"The temporary image has been removed from cache." => "Det midlertidige bildet er fjernet fra cache.",
 "CardDAV syncing addresses" => "Synkroniseringsadresse for CardDAV",
 "more info" => "mer info",
+"Primary address (Kontact et al)" => "Primær adresse (kontakt osv)",
 "iOS/OS X" => "iOS/OS X",
 "Addressbooks" => "Adressebøker",
 "New Address Book" => "Ny adressebok",
+"Name" => "Navn",
+"Description" => "Beskrivelse",
 "Save" => "Lagre"
 );
