@@ -2,87 +2,93 @@
 "Error (de)activating addressbook." => "(取消)激活地址簿错误。",
 "id is not set." => "没有设置 id。",
 "Cannot update addressbook with an empty name." => "无法使用一个空名称更新地址簿",
+"No category name given." => "未指定类别名称。",
+"Error adding group." => "添加分组错误。",
+"Group ID missing from request." => "请求缺少分组ID。",
+"Contact ID missing from request." => "请求缺少联系人ID。",
 "No ID provided" => "未提供 ID",
 "Error setting checksum." => "设置校验值错误。",
 "No categories selected for deletion." => "未选中要删除的分类。",
 "No address books found." => "找不到地址簿。",
 "No contacts found." => "找不到联系人。",
 "element name is not set." => "元素名称未设置",
-"Could not parse contact: " => "无法解析内容：",
-"Cannot add empty property." => "无法添加空属性。",
-"At least one of the address fields has to be filled out." => "至少需要填写一项地址。",
-"Trying to add duplicate property: " => "试图添加重复属性： ",
-"Missing IM parameter." => "缺少IM参数",
-"Unknown IM: " => "未知IM：",
-"Information about vCard is incorrect. Please reload the page." => "vCard 的信息不正确。请重新加载页面。",
-"Missing ID" => "缺少 ID",
-"Error parsing VCard for ID: \"" => "无法解析如下ID的 VCard：“",
 "checksum is not set." => "未设置校验值。",
+"Information about vCard is incorrect. Please reload the page." => "vCard 的信息不正确。请重新加载页面。",
 "Information about vCard is incorrect. Please reload the page: " => "vCard 信息不正确。请刷新页面: ",
 "Something went FUBAR. " => "有一些信息无法被处理。",
+"Missing IM parameter." => "缺少即时通讯IM参数",
+"Unknown IM: " => "未知即时通讯服务：",
 "No contact ID was submitted." => "未提交联系人 ID。",
-"Error reading contact photo." => "读取联系人照片错误。",
+"Error reading contact photo." => "读取联系人照片时错误。",
 "Error saving temporary file." => "保存临时文件错误。",
-"The loading photo is not valid." => "装入的照片不正确。",
+"The loading photo is not valid." => "载入的照片无效。",
 "Contact ID is missing." => "缺少联系人 ID。",
 "No photo path was submitted." => "未提供照片路径。",
 "File doesn't exist:" => "文件不存在:",
 "Error loading image." => "加载图片错误。",
-"Error getting contact object." => "获取联系人目标时出错。",
+"Error getting contact object." => "获取联系人对象时出错。",
 "Error getting PHOTO property." => "获取照片属性时出错。",
 "Error saving contact." => "保存联系人时出错。",
 "Error resizing image" => "缩放图像时出错",
 "Error cropping image" => "裁切图像时出错",
 "Error creating temporary image" => "创建临时图像时出错",
 "Error finding image: " => "查找图像时出错: ",
+"Could not set preference: " => "无法设定偏好：",
 "Error uploading contacts to storage." => "上传联系人到存储空间时出错",
 "There is no error, the file uploaded with success" => "文件上传成功，没有错误发生",
 "The uploaded file exceeds the upload_max_filesize directive in php.ini" => "上传的文件长度超出了 php.ini 中 upload_max_filesize 的限制",
 "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" => "上传的文件长度超出了 HTML 表单中 MAX_FILE_SIZE 的限制",
-"The uploaded file was only partially uploaded" => "已上传文件只上传了部分",
+"The uploaded file was only partially uploaded" => "已上传文件只上传了部分（不完整）",
 "No file was uploaded" => "没有文件被上传",
 "Missing a temporary folder" => "缺少临时目录",
 "Couldn't save temporary image: " => "无法保存临时图像: ",
 "Couldn't load temporary image: " => "无法加载临时图像: ",
 "No file was uploaded. Unknown error" => "没有文件被上传。未知错误",
 "Contacts" => "联系人",
-"Sorry, this functionality has not been implemented yet" => "抱歉，这个功能暂时还没有被实现",
-"Not implemented" => "未实现",
-"Couldn't get a valid address." => "无法获取一个合法的地址。",
-"Error" => "错误",
-"Please enter an email address." => "请输入电子邮件地址",
-"Enter name" => "输入姓名",
-"Format custom, Short name, Full name, Reverse or Reverse with comma" => "自定义格式，简称，全名，姓在前，姓在前并用逗号分割",
-"Select type" => "选择类型",
+"Add to..." => "添加到……",
+"Remove from..." => "从……删除",
+"Add group..." => "添加分组……",
+"Indexing contacts" => "正在索引联系人",
 "Select photo" => "选择图片",
-"You do not have permission to add contacts to " => "您没有权限添加联系人到",
-"Please select one of your own address books." => "请选择一个您的地址簿",
-"Permission error" => "权限错误",
-"Click to undo deletion of \"" => "撤销删除",
-"Cancelled deletion of: \"" => "已取消删除:",
-"This property has to be non-empty." => "这个属性必须是非空的",
-"Couldn't serialize elements." => "无法序列化元素",
-"Unknown error. Please check logs." => "未知错误。请检查日志",
-"'deleteProperty' called without type argument. Please report at bugs.owncloud.org" => "'deleteProperty' 调用时没有类型声明。请到 bugs.owncloud.org 汇报错误",
-"Edit name" => "编辑名称",
-"No files selected for upload." => "没有选择文件以上传",
-"The file you are trying to upload exceed the maximum size for file uploads on this server." => "您试图上传的文件超出了该服务器的最大文件限制",
-"Error loading profile picture." => "载入档案图片时出错",
-"Some contacts are marked for deletion, but not deleted yet. Please wait for them to be deleted." => "一些联系人已被标注为删除，但是尚未完成，请稍候。",
-"Do you want to merge these address books?" => "是否想合并这些地址簿？",
-"Shared by " => "共享人",
-"Upload too large" => "上传文件过大",
-"Only image files can be used as profile picture." => "只有图像文件才可用作头像",
-"Wrong file type" => "错误的文件类型",
-"Your browser doesn't support AJAX upload. Please click on the profile picture to select a photo to upload." => "您的浏览器不支持 AJAX 方式上传。请先点击头像再选择相片上传。",
+"Network or server error. Please inform administrator." => "网络或服务器错误。请通知管理员。",
+"Error adding to group." => "添加到组时出错。",
+"Error removing from group." => "从组删除时出错。",
+"There was an error opening a mail composer." => "打开邮件撰写器时出错。",
+"Deleting done. Click here to cancel reloading." => "删除完成。点击此处以取消重新载入。",
+"Add address book" => "添加地址簿",
+"Import done. Click here to cancel reloading." => "导入完毕。点击此处取消重载。",
+"Not all files uploaded. Retrying..." => "仍有文件未上传，重试中",
+"Something went wrong with the upload, please retry." => "上传中出现些问题，请重试。",
+"Error" => "错误",
+"Importing from {filename}..." => "正在导入 {文件名}...",
+"Importing..." => "导入中",
 "Unable to upload your file as it is a directory or has 0 bytes" => "无法上传您的文件，文件夹或者空文件",
 "Upload Error" => "上传错误",
+"The file you are trying to upload exceed the maximum size for file uploads on this server." => "您试图上传的文件超出了该服务器的最大文件限制",
+"Upload too large" => "上传文件过大",
 "Pending" => "等待",
-"Import done" => "导入完毕",
-"Not all files uploaded. Retrying..." => "仍有文件未上传，重试中",
-"Something went wrong with the upload, please retry." => "上传中出现些问题，正在重试哟。",
-"Importing..." => "导入中",
+"Add group" => "添加分组",
+"No files selected for upload." => "没有选择文件以上传",
+"Edit profile picture" => "编辑配置图片",
+"Error loading profile picture." => "载入档案图片时出错",
+"Enter name" => "输入姓名",
+"Enter description" => "输入描述",
+"Select addressbook" => "选择地址簿",
 "The address book name cannot be empty." => "地址簿名称不能为空",
+"Is this correct?" => "这正确吗？",
+"There was an unknown error when trying to delete this contact" => "尝试删除这个联系人时出现一个未知错误。",
+"Some contacts are marked for deletion, but not deleted yet. Please wait for them to be deleted." => "一些联系人已被标注为删除，但是尚未完成，请稍候。",
+"Click to undo deletion of {num} contacts" => "点击以撤销删除这{num}个联系人",
+"Contact is already in this group." => "联系人已经在这个组中。",
+"Contacts are already in this group." => "联系人都已经在这个组中。",
+"Couldn't get contact list." => "无法获取联系人列表。",
+"Contact is not in this group." => "联系人不在此分组中。",
+"Contacts are not in this group." => "联系人都没有在这个组中。",
+"A group named {group} already exists" => "分组{group}已存在。",
+"You can drag groups to\narrange them as you like." => "你可以拖拽群组以你喜欢的方式摆放他们。",
+"All" => "全部",
+"Favorites" => "收藏",
+"Shared by {owner}" => "共享人：{owner}",
 "Result: " => "结果: ",
 " imported, " => " 已导入， ",
 " failed." => " 失败。",
@@ -94,15 +100,12 @@
 "Delete" => "删除",
 "Cancel" => "取消",
 "More..." => "更多",
-"Less..." => "概要...",
+"Less..." => "更少...",
 "You do not have the permissions to read this addressbook." => "你没有权限查看地址簿",
-"You do not have the permissions to update this addressbook." => "你没有权限更新地址簿",
+"You do not have the permissions to update this addressbook." => "你没有权限更新此地址簿",
 "There was an error updating the addressbook." => "更新地址簿时出错",
 "You do not have the permissions to delete this addressbook." => "你没有权限编辑此地址簿",
 "There was an error deleting this addressbook." => "删除地址簿时出错",
-"Addressbook not found: " => "地址簿未找到",
-"This is not your addressbook." => "这不是您的地址簿。",
-"Contact could not be found." => "无法找到联系人。",
 "Jabber" => "Jabber",
 "AIM" => "AIM",
 "MSN" => "MSN",
@@ -118,7 +121,7 @@
 "Work" => "工作",
 "Home" => "家庭",
 "Other" => "其它",
-"Mobile" => "移动电话",
+"Mobile" => "手机",
 "Text" => "文本",
 "Voice" => "语音",
 "Message" => "消息",
@@ -126,37 +129,40 @@
 "Video" => "视频",
 "Pager" => "传呼机",
 "Internet" => "互联网",
-"Birthday" => "生日",
-"Business" => "商务",
-"Call" => "电话",
-"Clients" => "客户",
-"Deliverer" => "Deliverer",
-"Holidays" => "假期",
-"Ideas" => "创意",
-"Journey" => "旅行",
-"Jubilee" => "Jubilee",
-"Meeting" => "会议",
-"Personal" => "个人",
-"Projects" => "项目",
-"Questions" => "问题",
+"Friends" => "朋友",
+"Family" => "家庭",
+"There was an error deleting properties for this contact." => "删除这个联系人的属性时出现了一个错误。",
 "{name}'s Birthday" => "{name} 的生日",
 "Contact" => "联系人",
 "You do not have the permissions to add contacts to this addressbook." => "您没有权限增加联系人到此地址簿",
-"Could not find the vCard with ID." => "无法根据ID找到联系人。",
+"Could not find the vCard with ID." => "未能找到此 ID 的 vCard。",
 "You do not have the permissions to edit this contact." => "你没有权限编辑此联系人",
 "Could not find the vCard with ID: " => "无法找到联系人，根据ID：",
 "Could not find the Addressbook with ID: " => "无法找到地址簿，根据ID：",
 "You do not have the permissions to delete this contact." => "你没有权限删除此联系人",
 "There was an error deleting this contact." => "删除联系人时出错。",
-"Add Contact" => "添加联系人",
-"Import" => "导入",
+"Contact not found." => "找不到联系人。",
+"HomePage" => "主页",
+"New Group" => "新建分组",
 "Settings" => "设置",
+"Address books" => "地址簿",
+"Import" => "导入",
+"Select files to import" => "选择要导入的文件",
+"Select files" => "选择文件",
+"Import into:" => "导入至：",
+"OK" => "OK",
+"(De-)select all" => "反选全部",
+"New Contact" => "新建联系人",
+"Download Contact(s)" => "下载联系人",
+"Groups" => "分组",
+"Favorite" => "最爱",
+"Delete Contact" => "删除联系人",
 "Close" => "关闭",
 "Keyboard shortcuts" => "快捷键",
 "Navigation" => "导航",
 "Next contact in list" => "列表中的下一个联系人",
 "Previous contact in list" => "列表中的上一个联系人",
-"Expand/collapse current addressbook" => "展开、收起此地址簿",
+"Expand/collapse current addressbook" => "展开/收起此地址簿",
 "Next addressbook" => "下一个地址簿",
 "Previous addressbook" => "上一个地址簿",
 "Actions" => "地址",
@@ -164,91 +170,66 @@
 "Add new contact" => "新增联系人",
 "Add new addressbook" => "新增地址簿",
 "Delete current contact" => "删除当前联系人",
-"Drop photo to upload" => "拖拽图片进行上传",
+"<h3>You have no contacts in your addressbook.</h3><p>Add a new contact or import existing contacts from a VCF file.</p>" => "<h3>你的地址薄中没有联系人。</h3><p>添加一个新的联系人或者从VCF文件中导入。</p>",
+"Add contact" => "添加联系人",
+"Compose mail" => "编写邮件",
+"Delete group" => "删除分组",
 "Delete current photo" => "删除当前照片",
 "Edit current photo" => "编辑当前照片",
 "Upload new photo" => "上传新照片",
 "Select photo from ownCloud" => "从 ownCloud 选择照片",
-"Edit name details" => "编辑名称详情",
-"Organization" => "组织",
+"First name" => "名",
+"Additional names" => "其他名称",
+"Last name" => "姓",
+"Select groups" => "选择分组",
 "Nickname" => "昵称",
 "Enter nickname" => "输入昵称",
+"Title" => "标题",
+"Enter title" => "输入标题",
+"Organization" => "组织",
+"Enter organization" => "输入组织",
+"Birthday" => "生日",
+"Export as VCF" => "导出为 VCF",
+"Add" => "增加",
+"Phone" => "电话",
+"Email" => "电子邮件",
+"Instant Messaging" => "即时通讯",
+"Address" => "地址",
+"Note" => "注释",
 "Web site" => "网址",
-"http://www.somesite.com" => "http://www.wodewangzhan.com",
-"Go to web site" => "前往网站",
-"dd-mm-yyyy" => "yyyy-mm-dd",
-"Groups" => "分组",
-"Separate groups with commas" => "用逗号隔开分组",
-"Edit groups" => "编辑分组",
+"Delete contact" => "删除联系人",
 "Preferred" => "偏好",
 "Please specify a valid email address." => "请指定合法的电子邮件地址",
-"Enter email address" => "输入电子邮件地址",
+"someone@example.com" => "someone@example.com",
 "Mail to address" => "发送邮件到地址",
 "Delete email address" => "删除电子邮件地址",
 "Enter phone number" => "输入电话号码",
 "Delete phone number" => "删除电话号码",
-"Instant Messenger" => "即时聊天",
-"Delete IM" => "删除即时聊天工具",
+"Go to web site" => "访问网址",
+"Delete URL" => "删除ＵＲＬ",
 "View on map" => "在地图上显示",
-"Edit address details" => "编辑地址细节。",
-"Add notes here." => "添加注释。",
-"Add field" => "添加字段",
-"Phone" => "电话",
-"Email" => "电子邮件",
-"Instant Messaging" => "即时信息",
-"Address" => "地址",
-"Note" => "注释",
-"Download contact" => "下载联系人",
-"Delete contact" => "删除联系人",
-"The temporary image has been removed from cache." => "临时图像文件已从缓存中删除",
-"Edit address" => "编辑地址",
-"Type" => "类型",
-"PO Box" => "邮箱",
+"Delete address" => "删除地址",
+"1 Main Street" => "1 主街道",
 "Street address" => "街道地址",
-"Street and number" => "街道号码",
-"Extended" => "扩展",
-"Apartment number etc." => "公寓号码",
-"City" => "城市",
-"Region" => "地区",
-"E.g. state or province" => "例如州或省",
-"Zipcode" => "邮编",
+"12345" => "12345",
 "Postal code" => "邮政编码",
+"Your city" => "城市",
+"City" => "城市",
+"Some region" => "部分地区",
+"State or province" => "州/省",
+"Your country" => "国家",
 "Country" => "国家",
-"Addressbook" => "地址簿",
-"Hon. prefixes" => "名誉字首",
-"Miss" => "小姐",
-"Ms" => "女士",
-"Mr" => "先生",
-"Sir" => "先生",
-"Mrs" => "夫人",
-"Dr" => "博士",
-"Given name" => "名",
-"Additional names" => "其他名称",
-"Family name" => "姓",
-"Hon. suffixes" => "名誉后缀",
-"J.D." => "法律博士",
-"M.D." => "医学博士",
-"D.O." => "骨科医学博士",
-"D.C." => "教育学博士",
-"Ph.D." => "哲学博士",
-"Esq." => "先生",
-"Jr." => "小",
-"Sn." => "老",
-"Import a contacts file" => "导入联系人文件",
-"Please choose the addressbook" => "请选择地址簿",
-"create a new addressbook" => "创建新地址簿",
-"Name of new addressbook" => "新地址簿名称",
-"Importing contacts" => "导入联系人",
-"<h3>You have no contacts in your addressbook.</h3><p>You can import VCF files by dragging them to the contacts list and either drop them on an addressbook to import into it, or on an empty spot to create a new addressbook and import into that.<br />You can also import by clicking on the import button at the bottom of the list.</p>" => "<h3>您还没有联系人哟。</h3><p>您可以通过拖曳VCF文件到联系人列表或地址簿来导入联系人，或者空白处创建新的地址簿进行导入。<br />您还可以通过点击列表底部的导入按钮来导入</p>",
-"Add contact" => "添加联系人",
-"Select Address Books" => "选择地址簿",
-"Enter description" => "输入描述",
+"Instant Messenger" => "即时通讯",
+"Delete IM" => "删除即时通讯工具",
+"Share" => "共享",
+"Export" => "导出",
+"CardDAV link" => "CardDAV 链接",
+"The temporary image has been removed from cache." => "临时图像文件已从缓存中删除",
 "CardDAV syncing addresses" => "CardDAV 同步地址",
 "more info" => "更多信息",
 "Primary address (Kontact et al)" => "首选地址 (Kontact 等)",
 "iOS/OS X" => "iOS/OS X",
 "Addressbooks" => "地址簿",
-"Share" => "共享",
 "New Address Book" => "新建地址簿",
 "Name" => "姓名",
 "Description" => "描述",
