@@ -17,13 +17,15 @@ function getStandardImage() {
 	//OCP\Response::setExpiresHeader('P10D');
 	OCP\Response::enableCaching();
 	OCP\Response::redirect(OCP\Util::imagePath('contacts', 'person_large.png'));
+	exit;
 }
 
 $id = isset($_GET['id']) ? $_GET['id'] : null;
 $etag = null;
 $caching = null;
+$max_size = 170;
 
-if(is_null($id)) {
+if(!$id || $id === 'new') {
 	getStandardImage();
 }
 
@@ -33,9 +35,9 @@ if(!extension_loaded('gd') || !function_exists('gd_info')) {
 	getStandardImage();
 }
 
-$contact = OC_Contacts_App::getContactVCard($id);
+$contact = OCA\Contacts\App::getContactVCard($id);
 $image = new OC_Image();
-if (!$image) {
+if (!$image || !$contact) {
 	getStandardImage();
 }
 // invalid vcard
@@ -45,18 +47,18 @@ if (is_null($contact)) {
 		OCP\Util::ERROR);
 } else {
 	// Photo :-)
-	if ($image->loadFromBase64($contact->getAsString('PHOTO'))) {
+	if (isset($contact->PHOTO) && $image->loadFromBase64((string)$contact->PHOTO)) {
 		// OK
-		$etag = md5($contact->getAsString('PHOTO'));
+		$etag = md5($contact->PHOTO);
 	}
 	else
 	// Logo :-/
-	if ($image->loadFromBase64($contact->getAsString('LOGO'))) {
+	if (isset($contact->LOGO) && $image->loadFromBase64((string)$contact->LOGO)) {
 		// OK
-		$etag = md5($contact->getAsString('LOGO'));
+		$etag = md5($contact->LOGO);
 	}
 	if ($image->valid()) {
-		$modified = OC_Contacts_App::lastModified($contact);
+		$modified = OCA\Contacts\App::lastModified($contact);
 		// Force refresh if modified within the last minute.
 		if(!is_null($modified)) {
 			$caching = (time() - $modified->format('U') > 60) ? null : 0;
@@ -68,7 +70,6 @@ if (is_null($contact)) {
 		if($etag) {
 			OCP\Response::setETagHeader($etag);
 		}
-		$max_size = 200;
 		if ($image->width() > $max_size || $image->height() > $max_size) {
 			$image->resize($max_size);
 		}
