@@ -21,10 +21,6 @@
 *
 */
 
-
-// Init owncloud
-
-
 OCP\User::checkAdminUser();
 
 $htaccessWorking=(getenv('htaccessWorking')=='true');
@@ -46,7 +42,8 @@ if($_POST && OC_Util::isCallRegistered()) {
 		OCP\Config::setSystemValue('allowZipDownload', isset($_POST['allowZipDownload']));
 	}
 }
-$maxZipInputSize = OCP\Util::humanFileSize(OCP\Config::getSystemValue('maxZipInputSize', OCP\Util::computerFileSize('800 MB')));
+$maxZipInputSizeDefault = OCP\Util::computerFileSize('800 MB');
+$maxZipInputSize = OCP\Util::humanFileSize(OCP\Config::getSystemValue('maxZipInputSize', $maxZipInputSizeDefault));
 $allowZipDownload = intval(OCP\Config::getSystemValue('allowZipDownload', true));
 
 OCP\App::setActiveNavigationEntry( "files_administration" );
@@ -61,4 +58,4 @@ $tmpl->assign( 'displayMaxPossibleUploadSize', PHP_INT_SIZE===4);
 $tmpl->assign( 'maxPossibleUploadSize', OCP\Util::humanFileSize(PHP_INT_MAX));
 $tmpl->assign( 'allowZipDownload', $allowZipDownload);
 $tmpl->assign( 'maxZipInputSize', $maxZipInputSize);
-return $tmpl->fetchPage();
\ No newline at end of file
+return $tmpl->fetchPage();
