@@ -19,13 +19,14 @@ if(strpos($foldername, '/')!==false) {
 	exit();
 }
 
-if(OC_Files::newFile($dir, stripslashes($foldername), 'dir')) {
+if(\OC\Files\Filesystem::mkdir($dir . '/' . stripslashes($foldername))) {
 	if ( $dir != '/') {
 		$path = $dir.'/'.$foldername;
 	} else {
 		$path = '/'.$foldername;
 	}
-	$id = OC_FileCache::getId($path);
+	$meta = \OC\Files\Filesystem::getFileInfo($path);
+	$id = $meta['fileid'];
 	OCP\JSON::success(array("data" => array('id'=>$id)));
 	exit();
 }
