@@ -26,15 +26,34 @@ Files={
 		});
 		procesSelection();
 	},
+	updateMaxUploadFilesize:function(response) {
+		if(response == undefined) {
+			return;
+		}
+		if(response.data !== undefined && response.data.uploadMaxFilesize !== undefined) {
+			$('#max_upload').val(response.data.uploadMaxFilesize);
+			$('#upload.button').attr('original-title', response.data.maxHumanFilesize);
+			$('#usedSpacePercent').val(response.data.usedSpacePercent);
+			Files.displayStorageWarnings();
+		}
+		if(response[0] == undefined) {
+			return;
+		}
+		if(response[0].uploadMaxFilesize !== undefined) {
+			$('#max_upload').val(response[0].uploadMaxFilesize);
+			$('#upload.button').attr('original-title', response[0].maxHumanFilesize);
+			$('#usedSpacePercent').val(response[0].usedSpacePercent);
+			Files.displayStorageWarnings();
+		}
+
+	},
 	isFileNameValid:function (name) {
 		if (name === '.') {
-			$('#notification').text(t('files', '\'.\' is an invalid file name.'));
-			$('#notification').fadeIn();
+			OC.Notification.show(t('files', '\'.\' is an invalid file name.'));
 			return false;
 		}
 		if (name.length == 0) {
-			$('#notification').text(t('files', 'File name cannot be empty.'));
-			$('#notification').fadeIn();
+			OC.Notification.show(t('files', 'File name cannot be empty.'));
 			return false;
 		}
 
@@ -42,25 +61,35 @@ Files={
 		var invalid_characters = ['\\', '/', '<', '>', ':', '"', '|', '?', '*'];
 		for (var i = 0; i < invalid_characters.length; i++) {
 			if (name.indexOf(invalid_characters[i]) != -1) {
-				$('#notification').text(t('files', "Invalid name, '\\', '/', '<', '>', ':', '\"', '|', '?' and '*' are not allowed."));
-				$('#notification').fadeIn();
+				OC.Notification.show(t('files', "Invalid name, '\\', '/', '<', '>', ':', '\"', '|', '?' and '*' are not allowed."));
 				return false;
 			}
 		}
-		$('#notification').fadeOut();
+		OC.Notification.hide();
 		return true;
+	},
+	displayStorageWarnings: function() {
+		if (!OC.Notification.isHidden()) {
+			return;
+		}
+
+		var usedSpacePercent = $('#usedSpacePercent').val();
+		if (usedSpacePercent > 98) {
+			OC.Notification.show(t('files', 'Your storage is full, files can not be updated or synced anymore!'));
+			return;
+		}
+		if (usedSpacePercent > 90) {
+			OC.Notification.show(t('files', 'Your storage is almost full ({usedSpacePercent}%)', {usedSpacePercent: usedSpacePercent}));
+		}
 	}
 };
 $(document).ready(function() {
+	Files.bindKeyboardShortcuts(document, jQuery);
 	$('#fileList tr').each(function(){
 		//little hack to set unescape filenames in attribute
 		$(this).attr('data-file',decodeURIComponent($(this).attr('data-file')));
 	});
 
-	if($('tr[data-file]').length==0){
-		$('.file_upload_filename').addClass('highlight');
-	}
-
 	$('#file_action_panel').attr('activeAction', false);
 
 	//drag/drop of files
@@ -81,25 +110,27 @@ $(document).ready(function() {
 	}
 
 	// Triggers invisible file input
-	$('.file_upload_button_wrapper').live('click', function() {
-		$(this).parent().children('.file_upload_start').trigger('click');
+	$('#upload a').on('click', function() {
+		$(this).parent().children('#file_upload_start').trigger('click');
 		return false;
 	});
 
-	// Sets the file-action buttons behaviour :
-	$('tr').live('mouseenter',function(event) {
-		FileActions.display($(this).children('td.filename'));
+	// Trigger cancelling of file upload
+	$('#uploadprogresswrapper .stop').on('click', function() {
+		Files.cancelUploads();
 	});
-	$('tr').live('mouseleave',function(event) {
-		FileActions.hide();
+
+	// Show trash bin
+	$('#trash a').live('click', function() {
+		window.location=OC.filePath('files_trashbin', '', 'index.php');
 	});
 
 	var lastChecked;
 
 	// Sets the file link behaviour :
-	$('td.filename a').live('click',function(event) {
-		event.preventDefault();
+	$('#fileList').on('click','td.filename a',function(event) {
 		if (event.ctrlKey || event.shiftKey) {
+			event.preventDefault();
 			if (event.shiftKey) {
 				var last = $(lastChecked).parent().parent().prevAll().length;
 				var first = $(this).parent().parent().prevAll().length;
@@ -136,11 +167,13 @@ $(document).ready(function() {
 			var tr=$('tr').filterAttr('data-file',filename);
 			var renaming=tr.data('renaming');
 			if(!renaming && !FileList.isLoading(filename)){
-				var mime=$(this).parent().parent().data('mime');
-				var type=$(this).parent().parent().data('type');
-				var permissions = $(this).parent().parent().data('permissions');
+				FileActions.currentFile = $(this).parent();
+				var mime=FileActions.getCurrentMimeType();
+				var type=FileActions.getCurrentType();
+				var permissions = FileActions.getCurrentPermissions();
 				var action=FileActions.getDefault(mime,type, permissions);
 				if(action){
+					event.preventDefault();
 					action(filename);
 				}
 			}
@@ -162,7 +195,7 @@ $(document).ready(function() {
 		procesSelection();
 	});
 
-	$('td.filename input:checkbox').live('change',function(event) {
+	$('#fileList').on('change', 'td.filename input:checkbox',function(event) {
 		if (event.shiftKey) {
 			var last = $(lastChecked).parent().parent().prevAll().length;
 			var first = $(this).parent().parent().prevAll().length;
@@ -191,27 +224,21 @@ $(document).ready(function() {
 		procesSelection();
 	});
 
-	$('#file_newfolder_name').click(function(){
-		if($('#file_newfolder_name').val() == 'New Folder'){
-			$('#file_newfolder_name').val('');
-		}
-	});
-
 	$('.download').click('click',function(event) {
-		var files=getSelectedFiles('name').join(';');
+		var files=getSelectedFiles('name');
+		var fileslist = JSON.stringify(files);
 		var dir=$('#dir').val()||'/';
-		$('#notification').text(t('files','generating ZIP-file, it may take some time.'));
-		$('#notification').fadeIn();
+		OC.Notification.show(t('files','Your download is being prepared. This might take some time if the files are big.'));
 		// use special download URL if provided, e.g. for public shared files
 		if ( (downloadURL = document.getElementById("downloadURL")) ) {
-			window.location=downloadURL.value+"&download&files="+files;
+			window.location=downloadURL.value+"&download&files="+encodeURIComponent(fileslist);
 		} else {
-			window.location=OC.filePath('files', 'ajax', 'download.php') + '?'+ $.param({ dir: dir, files: files });
+			window.location=OC.filePath('files', 'ajax', 'download.php') + '?'+ $.param({ dir: dir, files: fileslist });
 		}
 		return false;
 	});
 
-	$('.delete').click(function(event) {
+	$('.delete-selected').click(function(event) {
 		var files=getSelectedFiles('name');
 		event.preventDefault();
 		FileList.do_delete(files);
@@ -224,235 +251,6 @@ $(document).ready(function() {
 			e.preventDefault(); // prevent browser from doing anything, if file isn't dropped in dropZone
 	});
 
-	if ( document.getElementById("data-upload-form") ) {
-	$(function() {
-		$('.file_upload_start').fileupload({
-			dropZone: $('#content'), // restrict dropZone to content div
-			add: function(e, data) {
-				var files = data.files;
-				var totalSize=0;
-				if(files){
-					for(var i=0;i<files.length;i++){
-						if(files[i].size ==0 && files[i].type== '')
-						{
-							OC.dialogs.alert(t('files', 'Unable to upload your file as it is a directory or has 0 bytes'), t('files', 'Upload Error'));
-							return;
-						}
-						totalSize+=files[i].size;
-						if(FileList.deleteFiles && FileList.deleteFiles.indexOf(files[i].name)!=-1){//finish delete if we are uploading a deleted file
-							FileList.finishDelete(function(){
-								$('.file_upload_start').change();
-							});
-							return;
-						}
-					}
-				}
-				if(totalSize>$('#max_upload').val()){
-					$( '#uploadsize-message' ).dialog({
-						modal: true,
-						buttons: {
-							Close: function() {
-								$( this ).dialog( 'close' );
-							}
-						}
-					});
-				}else{
-					var dropTarget = $(e.originalEvent.target).closest('tr');
-					if(dropTarget && dropTarget.attr('data-type') === 'dir') { // drag&drop upload to folder
-						var dirName = dropTarget.attr('data-file')
-					}
-
-					var date=new Date();
-					if(files){
-						for(var i=0;i<files.length;i++){
-							if(files[i].size>0){
-								var size=files[i].size;
-							}else{
-								var size=t('files','Pending');
-							}
-							if(files && !dirName){
-								var uniqueName = getUniqueName(files[i].name);
-								if (uniqueName != files[i].name) {
-									FileList.checkName(uniqueName, files[i].name, true);
-									var hidden = true;
-								} else {
-									var hidden = false;
-								}
-								FileList.addFile(uniqueName,size,date,true,hidden);
-							} else if(dirName) {
-								var uploadtext = $('tr').filterAttr('data-type', 'dir').filterAttr('data-file', dirName).find('.uploadtext')
-								var currentUploads = parseInt(uploadtext.attr('currentUploads'));
-								currentUploads += 1;
-								uploadtext.attr('currentUploads', currentUploads);
-								if(currentUploads === 1) {
-									var img = OC.imagePath('core', 'loading.gif');
-									var tr=$('tr').filterAttr('data-file',dirName);
-									tr.find('td.filename').attr('style','background-image:url('+img+')');
-									uploadtext.text(t('files', '1 file uploading'));
-									uploadtext.show();
-								} else {
-									uploadtext.text(currentUploads + ' ' + t('files', 'files uploading'));
-								}
-							}
-						}
-					}else{
-						var filename=this.value.split('\\').pop(); //ie prepends C:\fakepath\ in front of the filename
-						var uniqueName = getUniqueName(filename);
-						if (uniqueName != filename) {
-							FileList.checkName(uniqueName, filename, true);
-							var hidden = true;
-						} else {
-							var hidden = false;
-						}
-						FileList.addFile(uniqueName,'Pending',date,true,hidden);
-					}
-					if($.support.xhrFileUpload) {
-						for(var i=0;i<files.length;i++){
-							var fileName = files[i].name
-							var dropTarget = $(e.originalEvent.target).closest('tr');
-							if(dropTarget && dropTarget.attr('data-type') === 'dir') { // drag&drop upload to folder
-								var dirName = dropTarget.attr('data-file')
-								var jqXHR =  $('.file_upload_start').fileupload('send', {files: files[i],
-										formData: function(form) {
-											var formArray = form.serializeArray();
-											// array index 0 contains the max files size
-											// array index 1 contains the request token
-											// array index 2 contains the directory
-											formArray[2]['value'] = dirName;
-											return formArray;
-										}}).success(function(result, textStatus, jqXHR) {
-											var response;
-											response=jQuery.parseJSON(result);
-											if(response[0] == undefined || response[0].status != 'success') {
-												$('#notification').text(t('files', response.data.message));
-												$('#notification').fadeIn();
-											}
-											var file=response[0];
-											// TODO: this doesn't work if the file name has been changed server side
-											delete uploadingFiles[dirName][file.name];
-											if ($.assocArraySize(uploadingFiles[dirName]) == 0) {
-												delete uploadingFiles[dirName];
-											}
-
-											var uploadtext = $('tr').filterAttr('data-type', 'dir').filterAttr('data-file', dirName).find('.uploadtext')
-											var currentUploads = parseInt(uploadtext.attr('currentUploads'));
-											currentUploads -= 1;
-											uploadtext.attr('currentUploads', currentUploads);
-											if(currentUploads === 0) {
-												var img = OC.imagePath('core', 'filetypes/folder.png');
-												var tr=$('tr').filterAttr('data-file',dirName);
-												tr.find('td.filename').attr('style','background-image:url('+img+')');
-												uploadtext.text('');
-												uploadtext.hide();
-											} else {
-												uploadtext.text(currentUploads + ' ' + t('files', 'files uploading'));
-											}
-										})
-								.error(function(jqXHR, textStatus, errorThrown) {
-									if(errorThrown === 'abort') {
-										var currentUploads = parseInt(uploadtext.attr('currentUploads'));
-										currentUploads -= 1;
-										uploadtext.attr('currentUploads', currentUploads);
-										if(currentUploads === 0) {
-											var img = OC.imagePath('core', 'filetypes/folder.png');
-											var tr=$('tr').filterAttr('data-file',dirName);
-											tr.find('td.filename').attr('style','background-image:url('+img+')');
-											uploadtext.text('');
-											uploadtext.hide();
-										} else {
-											uploadtext.text(currentUploads + ' ' + t('files', 'files uploading'));
-										}
-										$('#notification').hide();
-										$('#notification').text(t('files', 'Upload cancelled.'));
-										$('#notification').fadeIn();
-									}
-								});
-								//TODO test with filenames containing slashes
-								if(uploadingFiles[dirName] === undefined) {
-									uploadingFiles[dirName] = {};
-								}
-								uploadingFiles[dirName][fileName] = jqXHR;
-							} else {
-								var jqXHR =  $('.file_upload_start').fileupload('send', {files: files[i]})
-										.success(function(result, textStatus, jqXHR) {
-											var response;
-											response=jQuery.parseJSON(result);
-											if(response[0] != undefined && response[0].status == 'success') {
-												var file=response[0];
-												delete uploadingFiles[file.name];
-												$('tr').filterAttr('data-file',file.name).data('mime',file.mime).data('id',file.id);
-												var size = $('tr').filterAttr('data-file',file.name).find('td.filesize').text();
-												if(size==t('files','Pending')){
-													$('tr').filterAttr('data-file',file.name).find('td.filesize').text(file.size);
-												}
-												FileList.loadingDone(file.name, file.id);
-											} else {
-												$('#notification').text(t('files', response.data.message));
-												$('#notification').fadeIn();
-												$('#fileList > tr').not('[data-mime]').fadeOut();
-												$('#fileList > tr').not('[data-mime]').remove();
-											}
-										})
-								.error(function(jqXHR, textStatus, errorThrown) {
-									if(errorThrown === 'abort') {
-										$('#notification').hide();
-										$('#notification').text(t('files', 'Upload cancelled.'));
-										$('#notification').fadeIn();
-									}
-								});
-								uploadingFiles[uniqueName] = jqXHR;
-							}
-						}
-					}else{
-						data.submit().success(function(data, status) {
-							// in safari data is a string
-							response = jQuery.parseJSON(typeof data === 'string' ? data : data[0].body.innerText);
-							if(response[0] != undefined && response[0].status == 'success') {
-								var file=response[0];
-								delete uploadingFiles[file.name];
-								$('tr').filterAttr('data-file',file.name).data('mime',file.mime).data('id',file.id);
-								var size = $('tr').filterAttr('data-file',file.name).find('td.filesize').text();
-								if(size==t('files','Pending')){
-									$('tr').filterAttr('data-file',file.name).find('td.filesize').text(file.size);
-								}
-								FileList.loadingDone(file.name, file.id);
-							} else {
-								$('#notification').text(t('files', response.data.message));
-								$('#notification').fadeIn();
-								$('#fileList > tr').not('[data-mime]').fadeOut();
-								$('#fileList > tr').not('[data-mime]').remove();
-							}
-						});
-					}
-				}
-			},
-			fail: function(e, data) {
-				// TODO: cancel upload & display error notification
-			},
-			progress: function(e, data) {
-				// TODO: show nice progress bar in file row
-			},
-			progressall: function(e, data) {
-				var progress = (data.loaded/data.total)*100;
-				$('#uploadprogressbar').progressbar('value',progress);
-			},
-			start: function(e, data) {
-				$('#uploadprogressbar').progressbar({value:0});
-				$('#uploadprogressbar').fadeIn();
-				if(data.dataType != 'iframe ') {
-					$('#upload input.stop').show();
-				}
-			},
-			stop: function(e, data) {
-				if(data.dataType != 'iframe ') {
-					$('#upload input.stop').hide();
-				}
-				$('#uploadprogressbar').progressbar('value',100);
-				$('#uploadprogressbar').fadeOut();
-			}
-		})
-	});
-	}
 	$.assocArraySize = function(obj) {
 		// http://stackoverflow.com/a/6700/11236
 		var size = 0, key;
@@ -470,7 +268,7 @@ $(document).ready(function() {
 
 	//add multiply file upload attribute to all browsers except konqueror (which crashes when it's used)
 	if(navigator.userAgent.search(/konqueror/i)==-1){
-		$('.file_upload_start').attr('multiple','multiple')
+		$('#file_upload_start').attr('multiple','multiple')
 	}
 
 	//if the breadcrumb is to long, start by replacing foldernames with '...' except for the current folder
@@ -495,10 +293,9 @@ $(document).ready(function() {
 		crumb.text(text);
 	}
 
-	$(window).click(function(){
+	$(document).click(function(){
 		$('#new>ul').hide();
 		$('#new').removeClass('active');
-		$('button.file_upload_filename').removeClass('active');
 		$('#new li').each(function(i,element){
 			if($(element).children('p').length==0){
 				$(element).children('form').remove();
@@ -512,7 +309,6 @@ $(document).ready(function() {
 	$('#new>a').click(function(){
 		$('#new>ul').toggle();
 		$('#new').toggleClass('active');
-		$('button.file_upload_filename').toggleClass('active');
 	});
 	$('#new li').click(function(){
 		if($(this).children('p').length==0){
@@ -539,17 +335,18 @@ $(document).ready(function() {
 			event.stopPropagation();
 			event.preventDefault();
 			var newname=input.val();
-			if(type == 'web' && newname.length == 0){
-				$('#notification').text(t('files', "URL cannot be empty."));
-				$('#notification').fadeIn();
+			if(type == 'web' && newname.length == 0) {
+				OC.Notification.show(t('files', 'URL cannot be empty.'));
 				return false;
 			} else if (type != 'web' && !Files.isFileNameValid(newname)) {
 				return false;
 			} else if( type == 'folder' && $('#dir').val() == '/' && newname == 'Shared') {
-				$('#notification').text(t('files','Invalid folder name. Usage of "Shared" is reserved by Owncloud'));
-				$('#notification').fadeIn();
+				OC.Notification.show(t('files','Invalid folder name. Usage of \'Shared\' is reserved by Owncloud'));
 				return false;
 			}
+			if (FileList.lastAction) {
+				FileList.lastAction();
+			}
 			var name = getUniqueName(newname);
 			if (newname != name) {
 				FileList.checkName(name, newname, true);
@@ -567,7 +364,7 @@ $(document).ready(function() {
 								var date=new Date();
 								FileList.addFile(name,0,date,false,hidden);
 								var tr=$('tr').filterAttr('data-file',name);
-								tr.data('mime','text/plain').data('id',result.data.id);
+								tr.attr('data-mime','text/plain');
 								tr.attr('data-id', result.data.id);
 								getMimeIcon('text/plain',function(path){
 									tr.find('td.filename').attr('style','background-image:url('+path+')');
@@ -608,12 +405,20 @@ $(document).ready(function() {
 						localName=(localName.match(/:\/\/(.[^/]+)/)[1]).replace('www.','');
 					}
 					localName = getUniqueName(localName);
-					$('#uploadprogressbar').progressbar({value:0});
-					$('#uploadprogressbar').fadeIn();
+					//IE < 10 does not fire the necessary events for the progress bar.
+					if($('html.lte9').length > 0) {
+					} else {
+						$('#uploadprogressbar').progressbar({value:0});
+						$('#uploadprogressbar').fadeIn();
+					}
 
 					var eventSource=new OC.EventSource(OC.filePath('files','ajax','newfile.php'),{dir:$('#dir').val(),source:name,filename:localName});
 					eventSource.listen('progress',function(progress){
-						$('#uploadprogressbar').progressbar('value',progress);
+						//IE < 10 does not fire the necessary events for the progress bar.
+						if($('html.lte9').length > 0) {
+						} else {
+							$('#uploadprogressbar').progressbar('value',progress);
+						}
 					});
 					eventSource.listen('success',function(data){
 						var mime=data.mime;
@@ -642,12 +447,8 @@ $(document).ready(function() {
 		});
 	});
 
-	//check if we need to scan the filesystem
-	$.get(OC.filePath('files','ajax','scan.php'),{checkonly:'true'}, function(response) {
-		if(response.data.done){
-			scanFiles();
-		}
-	}, "json");
+	//do a background scan if needed
+	scanFiles();
 
 	var lastWidth = 0;
 	var breadcrumbs = [];
@@ -662,9 +463,10 @@ $(document).ready(function() {
 		breadcrumbsWidth += $(breadcrumb).get(0).offsetWidth;
 	});
 
-	if ($('#controls .actions').length > 0) {
-		breadcrumbsWidth += $('#controls .actions').get(0).offsetWidth;
-	}
+
+	$.each($('#controls .actions>div'), function(index, action) {
+		breadcrumbsWidth += $(action).get(0).offsetWidth;
+	});
 
 	function resizeBreadcrumbs(firstRun) {
 		var width = $(this).width();
@@ -714,35 +516,80 @@ $(document).ready(function() {
 	});
 
 	resizeBreadcrumbs(true);
+
+	// display storage warnings
+	setTimeout ( "Files.displayStorageWarnings()", 100 );
+	OC.Notification.setDefault(Files.displayStorageWarnings);
+
+	// file space size sync
+	function update_storage_statistics() {
+		$.getJSON(OC.filePath('files','ajax','getstoragestats.php'),function(response) {
+			Files.updateMaxUploadFilesize(response);
+		});
+	}
+
+	// start on load - we ask the server every 5 minutes
+	var update_storage_statistics_interval = 5*60*1000;
+	var update_storage_statistics_interval_id = setInterval(update_storage_statistics, update_storage_statistics_interval);
+
+	// Use jquery-visibility to de-/re-activate file stats sync
+	if ($.support.pageVisibility) {
+		$(document).on({
+			'show.visibility': function() {
+				if (!update_storage_statistics_interval_id) {
+					update_storage_statistics_interval_id = setInterval(update_storage_statistics, update_storage_statistics_interval);
+				}
+			},
+			'hide.visibility': function() {
+				clearInterval(update_storage_statistics_interval_id);
+				update_storage_statistics_interval_id = 0;
+			}
+		});
+	}
 });
 
-function scanFiles(force,dir){
-	if(!dir){
-		dir='';
+function scanFiles(force, dir, users){
+	if (!OC.currentUser) {
+		return;
 	}
-	force=!!force; //cast to bool
-	scanFiles.scanning=true;
-	$('#scanning-message').show();
-	$('#fileList').remove();
-	var scannerEventSource=new OC.EventSource(OC.filePath('files','ajax','scan.php'),{force:force,dir:dir});
-	scanFiles.cancel=scannerEventSource.close.bind(scannerEventSource);
-	scannerEventSource.listen('scanning',function(data){
-		$('#scan-count').text(data.count + ' ' + t('files', 'files scanned'));
-		$('#scan-current').text(data.file+'/');
-	});
-	scannerEventSource.listen('success',function(success){
-		scanFiles.scanning=false;
-		if(success){
-			window.location.reload();
-		}else{
-			alert(t('files', 'error while scanning'));
+
+	if(!dir){
+		dir = '';
+	}
+	force = !!force; //cast to bool
+	scanFiles.scanning = true;
+	var scannerEventSource;
+	if (users) {
+		var usersString;
+		if (users === 'all') {
+			usersString = users;
+		} else {
+			usersString = JSON.stringify(users);
 		}
+		scannerEventSource = new OC.EventSource(OC.filePath('files','ajax','scan.php'),{force: force,dir: dir, users: usersString});
+	} else {
+		scannerEventSource = new OC.EventSource(OC.filePath('files','ajax','scan.php'),{force: force,dir: dir});
+	}
+	scanFiles.cancel = scannerEventSource.close.bind(scannerEventSource);
+	scannerEventSource.listen('count',function(count){
+		console.log(count + 'files scanned')
+	});
+	scannerEventSource.listen('folder',function(path){
+		console.log('now scanning ' + path)
+	});
+	scannerEventSource.listen('done',function(count){
+		scanFiles.scanning=false;
+		console.log('done after ' + count + 'files');
+	});
+	scannerEventSource.listen('user',function(user){
+		console.log('scanning files for ' + user);
 	});
 }
 scanFiles.scanning=false;
 
 function boolOperationFinished(data, callback) {
 	result = jQuery.parseJSON(data.responseText);
+	Files.updateMaxUploadFilesize(result);
 	if(result.status == 'success'){
 		callback.call();
 	} else {
@@ -754,32 +601,105 @@ function updateBreadcrumb(breadcrumbHtml) {
 	$('p.nav').empty().html(breadcrumbHtml);
 }
 
-//options for file drag/dropp
+var createDragShadow = function(event){
+	//select dragged file
+	var isDragSelected = $(event.target).parents('tr').find('td input:first').prop('checked');
+	if (!isDragSelected) {
+		//select dragged file
+		$(event.target).parents('tr').find('td input:first').prop('checked',true);
+	}
+
+	var selectedFiles = getSelectedFiles();
+
+	if (!isDragSelected && selectedFiles.length == 1) {
+		//revert the selection
+		$(event.target).parents('tr').find('td input:first').prop('checked',false);
+	}
+
+	//also update class when we dragged more than one file
+	if (selectedFiles.length > 1) {
+		$(event.target).parents('tr').addClass('selected');
+	}
+
+	// build dragshadow
+	var dragshadow = $('<table class="dragshadow"></table>');
+	var tbody = $('<tbody></tbody>');
+	dragshadow.append(tbody);
+
+	var dir=$('#dir').val();
+
+	$(selectedFiles).each(function(i,elem){
+		var newtr = $('<tr/>').attr('data-dir', dir).attr('data-filename', elem.name);
+		newtr.append($('<td/>').addClass('filename').text(elem.name));
+		newtr.append($('<td/>').addClass('size').text(humanFileSize(elem.size)));
+		tbody.append(newtr);
+		if (elem.type === 'dir') {
+			newtr.find('td.filename').attr('style','background-image:url('+OC.imagePath('core', 'filetypes/folder.png')+')');
+		} else {
+			getMimeIcon(elem.mime,function(path){
+				newtr.find('td.filename').attr('style','background-image:url('+path+')');
+			});
+		}
+	});
+
+	return dragshadow;
+}
+
+//options for file drag/drop
 var dragOptions={
-	distance: 20, revert: 'invalid', opacity: 0.7, helper: 'clone',
+	revert: 'invalid', revertDuration: 300,
+	opacity: 0.7, zIndex: 100, appendTo: 'body', cursorAt: { left: -5, top: -5 },
+	helper: createDragShadow, cursor: 'move',
 	stop: function(event, ui) {
 		$('#fileList tr td.filename').addClass('ui-draggable');
 	}
-};
+}
+// sane browsers support using the distance option
+if ( $('html.ie').length === 0) {
+	dragOptions['distance'] = 20;
+}
+
 var folderDropOptions={
 	drop: function( event, ui ) {
-		var file=ui.draggable.parent().data('file');
-		var target=$(this).find('.nametext').text().trim();
-		var dir=$('#dir').val();
-		$.ajax({
-			url: OC.filePath('files', 'ajax', 'move.php'),
-			data: "dir="+encodeURIComponent(dir)+"&file="+encodeURIComponent(file)+'&target='+encodeURIComponent(dir)+'/'+encodeURIComponent(target),
-			complete: function(data){boolOperationFinished(data, function(){
-				var el = $('#fileList tr').filterAttr('data-file',file).find('td.filename');
-				el.draggable('destroy');
-				FileList.remove(file);
-			});}
+		//don't allow moving a file into a selected folder
+		if ($(event.target).parents('tr').find('td input:first').prop('checked') === true) {
+			return false;
+		}
+
+		var target=$.trim($(this).find('.nametext').text());
+
+		var files = ui.helper.find('tr');
+		$(files).each(function(i,row){
+			var dir = $(row).data('dir');
+			var file = $(row).data('filename');
+			$.post(OC.filePath('files', 'ajax', 'move.php'), { dir: dir, file: file, target: dir+'/'+target }, function(result) {
+				if (result) {
+					if (result.status === 'success') {
+						//recalculate folder size
+						var oldSize = $('#fileList tr').filterAttr('data-file',target).data('size');
+						var newSize = oldSize + $('#fileList tr').filterAttr('data-file',file).data('size');
+						$('#fileList tr').filterAttr('data-file',target).data('size', newSize);
+						$('#fileList tr').filterAttr('data-file',target).find('td.filesize').text(humanFileSize(newSize));
+
+						FileList.remove(file);
+						procesSelection();
+						$('#notification').hide();
+					} else {
+						$('#notification').hide();
+						$('#notification').text(result.data.message);
+						$('#notification').fadeIn();
+					}
+				} else {
+					OC.dialogs.alert(t('Error moving file'));
+				}
+			});
 		});
-	}
+	},
+	tolerance: 'pointer'
 }
+
 var crumbDropOptions={
 	drop: function( event, ui ) {
-		var file=ui.draggable.text().trim();
 		var target=$(this).data('dir');
 		var dir=$('#dir').val();
 		while(dir.substr(0,1)=='/'){//remove extra leading /'s
@@ -792,12 +712,25 @@ var crumbDropOptions={
 		if(target==dir || target+'/'==dir){
 			return;
 		}
-		$.ajax({
-			url: OC.filePath('files', 'ajax', 'move.php'),
-		 data: "dir="+encodeURIComponent(dir)+"&file="+encodeURIComponent(file)+'&target='+encodeURIComponent(target),
-		 complete: function(data){boolOperationFinished(data, function(){
-			 FileList.remove(file);
-		 });}
+		var files = ui.helper.find('tr');
+		$(files).each(function(i,row){
+			var dir = $(row).data('dir');
+			var file = $(row).data('filename');
+			$.post(OC.filePath('files', 'ajax', 'move.php'), { dir: dir, file: file, target: target }, function(result) {
+				if (result) {
+					if (result.status === 'success') {
+						FileList.remove(file);
+						procesSelection();
+						$('#notification').hide();
+					} else {
+						$('#notification').hide();
+						$('#notification').text(result.data.message);
+						$('#notification').fadeIn();
+					}
+				} else {
+					OC.dialogs.alert(t('Error moving file'));
+				}
+			});
 		});
 	},
 	tolerance: 'pointer'
@@ -807,22 +740,14 @@ function procesSelection(){
 	var selected=getSelectedFiles();
 	var selectedFiles=selected.filter(function(el){return el.type=='file'});
 	var selectedFolders=selected.filter(function(el){return el.type=='dir'});
-	if(selectedFiles.length==0 && selectedFolders.length==0){
+	if(selectedFiles.length==0 && selectedFolders.length==0) {
 		$('#headerName>span.name').text(t('files','Name'));
 		$('#headerSize').text(t('files','Size'));
 		$('#modified').text(t('files','Modified'));
-		$('th').removeClass('multiselect');
+		$('table').removeClass('multiselect');
 		$('.selectedActions').hide();
-		$('thead').removeClass('fixed');
-		$('#headerName').css('width','auto');
-		$('#headerSize').css('width','auto');
-		$('#headerDate').css('width','auto');
-		$('table').css('padding-top','0');
-	}else{
-		var width={name:$('#headerName').css('width'),size:$('#headerSize').css('width'),date:$('#headerDate').css('width')};
-		$('#headerName').css('width',width.name);
-		$('#headerSize').css('width',width.size);
-		$('#headerDate').css('width',width.date);
+	}
+	else {
 		$('.selectedActions').show();
 		var totalSize=0;
 		for(var i=0;i<selectedFiles.length;i++){
@@ -837,9 +762,9 @@ function procesSelection(){
 		var selection='';
 		if(selectedFolders.length>0){
 			if(selectedFolders.length==1){
-				selection+='1 '+t('files','folder');
+				selection+=t('files','1 folder');
 			}else{
-				selection+=selectedFolders.length+' '+t('files','folders');
+				selection+=t('files','{count} folders',{count: selectedFolders.length});
 			}
 			if(selectedFiles.length>0){
 				selection+=' & ';
@@ -847,14 +772,14 @@ function procesSelection(){
 		}
 		if(selectedFiles.length>0){
 			if(selectedFiles.length==1){
-				selection+='1 '+t('files','file');
+				selection+=t('files','1 file');
 			}else{
-				selection+=selectedFiles.length+' '+t('files','files');
+				selection+=t('files','{count} files',{count: selectedFiles.length});
 			}
 		}
 		$('#headerName>span.name').text(selection);
 		$('#modified').text('');
-		$('th').addClass('multiselect');
+		$('table').addClass('multiselect');
 	}
 }
 
@@ -886,27 +811,6 @@ function getSelectedFiles(property){
 	return files;
 }
 
-function relative_modified_date(timestamp) {
-	var timediff = Math.round((new Date()).getTime() / 1000) - timestamp;
-	var diffminutes = Math.round(timediff/60);
-	var diffhours = Math.round(diffminutes/60);
-	var diffdays = Math.round(diffhours/24);
-	//var diffmonths = Math.round(diffdays/31);
-	//var diffyears = Math.round(diffdays/365);
-	if(timediff < 60) { return t('lib','seconds ago'); }
-	else if(timediff < 120) { return t('lib','1 minute ago'); }
-	else if(timediff < 3600) { return t('lib','%d minutes ago',diffminutes); }
-	//else if($timediff < 7200) { return '1 hour ago'; }
-	//else if($timediff < 86400) { return $diffhours.' hours ago'; }
-	else if(timediff < 86400) { return t('lib','today'); }
-	else if(timediff < 172800) { return t('lib','yesterday'); }
-	else if(timediff < 2678400) { return t('lib','%d days ago',diffdays); }
-	else if(timediff < 5184000) { return t('lib','last month'); }
-	else if(timediff < 31556926) { return t('lib','months ago'); }
-	else if(timediff < 63113852) { return t('lib','last year'); }
-	else { return t('lib','years ago'); }
-}
-
 function getMimeIcon(mime, ready){
 	if(getMimeIcon.cache[mime]){
 		ready(getMimeIcon.cache[mime]);
@@ -933,7 +837,7 @@ function getUniqueName(name){
 			num=parseInt(numMatch[numMatch.length-1])+1;
 			base=base.split('(')
 			base.pop();
-			base=base.join('(').trim();
+			base=$.trim(base.join('('));
 		}
 		name=base+' ('+num+')';
 		if (extension) {
