@@ -1,52 +1,53 @@
 <?php $TRANSLATIONS = array(
+"Could not move %s - File with this name already exists" => "Nelze přesunout %s - existuje soubor se stejným názvem",
+"Could not move %s" => "Nelze přesunout %s",
+"Unable to rename file" => "Nelze přejmenovat soubor",
+"No file was uploaded. Unknown error" => "Soubor nebyl odeslán. Neznámá chyba",
 "There is no error, the file uploaded with success" => "Soubor byl odeslán úspěšně",
-"The uploaded file exceeds the upload_max_filesize directive in php.ini" => "Odeslaný soubor přesáhl svou velikostí parametr upload_max_filesize v php.ini",
+"The uploaded file exceeds the upload_max_filesize directive in php.ini: " => "Odesílaný soubor přesahuje velikost upload_max_filesize povolenou v php.ini:",
 "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" => "Odeslaný soubor přesáhl svou velikostí parametr MAX_FILE_SIZE specifikovaný v formuláři HTML",
 "The uploaded file was only partially uploaded" => "Soubor byl odeslán pouze částečně",
 "No file was uploaded" => "Žádný soubor nebyl odeslán",
 "Missing a temporary folder" => "Chybí adresář pro dočasné soubory",
 "Failed to write to disk" => "Zápis na disk selhal",
+"Not enough storage available" => "Nedostatek dostupného úložného prostoru",
+"Invalid directory." => "Neplatný adresář",
 "Files" => "Soubory",
-"Unshare" => "Zrušit sdílení",
+"Share" => "Sdílet",
+"Delete permanently" => "Trvale odstranit",
 "Delete" => "Smazat",
 "Rename" => "Přejmenovat",
-"already exists" => "již existuje",
+"Pending" => "Čekající",
+"{new_name} already exists" => "{new_name} již existuje",
 "replace" => "nahradit",
 "suggest name" => "navrhnout název",
 "cancel" => "zrušit",
-"replaced" => "nahrazeno",
+"replaced {new_name} with {old_name}" => "nahrazeno {new_name} s {old_name}",
 "undo" => "zpět",
-"with" => "s",
-"unshared" => "sdílení zrušeno",
-"deleted" => "smazáno",
-"generating ZIP-file, it may take some time." => "generuji ZIP soubor, může to nějakou dobu trvat.",
+"perform delete operation" => "provést smazání",
+"'.' is an invalid file name." => "'.' je neplatným názvem souboru.",
+"File name cannot be empty." => "Název souboru nemůže být prázdný řetězec.",
+"Invalid name, '\\', '/', '<', '>', ':', '\"', '|', '?' and '*' are not allowed." => "Neplatný název, znaky '\\', '/', '<', '>', ':', '\"', '|', '?' a '*' nejsou povoleny.",
+"Your storage is full, files can not be updated or synced anymore!" => "Vaše úložiště je plné, nelze aktualizovat ani synchronizovat soubory.",
+"Your storage is almost full ({usedSpacePercent}%)" => "Vaše úložiště je téměř plné ({usedSpacePercent}%)",
+"Your download is being prepared. This might take some time if the files are big." => "Vaše soubory ke stažení se připravují. Pokud jsou velké může to chvíli trvat.",
 "Unable to upload your file as it is a directory or has 0 bytes" => "Nelze odeslat Váš soubor, protože je to adresář nebo má velikost 0 bajtů",
 "Upload Error" => "Chyba odesílání",
-"Pending" => "Čekající",
+"Close" => "Zavřít",
 "1 file uploading" => "odesílá se 1 soubor",
-"files uploading" => "souborů se odesílá",
+"{count} files uploading" => "odesílám {count} souborů",
 "Upload cancelled." => "Odesílání zrušeno.",
 "File upload is in progress. Leaving the page now will cancel the upload." => "Probíhá odesílání souboru. Opuštění stránky vyústí ve zrušení nahrávání.",
-"Invalid name, '/' is not allowed." => "Neplatný název, znak '/' není povolen",
-"files scanned" => "soubory prohledány",
-"error while scanning" => "chyba při prohledávání",
+"URL cannot be empty." => "URL nemůže být prázdná",
+"Invalid folder name. Usage of 'Shared' is reserved by Owncloud" => "Neplatný název složky. Použití 'Shared' je rezervováno pro vnitřní potřeby Owncloud",
 "Name" => "Název",
 "Size" => "Velikost",
 "Modified" => "Změněno",
-"folder" => "složka",
-"folders" => "složky",
-"file" => "soubor",
-"files" => "soubory",
-"seconds ago" => "před pár sekundami",
-"minute ago" => "před minutou",
-"minutes ago" => "před pár minutami",
-"today" => "dnes",
-"yesterday" => "včera",
-"days ago" => "před pár dny",
-"last month" => "minulý měsíc",
-"months ago" => "před pár měsíci",
-"last year" => "minulý rok",
-"years ago" => "před pár lety",
+"1 folder" => "1 složka",
+"{count} folders" => "{count} složky",
+"1 file" => "1 soubor",
+"{count} files" => "{count} soubory",
+"Upload" => "Odeslat",
 "File handling" => "Zacházení se soubory",
 "Maximum upload size" => "Maximální velikost pro odesílání",
 "max. possible: " => "největší možná: ",
@@ -58,14 +59,16 @@
 "New" => "Nový",
 "Text file" => "Textový soubor",
 "Folder" => "Složka",
-"From url" => "Z url",
-"Upload" => "Odeslat",
+"From link" => "Z odkazu",
+"Deleted files" => "Odstraněné soubory",
 "Cancel upload" => "Zrušit odesílání",
+"You don’t have write permissions here." => "Nemáte zde práva zápisu.",
 "Nothing in here. Upload something!" => "Žádný obsah. Nahrajte něco.",
-"Share" => "Sdílet",
 "Download" => "Stáhnout",
+"Unshare" => "Zrušit sdílení",
 "Upload too large" => "Odeslaný soubor je příliš velký",
 "The files you are trying to upload exceed the maximum size for file uploads on this server." => "Soubory, které se snažíte odeslat, překračují limit velikosti odesílání na tomto serveru.",
 "Files are being scanned, please wait." => "Soubory se prohledávají, prosím čekejte.",
-"Current scanning" => "Aktuální prohledávání"
+"Current scanning" => "Aktuální prohledávání",
+"Upgrading filesystem cache..." => "Aktualizuji mezipaměť souborového systému..."
 );
