@@ -1,52 +1,53 @@
 <?php $TRANSLATIONS = array(
+"Could not move %s - File with this name already exists" => "Ezin da %s mugitu - Izen hau duen fitxategia dagoeneko existitzen da",
+"Could not move %s" => "Ezin dira fitxategiak mugitu %s",
+"Unable to rename file" => "Ezin izan da fitxategia berrizendatu",
+"No file was uploaded. Unknown error" => "Ez da fitxategirik igo. Errore ezezaguna",
 "There is no error, the file uploaded with success" => "Ez da arazorik izan, fitxategia ongi igo da",
-"The uploaded file exceeds the upload_max_filesize directive in php.ini" => "Igotako fitxategiaren tamaina php.ini-ko upload_max_filesize direktiban adierazitakoa  baino handiagoa da",
+"The uploaded file exceeds the upload_max_filesize directive in php.ini: " => "Igotako fitxategiak php.ini fitxategian ezarritako upload_max_filesize muga gainditu du:",
 "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" => "Igotako fitxategiaren tamaina HTML inprimakiko MAX_FILESIZE direktiban adierazitakoa baino handiagoa da",
 "The uploaded file was only partially uploaded" => "Igotako fitxategiaren zati bat baino gehiago ez da igo",
 "No file was uploaded" => "Ez da fitxategirik igo",
 "Missing a temporary folder" => "Aldi baterako karpeta falta da",
 "Failed to write to disk" => "Errore bat izan da diskoan idazterakoan",
+"Not enough storage available" => "Ez dago behar aina leku erabilgarri,",
+"Invalid directory." => "Baliogabeko karpeta.",
 "Files" => "Fitxategiak",
-"Unshare" => "Ez partekatu",
+"Share" => "Elkarbanatu",
+"Delete permanently" => "Ezabatu betirako",
 "Delete" => "Ezabatu",
 "Rename" => "Berrizendatu",
-"already exists" => "dagoeneko existitzen da",
+"Pending" => "Zain",
+"{new_name} already exists" => "{new_name} dagoeneko existitzen da",
 "replace" => "ordeztu",
 "suggest name" => "aholkatu izena",
 "cancel" => "ezeztatu",
-"replaced" => "ordeztua",
+"replaced {new_name} with {old_name}" => " {new_name}-k {old_name} ordezkatu du",
 "undo" => "desegin",
-"with" => "honekin",
-"unshared" => "Ez partekatuta",
-"deleted" => "ezabatuta",
-"generating ZIP-file, it may take some time." => "ZIP-fitxategia sortzen ari da, denbora har dezake",
+"perform delete operation" => "Ezabatu",
+"'.' is an invalid file name." => "'.' ez da fitxategi izen baliogarria.",
+"File name cannot be empty." => "Fitxategi izena ezin da hutsa izan.",
+"Invalid name, '\\', '/', '<', '>', ':', '\"', '|', '?' and '*' are not allowed." => "IZen aliogabea, '\\', '/', '<', '>', ':', '\"', '|', '?' eta '*' ez daude baimenduta.",
+"Your storage is full, files can not be updated or synced anymore!" => "Zure biltegiratzea beterik dago, ezingo duzu aurrerantzean fitxategirik igo edo sinkronizatu!",
+"Your storage is almost full ({usedSpacePercent}%)" => "Zure biltegiratzea nahiko beterik dago (%{usedSpacePercent})",
+"Your download is being prepared. This might take some time if the files are big." => "Zure deskarga prestatu egin behar da. Denbora bat har lezake fitxategiak handiak badira. ",
 "Unable to upload your file as it is a directory or has 0 bytes" => "Ezin da zure fitxategia igo, karpeta bat da edo 0 byt ditu",
 "Upload Error" => "Igotzean errore bat suertatu da",
-"Pending" => "Zain",
+"Close" => "Itxi",
 "1 file uploading" => "fitxategi 1 igotzen",
-"files uploading" => "fitxategiak igotzen",
+"{count} files uploading" => "{count} fitxategi igotzen",
 "Upload cancelled." => "Igoera ezeztatuta",
 "File upload is in progress. Leaving the page now will cancel the upload." => "Fitxategien igoera martxan da. Orria orain uzteak igoera ezeztatutko du.",
-"Invalid name, '/' is not allowed." => "Baliogabeko izena, '/' ezin da erabili. ",
-"files scanned" => "fitxategiak eskaneatuta",
-"error while scanning" => "errore bat egon da eskaneatzen zen bitartean",
+"URL cannot be empty." => "URLa ezin da hutsik egon.",
+"Invalid folder name. Usage of 'Shared' is reserved by Owncloud" => "Baliogabeako karpeta izena. 'Shared' izena Owncloudek erreserbatzen du",
 "Name" => "Izena",
 "Size" => "Tamaina",
 "Modified" => "Aldatuta",
-"folder" => "karpeta",
-"folders" => "Karpetak",
-"file" => "fitxategia",
-"files" => "fitxategiak",
-"seconds ago" => "segundu",
-"minute ago" => "minutu",
-"minutes ago" => "minutu",
-"today" => "gaur",
-"yesterday" => "atzo",
-"days ago" => "egun",
-"last month" => "joan den hilabetean",
-"months ago" => "hilabete",
-"last year" => "joan den urtean",
-"years ago" => "urte",
+"1 folder" => "karpeta bat",
+"{count} folders" => "{count} karpeta",
+"1 file" => "fitxategi bat",
+"{count} files" => "{count} fitxategi",
+"Upload" => "Igo",
 "File handling" => "Fitxategien kudeaketa",
 "Maximum upload size" => "Igo daitekeen gehienezko tamaina",
 "max. possible: " => "max, posiblea:",
@@ -58,14 +59,16 @@
 "New" => "Berria",
 "Text file" => "Testu fitxategia",
 "Folder" => "Karpeta",
-"From url" => "URLtik",
-"Upload" => "Igo",
+"From link" => "Estekatik",
+"Deleted files" => "Ezabatutako fitxategiak",
 "Cancel upload" => "Ezeztatu igoera",
+"You don’t have write permissions here." => "Ez duzu hemen idazteko baimenik.",
 "Nothing in here. Upload something!" => "Ez dago ezer. Igo zerbait!",
-"Share" => "Elkarbanatu",
 "Download" => "Deskargatu",
+"Unshare" => "Ez elkarbanatu",
 "Upload too large" => "Igotakoa handiegia da",
 "The files you are trying to upload exceed the maximum size for file uploads on this server." => "Igotzen saiatzen ari zaren fitxategiak zerbitzari honek igotzeko onartzen duena baino handiagoak dira.",
 "Files are being scanned, please wait." => "Fitxategiak eskaneatzen ari da, itxoin mezedez.",
-"Current scanning" => "Orain eskaneatzen ari da"
+"Current scanning" => "Orain eskaneatzen ari da",
+"Upgrading filesystem cache..." => "Fitxategi sistemaren katxea eguneratzen..."
 );
