@@ -1,16 +1,20 @@
 <?php $TRANSLATIONS = array(
 "The uploaded file was only partially uploaded" => "Le file incargate solmente esseva incargate partialmente",
 "No file was uploaded" => "Nulle file esseva incargate",
+"Missing a temporary folder" => "Manca un dossier temporari",
 "Files" => "Files",
+"Share" => "Compartir",
 "Delete" => "Deler",
+"Close" => "Clauder",
 "Name" => "Nomine",
 "Size" => "Dimension",
 "Modified" => "Modificate",
+"Upload" => "Incargar",
 "Maximum upload size" => "Dimension maxime de incargamento",
+"Save" => "Salveguardar",
 "New" => "Nove",
 "Text file" => "File de texto",
 "Folder" => "Dossier",
-"Upload" => "Incargar",
 "Nothing in here. Upload something!" => "Nihil hic. Incarga alcun cosa!",
 "Download" => "Discargar",
 "Upload too large" => "Incargamento troppo longe"
