@@ -1,52 +1,52 @@
 <?php $TRANSLATIONS = array(
+"Could not move %s - File with this name already exists" => "ไม่สามารถย้าย %s ได้ - ไฟล์ที่ใช้ชื่อนี้มีอยู่แล้ว",
+"Could not move %s" => "ไม่สามารถย้าย %s ได้",
+"Unable to rename file" => "ไม่สามารถเปลี่ยนชื่อไฟล์ได้",
+"No file was uploaded. Unknown error" => "ยังไม่มีไฟล์ใดที่ถูกอัพโหลด เกิดข้อผิดพลาดที่ไม่ทราบสาเหตุ",
 "There is no error, the file uploaded with success" => "ไม่มีข้อผิดพลาดใดๆ ไฟล์ถูกอัพโหลดเรียบร้อยแล้ว",
-"The uploaded file exceeds the upload_max_filesize directive in php.ini" => "ไฟล์ที่อัพโหลดมีขนาดเกินคำสั่ง upload_max_filesize ที่ระบุเอาไว้ในไฟล์ php.ini",
+"The uploaded file exceeds the upload_max_filesize directive in php.ini: " => "ขนาดไฟล์ที่อัพโหลดมีขนาดเกิน upload_max_filesize ที่ระบุไว้ใน php.ini",
 "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" => "ไฟล์ที่อัพโหลดมีขนาดเกินคำสั่ง MAX_FILE_SIZE ที่ระบุเอาไว้ในรูปแบบคำสั่งในภาษา HTML",
 "The uploaded file was only partially uploaded" => "ไฟล์ที่อัพโหลดยังไม่ได้ถูกอัพโหลดอย่างสมบูรณ์",
 "No file was uploaded" => "ยังไม่มีไฟล์ที่ถูกอัพโหลด",
 "Missing a temporary folder" => "แฟ้มเอกสารชั่วคราวเกิดการสูญหาย",
 "Failed to write to disk" => "เขียนข้อมูลลงแผ่นดิสก์ล้มเหลว",
+"Not enough storage available" => "เหลือพื้นที่ไม่เพียงสำหรับใช้งาน",
+"Invalid directory." => "ไดเร็กทอรี่ไม่ถูกต้อง",
 "Files" => "ไฟล์",
-"Unshare" => "ยกเลิกการแชร์ข้อมูล",
+"Share" => "แชร์",
 "Delete" => "ลบ",
 "Rename" => "เปลี่ยนชื่อ",
-"already exists" => "มีอยู่แล้ว",
+"Pending" => "อยู่ระหว่างดำเนินการ",
+"{new_name} already exists" => "{new_name} มีอยู่แล้วในระบบ",
 "replace" => "แทนที่",
 "suggest name" => "แนะนำชื่อ",
 "cancel" => "ยกเลิก",
-"replaced" => "แทนที่แล้ว",
+"replaced {new_name} with {old_name}" => "แทนที่ {new_name} ด้วย {old_name} แล้ว",
 "undo" => "เลิกทำ",
-"with" => "กับ",
-"unshared" => "ยกเลิกการแชร์ข้อมูลแล้ว",
-"deleted" => "ลบแล้ว",
-"generating ZIP-file, it may take some time." => "กำลังสร้างไฟล์บีบอัด ZIP อาจใช้เวลาสักครู่",
+"perform delete operation" => "ดำเนินการตามคำสั่งลบ",
+"'.' is an invalid file name." => "'.' เป็นชื่อไฟล์ที่ไม่ถูกต้อง",
+"File name cannot be empty." => "ชื่อไฟล์ไม่สามารถเว้นว่างได้",
+"Invalid name, '\\', '/', '<', '>', ':', '\"', '|', '?' and '*' are not allowed." => "ชื่อที่ใช้ไม่ถูกต้อง, '\\', '/', '<', '>', ':', '\"', '|', '?' และ '*' ไม่ได้รับอนุญาตให้ใช้งานได้",
+"Your storage is full, files can not be updated or synced anymore!" => "พื้นที่จัดเก็บข้อมูลของคุณเต็มแล้ว ไม่สามารถอัพเดทหรือผสานไฟล์ต่างๆได้อีกต่อไป",
+"Your storage is almost full ({usedSpacePercent}%)" => "พื้นที่จัดเก็บข้อมูลของคุณใกล้เต็มแล้ว ({usedSpacePercent}%)",
+"Your download is being prepared. This might take some time if the files are big." => "กำลังเตรียมดาวน์โหลดข้อมูล หากไฟล์มีขนาดใหญ่ อาจใช้เวลาสักครู่",
 "Unable to upload your file as it is a directory or has 0 bytes" => "ไม่สามารถอัพโหลดไฟล์ของคุณได้ เนื่องจากไฟล์ดังกล่าวเป็นไดเร็กทอรี่หรือมีขนาด 0 ไบต์",
 "Upload Error" => "เกิดข้อผิดพลาดในการอัพโหลด",
-"Pending" => "อยู่ระหว่างดำเนินการ",
+"Close" => "ปิด",
 "1 file uploading" => "กำลังอัพโหลดไฟล์ 1 ไฟล์",
-"files uploading" => "การอัพโหลดไฟล์",
+"{count} files uploading" => "กำลังอัพโหลด {count} ไฟล์",
 "Upload cancelled." => "การอัพโหลดถูกยกเลิก",
 "File upload is in progress. Leaving the page now will cancel the upload." => "การอัพโหลดไฟล์กำลังอยู่ในระหว่างดำเนินการ การออกจากหน้าเว็บนี้จะทำให้การอัพโหลดถูกยกเลิก",
-"Invalid name, '/' is not allowed." => "ชื่อที่ใช้ไม่ถูกต้อง '/' ไม่อนุญาตให้ใช้งาน",
-"files scanned" => "ไฟล์ต่างๆได้รับการสแกนแล้ว",
-"error while scanning" => "พบข้อผิดพลาดในระหว่างการสแกนไฟล์",
+"URL cannot be empty." => "URL ไม่สามารถเว้นว่างได้",
+"Invalid folder name. Usage of 'Shared' is reserved by Owncloud" => "ชื่อโฟลเดอร์ไม่ถูกต้อง การใช้งาน 'แชร์' สงวนไว้สำหรับ Owncloud เท่านั้น",
 "Name" => "ชื่อ",
 "Size" => "ขนาด",
 "Modified" => "ปรับปรุงล่าสุด",
-"folder" => "โฟลเดอร์",
-"folders" => "โฟลเดอร์",
-"file" => "ไฟล์",
-"files" => "ไฟล์",
-"seconds ago" => "วินาที ก่อนหน้านี้",
-"minute ago" => "นาที ที่ผ่านมา",
-"minutes ago" => "นาที ที่ผ่านมา",
-"today" => "วันนี้",
-"yesterday" => "เมื่อวานนี้",
-"days ago" => "วัน ที่ผ่านมา",
-"last month" => "เดือนที่แล้ว",
-"months ago" => "เดือน ที่ผ่านมา",
-"last year" => "ปีที่แล้ว",
-"years ago" => "ปี ที่ผ่านมา",
+"1 folder" => "1 โฟลเดอร์",
+"{count} folders" => "{count} โฟลเดอร์",
+"1 file" => "1 ไฟล์",
+"{count} files" => "{count} ไฟล์",
+"Upload" => "อัพโหลด",
 "File handling" => "การจัดกาไฟล์",
 "Maximum upload size" => "ขนาดไฟล์สูงสุดที่อัพโหลดได้",
 "max. possible: " => "จำนวนสูงสุดที่สามารถทำได้: ",
@@ -58,14 +58,14 @@
 "New" => "อัพโหลดไฟล์ใหม่",
 "Text file" => "ไฟล์ข้อความ",
 "Folder" => "แฟ้มเอกสาร",
-"From url" => "จาก url",
-"Upload" => "อัพโหลด",
+"From link" => "จากลิงก์",
 "Cancel upload" => "ยกเลิกการอัพโหลด",
 "Nothing in here. Upload something!" => "ยังไม่มีไฟล์ใดๆอยู่ที่นี่ กรุณาอัพโหลดไฟล์!",
-"Share" => "แชร์",
 "Download" => "ดาวน์โหลด",
+"Unshare" => "ยกเลิกการแชร์ข้อมูล",
 "Upload too large" => "ไฟล์ที่อัพโหลดมีขนาดใหญ่เกินไป",
 "The files you are trying to upload exceed the maximum size for file uploads on this server." => "ไฟล์ที่คุณพยายามที่จะอัพโหลดมีขนาดเกินกว่าขนาดสูงสุดที่กำหนดไว้ให้อัพโหลดได้สำหรับเซิร์ฟเวอร์นี้",
 "Files are being scanned, please wait." => "ไฟล์กำลังอยู่ระหว่างการสแกน, กรุณารอสักครู่.",
-"Current scanning" => "ไฟล์ที่กำลังสแกนอยู่ขณะนี้"
+"Current scanning" => "ไฟล์ที่กำลังสแกนอยู่ขณะนี้",
+"Upgrading filesystem cache..." => "กำลังอัพเกรดหน่วยความจำแคชของระบบไฟล์..."
 );
