@@ -1,55 +1,52 @@
 <?php $TRANSLATIONS = array(
+"Could not move %s - File with this name already exists" => "无法移动 %s - 同名文件已存在",
+"Could not move %s" => "无法移动 %s",
+"Unable to rename file" => "无法重命名文件",
+"No file was uploaded. Unknown error" => "没有文件被上传。未知错误",
 "There is no error, the file uploaded with success" => "没有发生错误，文件上传成功。",
-"The uploaded file exceeds the upload_max_filesize directive in php.ini" => "上传的文件大小超过了php.ini 中指定的upload_max_filesize",
+"The uploaded file exceeds the upload_max_filesize directive in php.ini: " => "上传文件大小已超过php.ini中upload_max_filesize所规定的值",
 "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" => "上传的文件超过了在HTML 表单中指定的MAX_FILE_SIZE",
 "The uploaded file was only partially uploaded" => "只上传了文件的一部分",
 "No file was uploaded" => "文件没有上传",
 "Missing a temporary folder" => "缺少临时目录",
 "Failed to write to disk" => "写入磁盘失败",
+"Invalid directory." => "无效文件夹。",
 "Files" => "文件",
-"Unshare" => "取消分享",
+"Share" => "分享",
+"Delete permanently" => "永久删除",
 "Delete" => "删除",
 "Rename" => "重命名",
-"already exists" => "已经存在",
+"Pending" => "操作等待中",
+"{new_name} already exists" => "{new_name} 已存在",
 "replace" => "替换",
 "suggest name" => "建议名称",
 "cancel" => "取消",
-"replaced" => "已经替换",
+"replaced {new_name} with {old_name}" => "已将 {old_name}替换成 {new_name}",
 "undo" => "撤销",
-"with" => "随着",
-"unshared" => "已取消分享",
-"deleted" => "已经删除",
-"generating ZIP-file, it may take some time." => "正在生成 ZIP 文件，可能需要一些时间",
+"'.' is an invalid file name." => "'.' 是一个无效的文件名。",
+"File name cannot be empty." => "文件名不能为空。",
+"Invalid name, '\\', '/', '<', '>', ':', '\"', '|', '?' and '*' are not allowed." => "无效名称，'\\', '/', '<', '>', ':', '\"', '|', '?' 和 '*' 不被允许使用。",
+"Your download is being prepared. This might take some time if the files are big." => "下载正在准备中。如果文件较大可能会花费一些时间。",
 "Unable to upload your file as it is a directory or has 0 bytes" => "无法上传文件，因为它是一个目录或者大小为 0 字节",
 "Upload Error" => "上传错误",
-"Pending" => "操作等待中",
+"Close" => "关闭",
 "1 file uploading" => "1个文件上传中",
-"files uploading" => "文件上传中",
+"{count} files uploading" => "{count} 个文件上传中",
 "Upload cancelled." => "上传已取消",
 "File upload is in progress. Leaving the page now will cancel the upload." => "文件正在上传中。现在离开此页会导致上传动作被取消。",
-"Invalid name, '/' is not allowed." => "非法的名称，不允许使用‘/’。",
-"files scanned" => "已扫描文件",
-"error while scanning" => "扫描时出错",
+"URL cannot be empty." => "URL不能为空",
+"Invalid folder name. Usage of 'Shared' is reserved by Owncloud" => "无效文件夹名。'共享' 是 Owncloud 预留的文件夹名。",
 "Name" => "名称",
 "Size" => "大小",
 "Modified" => "修改日期",
-"folder" => "文件夹",
-"folders" => "文件夹",
-"file" => "文件",
-"files" => "文件",
-"seconds ago" => "几秒前",
-"minute ago" => "1分钟前",
-"minutes ago" => "分钟前",
-"today" => "今天",
-"yesterday" => "昨天",
-"days ago" => "%d 天前",
-"last month" => "上月",
-"months ago" => "月前",
-"last year" => "上年",
-"years ago" => "几年前",
+"1 folder" => "1个文件夹",
+"{count} folders" => "{count} 个文件夹",
+"1 file" => "1 个文件",
+"{count} files" => "{count} 个文件",
+"Upload" => "上传",
 "File handling" => "文件处理",
 "Maximum upload size" => "最大上传大小",
-"max. possible: " => "最大可能: ",
+"max. possible: " => "最大允许: ",
 "Needed for multi-file and folder downloads." => "多文件和文件夹下载需要此项。",
 "Enable ZIP-download" => "启用 ZIP 下载",
 "0 is unlimited" => "0 为无限制",
@@ -58,14 +55,13 @@
 "New" => "新建",
 "Text file" => "文本文件",
 "Folder" => "文件夹",
-"From url" => "来自地址",
-"Upload" => "上传",
+"From link" => "来自链接",
 "Cancel upload" => "取消上传",
 "Nothing in here. Upload something!" => "这里还什么都没有。上传些东西吧！",
-"Share" => "共享",
 "Download" => "下载",
+"Unshare" => "取消分享",
 "Upload too large" => "上传文件过大",
-"The files you are trying to upload exceed the maximum size for file uploads on this server." => "您正尝试上传的文件超过了此服务器可以上传的最大大小",
+"The files you are trying to upload exceed the maximum size for file uploads on this server." => "您正尝试上传的文件超过了此服务器可以上传的最大容量限制",
 "Files are being scanned, please wait." => "文件正在被扫描，请稍候。",
 "Current scanning" => "当前扫描"
 );
