@@ -2,16 +2,17 @@
 "Access granted" => "Sarrera baimendua",
 "Error configuring Dropbox storage" => "Errore bat egon da Dropbox biltegiratzea konfiguratzean",
 "Grant access" => "Baimendu sarrera",
-"Fill out all required fields" => "Bete eskatutako eremu guztiak",
 "Please provide a valid Dropbox app key and secret." => "Mesedez eman baliozkoa den Dropbox app giltza eta sekretua",
 "Error configuring Google Drive storage" => "Errore bat egon da Google Drive biltegiratzea konfiguratzean",
+"<b>Warning:</b> \"smbclient\" is not installed. Mounting of CIFS/SMB shares is not possible. Please ask your system administrator to install it." => "<b>Abisua:</b> \"smbclient\" ez dago instalatuta. CIFS/SMB partekatutako karpetak montatzea ez da posible. Mesedez eskatu zure sistema kudeatzaileari instalatzea.",
+"<b>Warning:</b> The FTP support in PHP is not enabled or installed. Mounting of FTP shares is not possible. Please ask your system administrator to install it." => "<b>Abisua:</b> PHPren FTP modulua ez dago instalatuta edo gaitua. FTP partekatutako karpetak montatzea ez da posible. Mesedez eskatu zure sistema kudeatzaileari instalatzea.",
 "External Storage" => "Kanpoko Biltegiratzea",
-"Mount point" => "Montatze puntua",
-"Backend" => "Motorra",
+"Folder name" => "Karpetaren izena",
+"External storage" => "Kanpoko biltegiratzea",
 "Configuration" => "Konfigurazioa",
 "Options" => "Aukerak",
 "Applicable" => "Aplikagarria",
-"Add mount point" => "Gehitu muntatze puntua",
+"Add storage" => "Gehitu biltegiratzea",
 "None set" => "Ezarri gabe",
 "All Users" => "Erabiltzaile guztiak",
 "Groups" => "Taldeak",
