@@ -2,16 +2,15 @@
 "Access granted" => "Accès autorisé",
 "Error configuring Dropbox storage" => "Erreur lors de la configuration du support de stockage Dropbox",
 "Grant access" => "Autoriser l'accès",
-"Fill out all required fields" => "Veuillez remplir tous les champs requis",
 "Please provide a valid Dropbox app key and secret." => "Veuillez fournir une clé d'application (app key) ainsi qu'un mot de passe valides.",
 "Error configuring Google Drive storage" => "Erreur lors de la configuration du support de stockage Google Drive",
+"<b>Warning:</b> \"smbclient\" is not installed. Mounting of CIFS/SMB shares is not possible. Please ask your system administrator to install it." => "<b>Attention : </b> \"smbclient\" n'est pas installé. Le montage des partages CIFS/SMB n'est pas disponible. Contactez votre administrateur système pour l'installer.",
+"<b>Warning:</b> The FTP support in PHP is not enabled or installed. Mounting of FTP shares is not possible. Please ask your system administrator to install it." => "<b>Attention : </b> Le support FTP de PHP n'est pas activé ou installé. Le montage des partages FTP n'est pas disponible. Contactez votre administrateur système pour l'installer.",
 "External Storage" => "Stockage externe",
-"Mount point" => "Point de montage",
-"Backend" => "Infrastructure",
+"Folder name" => "Nom du dossier",
 "Configuration" => "Configuration",
 "Options" => "Options",
 "Applicable" => "Disponible",
-"Add mount point" => "Ajouter un point de montage",
 "None set" => "Aucun spécifié",
 "All Users" => "Tous les utilisateurs",
 "Groups" => "Groupes",
