@@ -2,16 +2,17 @@
 "Access granted" => "アクセスは許可されました",
 "Error configuring Dropbox storage" => "Dropboxストレージの設定エラー",
 "Grant access" => "アクセスを許可",
-"Fill out all required fields" => "すべての必須フィールドを埋めて下さい",
 "Please provide a valid Dropbox app key and secret." => "有効なDropboxアプリのキーとパスワードを入力して下さい。",
 "Error configuring Google Drive storage" => "Googleドライブストレージの設定エラー",
+"<b>Warning:</b> \"smbclient\" is not installed. Mounting of CIFS/SMB shares is not possible. Please ask your system administrator to install it." => "<b>警告:</b> \"smbclient\" はインストールされていません。CIFS/SMB 共有のマウントはできません。システム管理者にインストールをお願いして下さい。",
+"<b>Warning:</b> The FTP support in PHP is not enabled or installed. Mounting of FTP shares is not possible. Please ask your system administrator to install it." => "<b>警告:</b> PHPのFTPサポートは無効もしくはインストールされていません。FTP共有のマウントはできません。システム管理者にインストールをお願いして下さい。",
 "External Storage" => "外部ストレージ",
-"Mount point" => "マウントポイント",
-"Backend" => "バックエンド",
+"Folder name" => "フォルダ名",
+"External storage" => "外部ストレージ",
 "Configuration" => "設定",
 "Options" => "オプション",
 "Applicable" => "適用範囲",
-"Add mount point" => "マウントポイントを追加",
+"Add storage" => "ストレージを追加",
 "None set" => "未設定",
 "All Users" => "すべてのユーザ",
 "Groups" => "グループ",
