@@ -1,7 +1,11 @@
 <?php $TRANSLATIONS = array(
 "Save" => "Desa",
+"Search:" => "Cerca:",
 "Close" => "Tanca",
+"Next" => "Següent",
+"Clear" => "Neteja",
 "Saving..." => "Desant...",
+"Failed to save file" => "Ha fallat en desar el fitxer",
 "An error occurred!" => "S'ha produït un error!",
 "There were unsaved changes, click here to go back" => "Hi havia canvis que no desats, feu click aquí per anar enrera"
 );
