@@ -1,7 +1,11 @@
 <?php $TRANSLATIONS = array(
 "Save" => "Gem",
+"Search:" => "Søg:",
 "Close" => "Luk",
+"Next" => "Næste",
+"Clear" => "Ryd",
 "Saving..." => "Gemmer...",
+"Failed to save file" => "Kunne ikke gemme filen",
 "An error occurred!" => "Der opstod en fejl!",
 "There were unsaved changes, click here to go back" => "Ændringer blev ikke gemt - klik her for at gå tilbage"
 );
