@@ -1,7 +1,11 @@
 <?php $TRANSLATIONS = array(
 "Save" => "Enregistrer",
+"Search:" => "Recherche:",
 "Close" => "Fermer",
+"Next" => "Suivant",
+"Clear" => "Effacer",
 "Saving..." => "Enregistrement...",
+"Failed to save file" => "Impossible d'enregistrer le fichier",
 "An error occurred!" => "Une erreur est survenue !",
 "There were unsaved changes, click here to go back" => "Certaines modifications n'ont pas été sauvegardées, cliquez ici pour revenir"
 );
