@@ -1,7 +1,11 @@
 <?php $TRANSLATIONS = array(
 "Save" => "Salva",
+"Search:" => "Ricerca:",
 "Close" => "Chiudi",
+"Next" => "Successivo",
+"Clear" => "Cancella",
 "Saving..." => "Salvataggio in corso...",
+"Failed to save file" => "Salvataggio del file non riuscito",
 "An error occurred!" => "Si è verificato un errore!",
 "There were unsaved changes, click here to go back" => "C'erano delle modifiche non salvate, fai clic qui per tornare indietro"
 );
