@@ -1,7 +1,11 @@
 <?php $TRANSLATIONS = array(
 "Save" => "Zapisz",
+"Search:" => "Szukaj:",
 "Close" => "Zamknij",
+"Next" => "Następny",
+"Clear" => "Wyczyść",
 "Saving..." => "Zapisywanie...",
+"Failed to save file" => "Błąd zapisu pliku",
 "An error occurred!" => "Wystąpił błąd!",
 "There were unsaved changes, click here to go back" => "Są niezapisane zmiany, kliknij żeby wrócić"
 );
