@@ -1,7 +1,11 @@
 <?php $TRANSLATIONS = array(
 "Save" => "Guardar",
+"Search:" => "Pesquisa:",
 "Close" => "Fechar",
+"Next" => "Próxima",
+"Clear" => "Limpar.",
 "Saving..." => "A guardar...",
+"Failed to save file" => "Erro a salvar o ficheiro!",
 "An error occurred!" => "Ocorreu um erro!",
 "There were unsaved changes, click here to go back" => "Houve alterações que não foram guardadas, click aqui para voltar atrás"
 );
