@@ -1,7 +1,11 @@
 <?php $TRANSLATIONS = array(
 "Save" => "保存",
+"Search:" => "搜索：",
 "Close" => "关闭",
+"Next" => "下一个",
+"Clear" => "清除",
 "Saving..." => "保存中",
+"Failed to save file" => "无法保存文件",
 "An error occurred!" => "发生错误！",
 "There were unsaved changes, click here to go back" => "有未保存的变更，点击回退"
 );
