@@ -1,9 +1,6 @@
 <?php $TRANSLATIONS = array(
 "Pictures" => "Obrázky",
-"Galleries" => "Galerie",
-"Share gallery" => "Sdílet galerii",
-"Error: " => "Chyba: ",
-"Internal error" => "Vnitřní chyba",
-"Slideshow" => "Prezentace",
+"Shared by" => "Sdílí",
+"Share" => "Sdílet",
 "The \"Image Viewer\" application also need to be enabled to use this application." => "Aplikace \"Prohlížeč obrázků\" musí být také povolena pro použití této aplikace."
 );
