@@ -1,9 +1,6 @@
 <?php $TRANSLATIONS = array(
 "Pictures" => "Billeder",
-"Galleries" => "Gallerier",
-"Share gallery" => "Del galleri",
-"Error: " => "Fejl: ",
-"Internal error" => "Intern fejl",
-"Slideshow" => "Billedpræsentation",
+"Shared by" => "Delt af",
+"Share" => "Del",
 "The \"Image Viewer\" application also need to be enabled to use this application." => "Applikationen \"Image Viewer\" skal også aktiveres for at bruge denne applikation."
 );
