@@ -1,9 +1,6 @@
 <?php $TRANSLATIONS = array(
 "Pictures" => "Bilder",
-"Galleries" => "Galerien",
-"Share gallery" => "Galerie freigeben",
-"Error: " => "Fehler:",
-"Internal error" => "Interner Fehler",
-"Slideshow" => "Slideshow",
+"Shared by" => "Geteilt von ",
+"Share" => "Teilen",
 "The \"Image Viewer\" application also need to be enabled to use this application." => "Die Anwendung \"Image Viewer\" muss aktiviert sein, damit Du diese Anwendung benutzen kannst."
 );
