@@ -1,9 +1,6 @@
 <?php $TRANSLATIONS = array(
 "Pictures" => "Pildid",
-"Galleries" => "Galeriid",
-"Share gallery" => "Jaga galeriid",
-"Error: " => "Viga: ",
-"Internal error" => "Sisemine viga",
-"Slideshow" => "Slaidiseanss",
+"Shared by" => "Jagas",
+"Share" => "Jaga",
 "The \"Image Viewer\" application also need to be enabled to use this application." => "\"Pildivaataja\" rakendus tuleb sisse lülitada, et seda rakendust kasutada."
 );
