@@ -1,9 +1,6 @@
 <?php $TRANSLATIONS = array(
 "Pictures" => "Images",
-"Galleries" => "Galerie",
-"Share gallery" => "Partager la galerie",
-"Error: " => "Erreur :",
-"Internal error" => "Erreur interne",
-"Slideshow" => "Diaporama",
+"Shared by" => "Partager par",
+"Share" => "Partager",
 "The \"Image Viewer\" application also need to be enabled to use this application." => "L'application \"Visualiseur d'Image\" nécessite d'être autorisée à utiliser cette application."
 );
