@@ -1,9 +1,6 @@
 <?php $TRANSLATIONS = array(
 "Pictures" => "Immagini",
-"Galleries" => "Gallerie",
-"Share gallery" => "Condividi la galleria",
-"Error: " => "Errore: ",
-"Internal error" => "Errore interno",
-"Slideshow" => "Presentazione",
+"Shared by" => "Condiviso da",
+"Share" => "Condividi",
 "The \"Image Viewer\" application also need to be enabled to use this application." => "Per utilizzare questa applicazione deve essere abilitato anche il \"Visualizzatore immagini\"."
 );
