@@ -1,9 +1,6 @@
 <?php $TRANSLATIONS = array(
 "Pictures" => "Imagens",
-"Galleries" => "Galerias",
-"Share gallery" => "Partilhar a galeria",
-"Error: " => "Erro: ",
-"Internal error" => "Erro interno",
-"Slideshow" => "Slideshow",
+"Shared by" => "Partilhado por",
+"Share" => "Partilhar",
 "The \"Image Viewer\" application also need to be enabled to use this application." => "A aplicação \"Image Viewer\" também precisa de estar activada para usar esta aplicação."
 );
