@@ -1,9 +1,6 @@
 <?php $TRANSLATIONS = array(
 "Pictures" => "Рисунки",
-"Galleries" => "Галереи",
-"Share gallery" => "Опубликовать",
-"Error: " => "Ошибка: ",
-"Internal error" => "Внутренняя ошибка",
-"Slideshow" => "Слайдшоу",
+"Shared by" => "Опубликовано",
+"Share" => "Открыть доступ",
 "The \"Image Viewer\" application also need to be enabled to use this application." => "Для работы этого приложения необходимо включить приложение \"Image Viewer\"."
 );
