@@ -1,9 +1,5 @@
 <?php $TRANSLATIONS = array(
 "Pictures" => "相片",
-"Galleries" => "相册",
-"Share gallery" => "分享相册",
-"Error: " => "错误：",
-"Internal error" => "内部错误",
-"Slideshow" => "幻灯片",
+"Share" => "分享",
 "The \"Image Viewer\" application also need to be enabled to use this application." => "使用此应用需同时启用\"相片查看器\"应用。"
 );
