@@ -2,6 +2,7 @@
 "Music" => "Hudba",
 "songs" => "skladby",
 "albums" => "alba",
+"Add to playlist" => "Přidat do seznamu skladeb",
 "Add album to playlist" => "Přidat album do seznamu skladeb",
 "Play" => "Přehrát",
 "Pause" => "Pozastavit",
@@ -12,5 +13,7 @@
 "Rescan Collection" => "Znovu prohledat",
 "Artist" => "Umělec",
 "Album" => "Album",
-"Title" => "Název"
+"Title" => "Název",
+"Media" => "Média",
+"Ampache address:" => "Adresa ampache:"
 );
