@@ -1,5 +1,8 @@
 <?php $TRANSLATIONS = array(
 "Music" => "Musik",
+"songs" => "sange",
+"albums" => "albummer",
+"Add to playlist" => "Føj til afspilningsliste",
 "Add album to playlist" => "Tilføj album til afspilningsliste",
 "Play" => "Afspil",
 "Pause" => "Pause",
@@ -10,5 +13,7 @@
 "Rescan Collection" => "Genskan Samling",
 "Artist" => "Kunstner",
 "Album" => "Album",
-"Title" => "Titel"
+"Title" => "Titel",
+"Media" => "Medier",
+"Ampache address:" => "Ampache-adresse:"
 );
