@@ -2,6 +2,7 @@
 "Music" => "Μουσική",
 "songs" => "τραγούδια",
 "albums" => "άλμπουμ",
+"Add to playlist" => "Προσθήκη στην λίστα αναπαραγωγής",
 "Add album to playlist" => "Προσθήκη άλμπουμ στην λίστα αναπαραγωγής",
 "Play" => "Αναπαραγωγή",
 "Pause" => "Παύση",
@@ -12,5 +13,7 @@
 "Rescan Collection" => "Επανασάρωση συλλογής",
 "Artist" => "Καλλιτέχνης",
 "Album" => "Άλμπουμ",
-"Title" => "Τίτλος"
+"Title" => "Τίτλος",
+"Media" => "Πολυμέσα",
+"Ampache address:" => "Διεύθυνση Ampache:"
 );
