@@ -2,6 +2,7 @@
 "Music" => "Musika",
 "songs" => "abestiak",
 "albums" => "albumak",
+"Add to playlist" => "Gehitu erreprodukzio zerrendara",
 "Add album to playlist" => "Gehitu albuma erreprodukzio zerrendara",
 "Play" => "Erreproduzitu",
 "Pause" => "Pausarazi",
@@ -12,5 +13,7 @@
 "Rescan Collection" => "Bireskaneatu Bilduma",
 "Artist" => "Artista",
 "Album" => "Albuma",
-"Title" => "Izenburua"
+"Title" => "Izenburua",
+"Media" => "Medioa",
+"Ampache address:" => "Ampache helbidea:"
 );
