@@ -2,6 +2,7 @@
 "Music" => "ミュージック",
 "songs" => "曲",
 "albums" => "アルバム",
+"Add to playlist" => "プレイリストに追加",
 "Add album to playlist" => "アルバムをプレイリストに追加",
 "Play" => "再生",
 "Pause" => "一時停止",
@@ -12,5 +13,7 @@
 "Rescan Collection" => "コレクションの再スキャン",
 "Artist" => "アーティスト",
 "Album" => "アルバム",
-"Title" => "曲名"
+"Title" => "曲名",
+"Media" => "メディア",
+"Ampache address:" => "Ampache アドレス:"
 );
