@@ -1,5 +1,8 @@
 <?php $TRANSLATIONS = array(
 "Music" => "Muziek",
+"songs" => "Nummers",
+"albums" => "Albums",
+"Add to playlist" => "Voeg aan de afspeellijst toe",
 "Add album to playlist" => "Voeg album toe aan afspeellijst",
 "Play" => "Afspelen",
 "Pause" => "Pauzeer",
@@ -10,5 +13,7 @@
 "Rescan Collection" => "Collectie opnieuw scannen",
 "Artist" => "Artiest",
 "Album" => "Album",
-"Title" => "Titel"
+"Title" => "Titel",
+"Media" => "Media",
+"Ampache address:" => "Ampache adres:"
 );
