@@ -1,5 +1,9 @@
 <?php $TRANSLATIONS = array(
 "Music" => "Музика",
+"songs" => "нумере",
+"albums" => "албуми",
+"Add to playlist" => "Додај на листу",
+"Add album to playlist" => "Додај албум на листу",
 "Play" => "Пусти",
 "Pause" => "Паузирај",
 "Previous" => "Претходна",
