@@ -2,6 +2,7 @@
 "Music" => "เพลง",
 "songs" => "เพลง",
 "albums" => "อัลบั้ม",
+"Add to playlist" => "เพิ่มเข้าไปยังรายการเปิดเล่น",
 "Add album to playlist" => "เพิ่มอัลบั้มเข้าไปยังเพลย์ลิสต์",
 "Play" => "เล่น",
 "Pause" => "หยุดชั่วคราว",
@@ -12,5 +13,7 @@
 "Rescan Collection" => "ตรวจสอบไฟล์ที่เก็บไว้อีกครั้ง",
 "Artist" => "ศิลปิน",
 "Album" => "อัลบั้ม",
-"Title" => "ชื่อ"
+"Title" => "ชื่อ",
+"Media" => "ไฟล์มีเดีย",
+"Ampache address:" => "ที่อยู่ Ampache:"
 );
