@@ -1,5 +1,8 @@
 <?php $TRANSLATIONS = array(
 "Music" => "Müzik",
+"songs" => "şarkılar",
+"albums" => "albümler",
+"Add to playlist" => "Çalma listesine ekle",
 "Add album to playlist" => "Albümü çalma listesine ekle",
 "Play" => "Oynat",
 "Pause" => "Beklet",
