@@ -1,6 +1,9 @@
 <?php $TRANSLATIONS = array(
 "Invalid date/time" => "Ugyldig dato/tid",
 "Tasks" => "Opgaver",
+"Due" => "På grund af",
+"List" => "Liste",
+"Location" => "Placering",
 "No category" => "Ingen kategori",
 "Unspecified" => "Uspecificeret",
 "1=highest" => "1=højeste",
