@@ -124,7 +124,7 @@ class GROUP_LDAP extends lib\Access implements \OCP\GroupInterface {
 			$this->connection->ldapGroupFilter,
 			$this->connection->ldapGroupMemberAssocAttr.'='.$uid
 		));
-		$groups = $this->fetchListOfGroups($filter, array($this->connection->ldapGroupDisplayName,'dn'));
+		$groups = $this->fetchListOfGroups($filter, array($this->connection->ldapGroupDisplayName, 'dn'));
 		$groups = array_unique($this->ownCloudGroupNames($groups), SORT_LOCALE_STRING);
 		$this->connection->writeToCache($cacheKey, $groups);
 
@@ -139,61 +139,96 @@ class GROUP_LDAP extends lib\Access implements \OCP\GroupInterface {
 		if(!$this->enabled) {
 			return array();
 		}
-		$this->groupSearch = $search;
-		if($this->connection->isCached('usersInGroup'.$gid)) {
-			$groupUsers = $this->connection->getFromCache('usersInGroup'.$gid);
-			if(!empty($this->groupSearch)) {
-				$groupUsers = array_filter($groupUsers, array($this, 'groupMatchesFilter'));
-			}
-			if($limit == -1) {
-				$limit = null;
-			}
-			return array_slice($groupUsers, $offset, $limit);
+		if(!$this->groupExists($gid)) {
+			return array();
+		}
+		$cachekey = 'usersInGroup-'.$gid.'-'.$search.'-'.$limit.'-'.$offset;
+		// check for cache of the exact query
+		$groupUsers = $this->connection->getFromCache($cachekey);
+		if(!is_null($groupUsers)) {
+			return $groupUsers;
 		}
 
+		// check for cache of the query without limit and offset
+		$groupUsers = $this->connection->getFromCache('usersInGroup-'.$gid.'-'.$search);
+		if(!is_null($groupUsers)) {
+			$groupUsers = array_slice($groupUsers, $offset, $limit);
+			$this->connection->writeToCache($cachekey, $groupUsers);
+			return $groupUsers;
+		}
+
+		if($limit == -1) {
+			$limit = null;
+		}
 		$groupDN = $this->groupname2dn($gid);
 		if(!$groupDN) {
-			$this->connection->writeToCache('usersInGroup'.$gid, array());
+			// group couldn't be found, return empty resultset
+			$this->connection->writeToCache($cachekey, array());
 			return array();
 		}
 
 		$members = $this->readAttribute($groupDN, $this->connection->ldapGroupMemberAssocAttr);
 		if(!$members) {
-			$this->connection->writeToCache('usersInGroup'.$gid, array());
+			//in case users could not be retrieved, return empty resultset
+			$this->connection->writeToCache($cachekey, array());
 			return array();
 		}
 
-		$result = array();
+		$groupUsers = array();
 		$isMemberUid = (strtolower($this->connection->ldapGroupMemberAssocAttr) == 'memberuid');
 		foreach($members as $member) {
 			if($isMemberUid) {
-				$filter = \OCP\Util::mb_str_replace('%uid', $member, $this->connection->ldapLoginFilter, 'UTF-8');
+				//we got uids, need to get their DNs to 'tranlsate' them to usernames
+				$filter = $this->combineFilterWithAnd(array(
+					\OCP\Util::mb_str_replace('%uid', $member,
+						$this->connection->ldapLoginFilter, 'UTF-8'),
+					$this->getFilterPartForUserSearch($search)
+				));
 				$ldap_users = $this->fetchListOfUsers($filter, 'dn');
 				if(count($ldap_users) < 1) {
 					continue;
 				}
-				$result[] = $this->dn2username($ldap_users[0]);
-				continue;
+				$groupUsers[] = $this->dn2username($ldap_users[0]);
 			} else {
+				//we got DNs, check if we need to filter by search or we can give back all of them
+				if(!empty($search)) {
+					if(!$this->readAttribute($member,
+						$this->connection->ldapUserDisplayName,
+						$this->getFilterPartForUserSearch($search))) {
+						continue;
+					}
+				}
+				// dn2username will also check if the users belong to the allowed base
 				if($ocname = $this->dn2username($member)) {
-					$result[] = $ocname;
+					$groupUsers[] = $ocname;
 				}
 			}
 		}
-		if(!$isMemberUid) {
-			$result = array_intersect($result, \OCP\User::getUsers());
-		}
-		$groupUsers = array_unique($result, SORT_LOCALE_STRING);
-		$this->connection->writeToCache('usersInGroup'.$gid, $groupUsers);
+		natsort($groupUsers);
+		$this->connection->writeToCache('usersInGroup-'.$gid.'-'.$search, $groupUsers);
+		$groupUsers = array_slice($groupUsers, $offset, $limit);
+		$this->connection->writeToCache($cachekey, $groupUsers);
 
-		if(!empty($this->groupSearch)) {
-			$groupUsers = array_filter($groupUsers, array($this, 'groupMatchesFilter'));
-		}
-		if($limit == -1) {
-			$limit = null;
-		}
-		return array_slice($groupUsers, $offset, $limit);
+		return $groupUsers;
+	}
 
+	/**
+	 * @brief get a list of all display names in a group
+	 * @returns array with display names (value) and user ids(key)
+	 */
+	public function displayNamesInGroup($gid, $search, $limit, $offset) {
+		if(!$this->enabled) {
+			return array();
+		}
+		if(!$this->groupExists($gid)) {
+			return array();
+		}
+		$users = $this->usersInGroup($gid, $search, $limit, $offset);
+		$displayNames = array();
+		foreach($users as $user) {
+			$displayNames[$user] = \OC_User::getDisplayName($user);
+		}
+		return $displayNames;
 	}
 
 	/**
@@ -206,22 +241,31 @@ class GROUP_LDAP extends lib\Access implements \OCP\GroupInterface {
 		if(!$this->enabled) {
 			return array();
 		}
+		$cachekey = 'getGroups-'.$search.'-'.$limit.'-'.$offset;
 
-		if($this->connection->isCached('getGroups')) {
-			$ldap_groups = $this->connection->getFromCache('getGroups');
-		} else {
-			$ldap_groups = $this->fetchListOfGroups($this->connection->ldapGroupFilter, array($this->connection->ldapGroupDisplayName, 'dn'));
-			$ldap_groups = $this->ownCloudGroupNames($ldap_groups);
-			$this->connection->writeToCache('getGroups', $ldap_groups);
+		//Check cache before driving unnecessary searches
+		\OCP\Util::writeLog('user_ldap', 'getGroups '.$cachekey, \OCP\Util::DEBUG);
+		$ldap_groups = $this->connection->getFromCache($cachekey);
+		if(!is_null($ldap_groups)) {
+			return $ldap_groups;
 		}
-		$this->groupSearch = $search;
-		if(!empty($this->groupSearch)) {
-			$ldap_groups = array_filter($ldap_groups, array($this, 'groupMatchesFilter'));
-		}
-		if($limit = -1) {
+
+		// if we'd pass -1 to LDAP search, we'd end up in a Protocol
+		// error. With a limit of 0, we get 0 results. So we pass null.
+		if($limit <= 0) {
 			$limit = null;
 		}
-		return array_slice($ldap_groups, $offset, $limit);
+		$filter = $this->combineFilterWithAnd(array(
+			$this->connection->ldapGroupFilter,
+			$this->getFilterPartForGroupSearch($search)
+		));
+		\OCP\Util::writeLog('user_ldap', 'getGroups Filter '.$filter, \OCP\Util::DEBUG);
+		$ldap_groups = $this->fetchListOfGroups($filter, array($this->connection->ldapGroupDisplayName, 'dn'),
+			$limit, $offset);
+		$ldap_groups = $this->ownCloudGroupNames($ldap_groups);
+
+		$this->connection->writeToCache($cachekey, $ldap_groups);
+		return $ldap_groups;
 	}
 
 	public function groupMatchesFilter($group) {
@@ -265,7 +309,6 @@ class GROUP_LDAP extends lib\Access implements \OCP\GroupInterface {
 	* compared with OC_USER_BACKEND_CREATE_USER etc.
 	*/
 	public function implementsActions($actions) {
-		//always returns false, because possible actions are modifying actions. We do not write to LDAP, at least for now.
-		return false;
+		return (bool)(OC_GROUP_BACKEND_GET_DISPLAYNAME	& $actions);
 	}
-}
\ No newline at end of file
+}
