@@ -20,7 +20,7 @@
 *
 */
 
-class Test_Group_Ldap extends UnitTestCase {
+class Test_Group_Ldap extends PHPUnit_Framework_TestCase {
 	function setUp() {
 		OC_Group::clearBackends();
 	}
@@ -29,18 +29,18 @@ class Test_Group_Ldap extends UnitTestCase {
 		OC_Group::useBackend(new OCA\user_ldap\GROUP_LDAP());
 		$group_ldap = new OCA\user_ldap\GROUP_LDAP();
 
-		$this->assertIsA(OC_Group::getGroups(),gettype(array()));
-		$this->assertIsA($group_ldap->getGroups(),gettype(array()));
+		$this->assertIsA(OC_Group::getGroups(), gettype(array()));
+		$this->assertIsA($group_ldap->getGroups(), gettype(array()));
 
-		$this->assertFalse(OC_Group::inGroup('john','dosers'),gettype(false));
-		$this->assertFalse($group_ldap->inGroup('john','dosers'),gettype(false));
+		$this->assertFalse(OC_Group::inGroup('john', 'dosers'), gettype(false));
+		$this->assertFalse($group_ldap->inGroup('john', 'dosers'), gettype(false));
 		//TODO: check also for expected true result. This backend won't be able to do any modifications, maybe use a dummy for this.
 
-		$this->assertIsA(OC_Group::getUserGroups('john doe'),gettype(array()));
-		$this->assertIsA($group_ldap->getUserGroups('john doe'),gettype(array()));
+		$this->assertIsA(OC_Group::getUserGroups('john doe'), gettype(array()));
+		$this->assertIsA($group_ldap->getUserGroups('john doe'), gettype(array()));
 
-		$this->assertIsA(OC_Group::usersInGroup('campers'),gettype(array()));
-		$this->assertIsA($group_ldap->usersInGroup('campers'),gettype(array()));
+		$this->assertIsA(OC_Group::usersInGroup('campers'), gettype(array()));
+		$this->assertIsA($group_ldap->usersInGroup('campers'), gettype(array()));
 	}
 
 }
