@@ -2,7 +2,7 @@ $(document).ready(function(){
     // Do the export
 	$('#exportbtn').click(function(){
 		// Show loader
-		$('.loading').show();
+		$('.loadingexport').show();
 		$.getJSON(
 			OC.filePath('user_migrate','ajax','export.php'),
 			{operation:'create'},
@@ -15,13 +15,21 @@ $(document).ready(function(){
 				} else {
 					// Cancel loading
 					$('#exportbtn').html('Failed');
-					// Show Dialog	
-					OC.dialogs.alert(t('user_migrate', 'Something went wrong while the export file was being generated'), t('user_migrate', 'An error has occurred'), function(){ 
-						$('#exportbtn').html(t('user_migrate', 'Export')+'<img style="display: none;" class="loading" src="'+OC.filePath('core','img','loading.gif')+'" />'); 
+					// Show Dialog
+					OC.dialogs.alert(t('user_migrate', 'Something went wrong while the export file was being generated'), t('user_migrate', 'An error has occurred'), function(){
+						$('#exportbtn').html(t('user_migrate', 'Export')+'<img class="loadingexport" src="'+OC.filePath('core','img','loading.gif')+'" />');
 					});
 				}
 			}
 		// End ajax
 		);
 	});
+	
+	// Do the import
+	$('#importbtn').click(function(){
+		// Show loader
+		$('.loadingimport').show();
+		$('#import').submit();
+		
+	});
 });
\ No newline at end of file
