@@ -1,10 +1,13 @@
 <?php $TRANSLATIONS = array(
+"OpenID Changed" => "OpenID změněno",
+"Invalid request" => "Neplatný požadavek",
 "This is an OpenID server endpoint. For more information, see " => "Koncový bod serveru OpenID. Více informací na",
 "Identity: <b>" => "Identita: <b>",
 "Realm: <b>" => "Doména: <b>",
 "User: <b>" => "Uživatel: <b>",
 "Login" => "Přihlášení",
 "Error: <b>No user Selected" => "Chyba: <b>Není vybrán žádný uživatel",
+"OpenID" => "OpenID",
 "you can authenticate to other sites with this address" => "s touto adresou se můžete ověřit k dalším stránkám",
 "Authorized OpenID provider" => "Ověřený poskytovatel OpenID",
 "Your address at Wordpress, Identi.ca, &hellip;" => "Vaše adresa na Wordpressu, Identi.ca, &hellip;"
