@@ -1,10 +1,13 @@
 <?php $TRANSLATIONS = array(
+"OpenID Changed" => "La agordo de OpenID estas ŝanĝita",
+"Invalid request" => "Nevalida peto",
 "This is an OpenID server endpoint. For more information, see " => "Ĉi tio estas finpunkto de OpenID-servilo. Por pli da informo, vidu",
 "Identity: <b>" => "Idento: <b>",
 "Realm: <b>" => "Regno: <b>",
 "User: <b>" => "Uzanto: <b>",
 "Login" => "Ensaluti",
 "Error: <b>No user Selected" => "Eraro: <b>neniu uzanto estas elektita",
+"OpenID" => "OpenID",
 "you can authenticate to other sites with this address" => "Vi povas ensaluti en aliaj ejoj per tiu ĉi adreso",
 "Authorized OpenID provider" => "Rajtigita OpenID-provizanto",
 "Your address at Wordpress, Identi.ca, &hellip;" => "Via adreso ĉe Wordpress, Identi.ca&hellip;"
