@@ -1,10 +1,13 @@
 <?php $TRANSLATIONS = array(
+"OpenID Changed" => "OpenID cambiato",
+"Invalid request" => "Richiesta non valida",
 "This is an OpenID server endpoint. For more information, see " => "Questo è un server OpenID. Per ulteriori informazioni, vedi ",
 "Identity: <b>" => "Identità: <b>",
 "Realm: <b>" => "Dominio: <b>",
 "User: <b>" => "Utente: <b>",
 "Login" => "Accesso",
 "Error: <b>No user Selected" => "Errore: <b>nessun utente selezionato",
+"OpenID" => "OpenID",
 "you can authenticate to other sites with this address" => "puoi autenticarti ad altri siti con questo indirizzo",
 "Authorized OpenID provider" => "Fornitore OpenID autorizzato",
 "Your address at Wordpress, Identi.ca, &hellip;" => "Il tuo indirizzo su Wordpress, Identi.ca, &hellip;"
