@@ -67,7 +67,7 @@ var OCdialogs = {
 	* prompt user for input with custom form
 	* fields should be passed in following format: [{text:'prompt text', name:'return name', type:'input type', value: 'dafault value'},...]
 	* select example 	var fields=[{text:'Test', name:'test', type:'select', options:[{text:'hallo',value:1},{text:'hallo1',value:2}] }];
-	* @param fields to display
+	* @param fields to display 
 	* @param title dialog title
 	* @param callback which will be triggered when user press OK (user answers will be passed to callback in following format: [{name:'return name', value: 'user value'},...])
 	*/
@@ -76,7 +76,7 @@ var OCdialogs = {
 		$.each(fields, function(index, val){
 			content += '<tr><td>'+val.text+'</td><td>';
 			var type=val.type;
-
+			
 			if (type == 'text' || type == 'checkbox' || type == 'password') {
 				content += '<input type="'+type+'" name="'+val.name+'"';
 				if (type == 'checkbox') {
@@ -108,12 +108,12 @@ var OCdialogs = {
 	filepicker:function(title, callback, multiselect, mimetype_filter, modal) {
 		var c_name = 'oc-dialog-'+OCdialogs.dialogs_counter+'-content';
 		var c_id = '#'+c_name;
-		var d = '<div id="'+c_name+'" title="'+title+'"><select id="dirtree"><option value="0">'+OC.currentUser+'</option></select><div id="filelist"></div><div class="filepicker_loader"><img src="'+OC.filePath('core','img','loading.gif')+'"></div></div>';
+		var d = '<div id="'+c_name+'" title="'+title+'"><select id="dirtree"><option value="0">'+OC.currentUser+'</option></select><div id="filelist"></div><div class="filepicker_loader"><img src="'+OC.filePath('gallery','img','loading.gif')+'"></div></div>';
 		if (!modal) modal = false; // Huh..
 		if (!multiselect) multiselect = false;
 		$('body').append(d);
 		$(c_id + ' #dirtree').focus(function() {
-			var t = $(this);
+			var t = $(this); 
 			t.data('oldval',  t.val())
 		}).change({dcid: c_id}, OC.dialogs.handleTreeListSelect);
 		$(c_id).ready(function(){
@@ -123,19 +123,19 @@ var OCdialogs = {
 		}).data('multiselect', multiselect).data('mimetype',mimetype_filter);
 		// build buttons
 		var b = [{
-			text: t('core', 'Choose'),
+			text: t('core', 'Choose'), 
 			click: function(){
 				if (callback != undefined) {
 					var p;
 					if ($(c_id).data('multiselect') == true) {
 						p = [];
-						$(c_id+' .filepicker_element_selected #filename').each(function(i, elem) {
+						$(c_id+' .filepicker_element_selected .filename').each(function(i, elem) {
 							p.push(($(c_id).data('path')?$(c_id).data('path'):'')+'/'+$(elem).text());
 						});
 					} else {
 						var p = $(c_id).data('path');
 						if (p == undefined) p = '';
-						p = p+'/'+$(c_id+' .filepicker_element_selected #filename').text()
+						p = p+'/'+$(c_id+' .filepicker_element_selected .filename').text()
 					}
 					callback(p);
 					$(c_id).dialog('close');
@@ -143,7 +143,7 @@ var OCdialogs = {
 			}
 		},
 		{
-			text: t('core', 'Cancel'),
+			text: t('core', 'Cancel'), 
 			click: function(){$(c_id).dialog('close'); }}
 		];
 		$(c_id).dialog({width: ((4*$('body').width())/9), height: 400, modal: modal, buttons: b});
@@ -216,13 +216,15 @@ var OCdialogs = {
 		}
 	},
 	fillFilePicker:function(r, dialog_content_id) {
-		var entry_template = '<div onclick="javascript:OC.dialogs.handlePickerClick(this, \'*ENTRYNAME*\',\''+dialog_content_id+'\')" data="*ENTRYTYPE*"><img src="*MIMETYPEICON*" style="margin-right:1em;"><span id="filename">*NAME*</span><div style="float:right;margin-right:1em;">*LASTMODDATE*</div></div>';
+		var entry_template = '<div data-entryname="*ENTRYNAME*" data-dcid="'+dialog_content_id+'" data="*ENTRYTYPE*"><img src="*MIMETYPEICON*" style="margin-right:1em;"><span class="filename">*NAME*</span><div style="float:right;margin-right:1em;">*LASTMODDATE*</div></div>';
 		var names = '';
 		$.each(r.data, function(index, a) {
-			names += entry_template.replace('*LASTMODDATE*', OC.mtime2date(a.mtime)).replace('*NAME*', a.name).replace('*MIMETYPEICON*', a.mimetype_icon).replace('*ENTRYNAME*', a.name).replace('*ENTRYTYPE*', a.type);
+			names += entry_template.replace('*LASTMODDATE*', OC.mtime2date(a.mtime)).replace('*NAME*', escapeHTML(a.name)).replace('*MIMETYPEICON*', a.mimetype_icon).replace('*ENTRYNAME*', escapeHTML(a.name)).replace('*ENTRYTYPE*', escapeHTML(a.type));
+		});
+		
+		$(dialog_content_id + ' #filelist').html(names).on('click', '[data="file"]', function() {
+			OC.dialogs.handlePickerClick(this, $(this).data('entryname'), $(this).data('dcid'));
 		});
-
-		$(dialog_content_id + ' #filelist').html(names);
 		$(dialog_content_id + ' .filepicker_loader').css('visibility', 'hidden');
 	},
 	handleTreeListSelect:function(event) {
@@ -235,10 +237,10 @@ var OCdialogs = {
 		}
 		var skip_first = true;
 		var path = '';
-		$(this).children().each(function(i, element) {
+		$(this).children().each(function(i, element) { 
 			if (skip_first) {
-				skip_first = false;
-				return;
+				skip_first = false; 
+				return; 
 			}
 			path += '/'+$(element).text();
 		});
