@@ -1,10 +1,28 @@
 <?php $TRANSLATIONS = array(
-"This category already exists: " => "Iste categoria jam existe:",
+"Sunday" => "Dominica",
+"Monday" => "Lunedi",
+"Tuesday" => "Martedi",
+"Wednesday" => "Mercuridi",
+"Thursday" => "Jovedi",
+"Friday" => "Venerdi",
+"Saturday" => "Sabbato",
+"January" => "januario",
+"February" => "Februario",
+"March" => "Martio",
+"April" => "April",
+"May" => "Mai",
+"June" => "Junio",
+"July" => "Julio",
+"August" => "Augusto",
+"September" => "Septembre",
+"October" => "Octobre",
+"November" => "Novembre",
+"December" => "Decembre",
 "Settings" => "Configurationes",
+"Cancel" => "Cancellar",
+"Share" => "Compartir",
 "Password" => "Contrasigno",
 "ownCloud password reset" => "Reinitialisation del contrasigno de ownCLoud",
-"Requested" => "Requestate",
-"Login failed!" => "Initio de session fallite!",
 "Username" => "Nomine de usator",
 "Request reset" => "Requestar reinitialisation",
 "Your password was reset" => "Tu contrasigno esseva reinitialisate",
@@ -34,7 +52,6 @@
 "Lost your password?" => "Tu perdeva le contrasigno?",
 "remember" => "memora",
 "Log in" => "Aperir session",
-"You are logged out." => "Tu session ha essite claudite.",
 "prev" => "prev",
 "next" => "prox"
 );
