@@ -1,9 +1,27 @@
 <?php $TRANSLATIONS = array(
+"Sunday" => "Nedelja",
+"Monday" => "Ponedeljak",
+"Tuesday" => "Utorak",
+"Wednesday" => "Sreda",
+"Thursday" => "Četvrtak",
+"Friday" => "Petak",
+"Saturday" => "Subota",
+"January" => "Januar",
+"February" => "Februar",
+"March" => "Mart",
+"April" => "April",
+"May" => "Maj",
+"June" => "Jun",
+"July" => "Jul",
+"August" => "Avgust",
+"September" => "Septembar",
+"October" => "Oktobar",
+"November" => "Novembar",
+"December" => "Decembar",
 "Settings" => "Podešavanja",
+"Cancel" => "Otkaži",
 "Password" => "Lozinka",
 "You will receive a link to reset your password via Email." => "Dobićete vezu za resetovanje lozinke putem e-pošte.",
-"Requested" => "Zahtevano",
-"Login failed!" => "Nesupela prijava!",
 "Username" => "Korisničko ime",
 "Request reset" => "Zahtevaj resetovanje",
 "Your password was reset" => "Vaša lozinka je resetovana",
@@ -28,7 +46,6 @@
 "Log out" => "Odjava",
 "Lost your password?" => "Izgubili ste lozinku?",
 "remember" => "upamti",
-"You are logged out." => "Odjavljeni ste.",
 "prev" => "prethodno",
 "next" => "sledeće"
 );
