@@ -98,8 +98,7 @@ class MDB2_Driver_sqlite3 extends MDB2_Driver_Common
         if ($this->connection) {
             $native_code = $this->connection->lastErrorCode();
         }
-        $native_msg = $this->_lasterror
-            ? html_entity_decode($this->_lasterror) : $this->connection->lastErrorMsg();
+	$native_msg = html_entity_decode($this->_lasterror);
 
         // PHP 5.2+ prepends the function name to $php_errormsg, so we need
         // this hack to work around it, per bug #9599.
@@ -150,10 +149,10 @@ class MDB2_Driver_sqlite3 extends MDB2_Driver_Common
      */
     public function escape($text, $escape_wildcards = false)
     {
-		if($this->connection){
+		if($this->connection) {
 			return $this->connection->escapeString($text);
 		}else{
-			return str_replace("'","''",$text);//TODO; more
+			return str_replace("'", "''", $text);//TODO; more
 		}
     }
 
@@ -276,7 +275,7 @@ class MDB2_Driver_sqlite3 extends MDB2_Driver_Common
      * @access  public
      * @since   2.1.1
      */
-    function setTransactionIsolation($isolation,$options=array())
+    function setTransactionIsolation($isolation, $options=array())
     {
         $this->debug('Setting transaction isolation level', __FUNCTION__, array('is_manip' => true));
         switch ($isolation) {
@@ -324,7 +323,7 @@ class MDB2_Driver_sqlite3 extends MDB2_Driver_Common
      **/
     function connect()
     {
-		if($this->connection instanceof SQLite3){
+		if($this->connection instanceof SQLite3) {
 			return MDB2_OK;
 		}
 		$datadir=OC_Config::getValue( "datadirectory", OC::$SERVERROOT."/data" );
@@ -351,7 +350,7 @@ class MDB2_Driver_sqlite3 extends MDB2_Driver_Common
         }
 
         if ($database_file !== ':memory:') {
-			if(!strpos($database_file,'.db')){
+			if(!strpos($database_file, '.db')) {
 				$database_file="$datadir/$database_file.db";
 			}
             if (!file_exists($database_file)) {
@@ -387,8 +386,8 @@ class MDB2_Driver_sqlite3 extends MDB2_Driver_Common
 
         $php_errormsg = '';
 		$this->connection = new SQLite3($database_file);
-		if(is_callable(array($this->connection,'busyTimeout'))){//busy timout is only available in php>=5.3
-			$this->connection->busyTimeout(100);
+		if(is_callable(array($this->connection, 'busyTimeout'))) {//busy timout is only available in php>=5.3
+			$this->connection->busyTimeout(60000);
 		}
         $this->_lasterror = $this->connection->lastErrorMsg();
         if (!$this->connection) {
@@ -397,8 +396,7 @@ class MDB2_Driver_sqlite3 extends MDB2_Driver_Common
         }
 
         if ($this->fix_assoc_fields_names ||
-            $this->options['portability'] & MDB2_PORTABILITY_FIX_ASSOC_FIELD_NAMES)
-        {
+            $this->options['portability'] & MDB2_PORTABILITY_FIX_ASSOC_FIELD_NAMES) {
             $this->connection->exec("PRAGMA short_column_names = 1");
             $this->fix_assoc_fields_names = true;
         }
@@ -1055,7 +1053,7 @@ class MDB2_BufferedResult_sqlite3 extends MDB2_Result_sqlite3
     function seek($rownum = 0)
     {
 		$this->result->reset();
-		for($i=0;$i<$rownum;$i++){
+		for($i=0;$i<$rownum;$i++) {
 			$this->result->fetchArray();
 		}
         $this->rownum = $rownum - 1;
@@ -1093,7 +1091,7 @@ class MDB2_BufferedResult_sqlite3 extends MDB2_Result_sqlite3
     {
         $rows = 0;
         $this->result->reset();
-        while($this->result->fetchArray()){
+        while($this->result->fetchArray()) {
 			$rows++;
         }
         $this->result->reset();
@@ -1113,8 +1111,8 @@ class MDB2_Statement_sqlite3 extends MDB2_Statement_Common
 	// }}}
     // {{{ function bindValue($parameter, &$value, $type = null)
 
-	private function getParamType($type){
-		switch(strtolower($type)){
+	private function getParamType($type) {
+		switch(strtolower($type)) {
 			case 'text':
 				return SQLITE3_TEXT;
 			case 'boolean':
@@ -1139,12 +1137,12 @@ class MDB2_Statement_sqlite3 extends MDB2_Statement_Common
      *
      * @access  public
      */
-    function bindValue($parameter, $value, $type = null){
-		if($type){
+    function bindValue($parameter, $value, $type = null) {
+		if($type) {
 			$type=$this->getParamType($type);
-			$this->statement->bindValue($parameter,$value,$type);
+			$this->statement->bindValue($parameter, $value, $type);
 		}else{
-			$this->statement->bindValue($parameter,$value);
+			$this->statement->bindValue($parameter, $value);
 		}
 		return MDB2_OK;
     }
@@ -1162,12 +1160,12 @@ class MDB2_Statement_sqlite3 extends MDB2_Statement_Common
      *
      * @access  public
      */
-    function bindParam($parameter, &$value, $type = null){
-        if($type){
+    function bindParam($parameter, &$value, $type = null) {
+        if($type) {
 			$type=$this->getParamType($type);
-			$this->statement->bindParam($parameter,$value,$type);
+			$this->statement->bindParam($parameter, $value, $type);
 		}else{
-			$this->statement->bindParam($parameter,$value);
+			$this->statement->bindParam($parameter, $value);
 		}
         return MDB2_OK;
     }
@@ -1193,7 +1191,7 @@ class MDB2_Statement_sqlite3 extends MDB2_Statement_Common
      *               a MDB2 error on failure
      * @access private
      */
-    function _execute($result_class = true, $result_wrap_class = false){
+    function _execute($result_class = true, $result_wrap_class = false) {
 		if (is_null($this->statement)) {
             $result =& parent::_execute($result_class, $result_wrap_class);
             return $result;
@@ -1221,7 +1219,7 @@ class MDB2_Statement_sqlite3 extends MDB2_Statement_Common
             return $affected_rows;
         }
 
-        $result =& $this->db->_wrapResult($result, $this->result_types,
+        $result = $this->db->_wrapResult($result, $this->result_types,
             $result_class, $result_wrap_class, $this->limit, $this->offset);
         $this->db->debug($this->query, 'execute', array('is_manip' => $this->is_manip, 'when' => 'post', 'result' => $result));
         return $result;
@@ -1313,12 +1311,12 @@ class MDB2_Statement_sqlite3 extends MDB2_Statement_Common
         }
         $values = (array)$values;
         if (!empty($values)) {
-			if(count($this->types)){
+			if(count($this->types)) {
 				$types=$this->types;
 			}else{
 				$types=null;
 			}
-            $err = $this->bindValueArray($values,$types);
+            $err = $this->bindValueArray($values, $types);
             if (PEAR::isError($err)) {
                 return $this->db->raiseError(MDB2_ERROR, null, null,
                                             'Binding Values failed with message: ' . $err->getMessage(), __FUNCTION__);
@@ -1332,5 +1330,3 @@ class MDB2_Statement_sqlite3 extends MDB2_Statement_Common
 		$this->free();
     }
 }
-
-?>
