@@ -45,9 +45,15 @@ class OC_Connector_Sabre_Directory extends OC_Connector_Sabre_Node implements Sa
 	 *
 	 * @param string $name Name of the file
 	 * @param resource|string $data Initial payload
+	 * @throws Sabre_DAV_Exception_Forbidden
 	 * @return null|string
 	 */
 	public function createFile($name, $data = null) {
+
+		if (!\OC\Files\Filesystem::isCreatable($this->path)) {
+			throw new \Sabre_DAV_Exception_Forbidden();
+		}
+
 		if (isset($_SERVER['HTTP_OC_CHUNKED'])) {
 			$info = OC_FileChunking::decodeName($name);
 			if (empty($info)) {
@@ -62,7 +68,36 @@ class OC_Connector_Sabre_Directory extends OC_Connector_Sabre_Node implements Sa
 			}
 		} else {
 			$newPath = $this->path . '/' . $name;
-			OC_Filesystem::file_put_contents($newPath, $data);
+
+			// mark file as partial while uploading (ignored by the scanner)
+			$partpath = $newPath . '.part';
+
+			\OC\Files\Filesystem::file_put_contents($partpath, $data);
+
+			//detect aborted upload
+			if (isset ($_SERVER['REQUEST_METHOD']) && $_SERVER['REQUEST_METHOD'] === 'PUT' ) {
+				if (isset($_SERVER['CONTENT_LENGTH'])) {
+					$expected = $_SERVER['CONTENT_LENGTH'];
+					$actual = \OC\Files\Filesystem::filesize($partpath);
+					if ($actual != $expected) {
+						\OC\Files\Filesystem::unlink($partpath);
+						throw new Sabre_DAV_Exception_BadRequest(
+								'expected filesize ' . $expected . ' got ' . $actual);
+					}
+				}
+			}
+
+			// rename to correct path
+			\OC\Files\Filesystem::rename($partpath, $newPath);
+
+			// allow sync clients to send the mtime along in a header
+			$mtime = OC_Request::hasModificationTime();
+			if ($mtime !== false) {
+				if(\OC\Files\Filesystem::touch($newPath, $mtime)) {
+					header('X-OC-MTime: accepted');
+				}
+			}
+
 			return OC_Connector_Sabre_Node::getETagPropertyForPath($newPath);
 		}
 
@@ -73,12 +108,19 @@ class OC_Connector_Sabre_Directory extends OC_Connector_Sabre_Node implements Sa
 	 * Creates a new subdirectory
 	 *
 	 * @param string $name
+	 * @throws Sabre_DAV_Exception_Forbidden
 	 * @return void
 	 */
 	public function createDirectory($name) {
 
+		if (!\OC\Files\Filesystem::isCreatable($this->path)) {
+			throw new \Sabre_DAV_Exception_Forbidden();
+		}
+
 		$newPath = $this->path . '/' . $name;
-		OC_Filesystem::mkdir($newPath);
+		if(!\OC\Files\Filesystem::mkdir($newPath)) {
+			throw new Sabre_DAV_Exception_Forbidden('Could not create directory '.$newPath);
+		}
 
 	}
 
@@ -93,7 +135,7 @@ class OC_Connector_Sabre_Directory extends OC_Connector_Sabre_Node implements Sa
 
 		$path = $this->path . '/' . $name;
 		if (is_null($info)) {
-			$info = OC_Files::getFileInfo($path);
+			$info = \OC\Files\Filesystem::getFileInfo($path);
 		}
 
 		if (!$info) {
@@ -117,28 +159,31 @@ class OC_Connector_Sabre_Directory extends OC_Connector_Sabre_Node implements Sa
 	 */
 	public function getChildren() {
 
-		$source = $this->getFileSource($this->path);
-		$path = $source['path'];
-		$user = $source['user'];
-		
-		$folder_content = OC_Files::getDirectoryContent($this->path);
+		$folder_content = \OC\Files\Filesystem::getDirectoryContent($this->path);
 		$paths = array();
 		foreach($folder_content as $info) {
-			$paths[] = $path.'/'.$info['name'];
+			$paths[] = $this->path.'/'.$info['name'];
+			$properties[$this->path.'/'.$info['name']][self::GETETAG_PROPERTYNAME] = '"' . $info['etag'] . '"';
 		}
-		$properties = array_fill_keys($paths, array());
 		if(count($paths)>0) {
+			//
+			// the number of arguments within IN conditions are limited in most databases
+			// we chunk $paths into arrays of 200 items each to meet this criteria
+			//
 			$chunks = array_chunk($paths, 200, false);
 			foreach ($chunks as $pack) {
 				$placeholders = join(',', array_fill(0, count($pack), '?'));
-				$query = OC_DB::prepare( 'SELECT * FROM `*PREFIX*properties` WHERE `userid` = ?' . ' AND `propertypath` IN ('.$placeholders.')' );
-				array_unshift($pack, $user); // prepend userid
+				$query = OC_DB::prepare( 'SELECT * FROM `*PREFIX*properties`'
+					.' WHERE `userid` = ?' . ' AND `propertypath` IN ('.$placeholders.')' );
+				array_unshift($pack, OC_User::getUser()); // prepend userid
 				$result = $query->execute( $pack );
 				while($row = $result->fetchRow()) {
 					$propertypath = $row['propertypath'];
 					$propertyname = $row['propertyname'];
 					$propertyvalue = $row['propertyvalue'];
-					$properties[$propertypath][$propertyname] = $propertyvalue;
+					if($propertyname !== self::GETETAG_PROPERTYNAME) {
+						$properties[$propertypath][$propertyname] = $propertyvalue;
+					}
 				}
 			}
 		}
@@ -146,7 +191,7 @@ class OC_Connector_Sabre_Directory extends OC_Connector_Sabre_Node implements Sa
 		$nodes = array();
 		foreach($folder_content as $info) {
 			$node = $this->getChild($info['name'], $info);
-			$node->setPropertyCache($properties[$path.'/'.$info['name']]);
+			$node->setPropertyCache($properties[$this->path.'/'.$info['name']]);
 			$nodes[] = $node;
 		}
 		return $nodes;
@@ -161,7 +206,7 @@ class OC_Connector_Sabre_Directory extends OC_Connector_Sabre_Node implements Sa
 	public function childExists($name) {
 
 		$path = $this->path . '/' . $name;
-		return OC_Filesystem::file_exists($path);
+		return \OC\Files\Filesystem::file_exists($path);
 
 	}
 
@@ -169,12 +214,16 @@ class OC_Connector_Sabre_Directory extends OC_Connector_Sabre_Node implements Sa
 	 * Deletes all files in this directory, and then itself
 	 *
 	 * @return void
+	 * @throws Sabre_DAV_Exception_Forbidden
 	 */
 	public function delete() {
 
+		if (!\OC\Files\Filesystem::isDeletable($this->path)) {
+			throw new \Sabre_DAV_Exception_Forbidden();
+		}
 		if ($this->path != "/Shared") {
 			foreach($this->getChildren() as $child) $child->delete();
-			OC_Filesystem::rmdir($this->path);
+			\OC\Files\Filesystem::rmdir($this->path);
 		}
 
 	}
@@ -185,10 +234,10 @@ class OC_Connector_Sabre_Directory extends OC_Connector_Sabre_Node implements Sa
 	 * @return array
 	 */
 	public function getQuotaInfo() {
-		$rootInfo=OC_FileCache_Cached::get('');
+		$rootInfo=\OC\Files\Filesystem::getFileInfo('');
 		return array(
 			$rootInfo['size'],
-			OC_Filesystem::free_space()
+			\OC\Files\Filesystem::free_space()
 		);
 
 	}
