@@ -20,6 +20,19 @@
  *
  */
 
+class DatabaseException extends Exception{
+	private $query;
+
+	public function __construct($message, $query){
+		parent::__construct($message);
+		$this->query = $query;
+	}
+
+	public function getQuery(){
+		return $this->query;
+	}
+}
+
 /**
  * This class manages the access to the database. It basically is a wrapper for
  * MDB2 with some adaptions.
@@ -28,6 +41,9 @@ class OC_DB {
 	const BACKEND_PDO=0;
 	const BACKEND_MDB2=1;
 
+	static private $preparedQueries = array();
+	static private $cachingEnabled = true;
+
 	/**
 	 * @var MDB2_Driver_Common
 	 */
@@ -108,6 +124,7 @@ class OC_DB {
 				return true;
 			}
 		}
+		self::$preparedQueries = array();
 		// The global data we need
 		$name = OC_Config::getValue( "dbname", "owncloud" );
 		$host = OC_Config::getValue( "dbhost", "" );
@@ -115,7 +132,7 @@ class OC_DB {
 		$pass = OC_Config::getValue( "dbpassword", "" );
 		$type = OC_Config::getValue( "dbtype", "sqlite" );
 		if(strpos($host, ':')) {
-			list($host, $port)=explode(':', $host,2);
+			list($host, $port)=explode(':', $host, 2);
 		}else{
 			$port=false;
 		}
@@ -147,7 +164,7 @@ class OC_DB {
 						$dsn='pgsql:dbname='.$name.';host='.$host;
 					}
 					/**
-					* Ugly fix for pg connections pbm when password use spaces (php#62479)
+					* Ugly fix for pg connections pbm when password use spaces
 					*/
 					$e_user = addslashes($user);
 					$e_password = addslashes($pass);
@@ -162,14 +179,22 @@ class OC_DB {
 							$dsn = 'oci:dbname=//' . $host . '/' . $name;
 					}
 					break;
+                case 'mssql':
+					if ($port) {
+							$dsn='sqlsrv:Server='.$host.','.$port.';Database='.$name;
+					} else {
+							$dsn='sqlsrv:Server='.$host.';Database='.$name;
+					}
+					break;                    
 				default:
 					return false;
 			}
 			try{
 				self::$PDO=new PDO($dsn, $user, $pass, $opts);
 			}catch(PDOException $e) {
-			  OC_Log::write('core', $e->getMessage(), OC_Log::FATAL);
+				OC_Log::write('core', $e->getMessage(), OC_Log::FATAL);
 				OC_User::setUserId(null);
+
 				// send http status 503
 				header('HTTP/1.1 503 Service Temporarily Unavailable');
 				header('Status: 503 Service Temporarily Unavailable');
@@ -194,6 +219,7 @@ class OC_DB {
 				return true;
 			}
 		}
+		self::$preparedQueries = array();
 		// The global data we need
 		$name = OC_Config::getValue( "dbname", "owncloud" );
 		$host = OC_Config::getValue( "dbhost", "" );
@@ -210,11 +236,12 @@ class OC_DB {
 
 			// Prepare options array
 			$options = array(
-			  'portability' => MDB2_PORTABILITY_ALL - MDB2_PORTABILITY_FIX_CASE,
-			  'log_line_break' => '<br>',
-			  'idxname_format' => '%s',
-			  'debug' => true,
-			  'quote_identifier' => true  );
+					'portability' => MDB2_PORTABILITY_ALL - MDB2_PORTABILITY_FIX_CASE,
+					'log_line_break' => '<br>',
+					'idxname_format' => '%s',
+					'debug' => true,
+					'quote_identifier' => true
+					);
 
 			// Add the dsn according to the database type
 			switch($type) {
@@ -246,18 +273,24 @@ class OC_DB {
 					break;
 				case 'oci':
 					$dsn = array(
-							'phptype'  => 'oci8',
-							'username' => $user,
-							'password' => $pass,
-							'charset' => 'AL32UTF8',
+						'phptype'  => 'oci8',
+						'username' => $user,
+						'password' => $pass,
+						'service'  => $name,
+						'hostspec' => $host,
+						'charset' => 'AL32UTF8',
 					);
-					if ($host != '') {
-						$dsn['hostspec'] = $host;
-						$dsn['database'] = $name;
-					} else { // use dbname for hostspec
-						$dsn['hostspec'] = $name;
-						$dsn['database'] = $user;
-					}
+					break;
+				case 'mssql':
+					$dsn = array(
+						'phptype' => 'sqlsrv',
+						'username' => $user,
+						'password' => $pass,
+						'hostspec' => $host,
+						'database' => $name,
+						'charset' => 'UTF-8'
+					);
+					$options['portability'] = $options['portability'] - MDB2_PORTABILITY_EMPTY_TO_NULL;
 					break;
 				default:
 					return false;
@@ -268,8 +301,11 @@ class OC_DB {
 
 			// Die if we could not connect
 			if( PEAR::isError( self::$MDB2 )) {
+				OC_Log::write('core', self::$MDB2->getUserInfo(), OC_Log::FATAL);
+				OC_Log::write('core', self::$MDB2->getMessage(), OC_Log::FATAL);
 				OC_User::setUserId(null);
 
+				// send http status 503
 				header('HTTP/1.1 503 Service Temporarily Unavailable');
 				header('Status: 503 Service Temporarily Unavailable');
 				OC_Template::printErrorPage('Failed to connect to database');
@@ -289,11 +325,12 @@ class OC_DB {
 	 * @param string $query Query string
 	 * @param int $limit
 	 * @param int $offset
+	 * @param bool $isManipulation
 	 * @return MDB2_Statement_Common prepared SQL query
 	 *
 	 * SQL query via MDB2 prepare(), needs to be execute()'d!
 	 */
-	static public function prepare( $query , $limit=null, $offset=null ) {
+	static public function prepare( $query , $limit = null, $offset = null, $isManipulation = null) {
 
 		if (!is_null($limit) && $limit != -1) {
 			if (self::$backend == self::BACKEND_MDB2) {
@@ -317,39 +354,80 @@ class OC_DB {
 					$query.=$limitsql;
 				}
 			}
+		} else {
+			if (isset(self::$preparedQueries[$query]) and self::$cachingEnabled) {
+				return self::$preparedQueries[$query];
+			}
 		}
+		$rawQuery = $query;
 
 		// Optimize the query
 		$query = self::processQuery( $query );
 
 		self::connect();
+		
+		if ($isManipulation === null) {
+			//try to guess, so we return the number of rows on manipulations
+			$isManipulation = self::isManipulation($query);
+		}
+		
 		// return the result
 		if(self::$backend==self::BACKEND_MDB2) {
-			$result = self::$connection->prepare( $query );
+			// differentiate between query and manipulation
+			if ($isManipulation) {
+				$result = self::$connection->prepare( $query, null, MDB2_PREPARE_MANIP );
+			} else {
+				$result = self::$connection->prepare( $query, null, MDB2_PREPARE_RESULT );
+			}
 
 			// Die if we have an error (error means: bad query, not 0 results!)
-			if( PEAR::isError($result)) {
-				$entry = 'DB Error: "'.$result->getMessage().'"<br />';
-				$entry .= 'Offending command was: '.htmlentities($query).'<br />';
-				OC_Log::write('core', $entry,OC_Log::FATAL);
-				error_log('DB error: '.$entry);
-				OC_Template::printErrorPage( $entry );
+			if( self::isError($result)) {
+				throw new DatabaseException($result->getMessage(), $query);
 			}
 		}else{
 			try{
 				$result=self::$connection->prepare($query);
 			}catch(PDOException $e) {
-				$entry = 'DB Error: "'.$e->getMessage().'"<br />';
-				$entry .= 'Offending command was: '.htmlentities($query).'<br />';
-				OC_Log::write('core', $entry,OC_Log::FATAL);
-				error_log('DB error: '.$entry);
-				OC_Template::printErrorPage( $entry );
+				throw new DatabaseException($e->getMessage(), $query);
+			}
+			// differentiate between query and manipulation
+			$result = new PDOStatementWrapper($result, $isManipulation);
+		}
+		if ((is_null($limit) || $limit == -1) and self::$cachingEnabled ) {
+			$type = OC_Config::getValue( "dbtype", "sqlite" );
+			if( $type != 'sqlite' && $type != 'sqlite3' ) {
+				self::$preparedQueries[$rawQuery] = $result;
 			}
-			$result=new PDOStatementWrapper($result);
 		}
 		return $result;
 	}
-
+	
+	/**
+	 * tries to guess the type of statement based on the first 10 characters
+	 * the current check allows some whitespace but does not work with IF EXISTS or other more complex statements
+	 * 
+	 * @param string $sql
+	 */
+	static public function isManipulation( $sql ) {
+		$selectOccurence = stripos ($sql, "SELECT");
+		if ($selectOccurence !== false && $selectOccurence < 10) {
+			return false;
+		}
+		$insertOccurence = stripos ($sql, "INSERT");
+		if ($insertOccurence !== false && $insertOccurence < 10) {
+			return true;
+		}
+		$updateOccurence = stripos ($sql, "UPDATE");
+		if ($updateOccurence !== false && $updateOccurence < 10) {
+			return true;
+		}
+		$deleteOccurance = stripos ($sql, "DELETE");
+		if ($deleteOccurance !== false && $deleteOccurance < 10) {
+			return true;
+		}
+		return false;
+	}
+	
 	/**
 	 * @brief gets last value of autoincrement
 	 * @param string $table The optional table name (will replace *PREFIX*) and add sequence suffix
@@ -362,12 +440,25 @@ class OC_DB {
 	 */
 	public static function insertid($table=null) {
 		self::connect();
-		if($table !== null) {
-			$prefix = OC_Config::getValue( "dbtableprefix", "oc_" );
-			$suffix = OC_Config::getValue( "dbsequencesuffix", "_id_seq" );
-			$table = str_replace( '*PREFIX*', $prefix, $table ).$suffix;
+		$type = OC_Config::getValue( "dbtype", "sqlite" );
+		if( $type == 'pgsql' ) {
+			$query = self::prepare('SELECT lastval() AS id');
+			$row = $query->execute()->fetchRow();
+			return $row['id'];
+		} else if( $type === 'mssql' || $type === 'oci') {
+			if($table !== null) {
+				$prefix = OC_Config::getValue( "dbtableprefix", "oc_" );
+				$table = str_replace( '*PREFIX*', $prefix, $table );
+			}
+			return self::$connection->lastInsertId($table);
+		} else {
+			if($table !== null) {
+				$prefix = OC_Config::getValue( "dbtableprefix", "oc_" );
+				$suffix = OC_Config::getValue( "dbsequencesuffix", "_id_seq" );
+				$table = str_replace( '*PREFIX*', $prefix, $table ).$suffix;
+			}
+			return self::$connection->lastInsertId($table);
 		}
-		return self::$connection->lastInsertId($table);
 	}
 
 	/**
@@ -398,7 +489,7 @@ class OC_DB {
 	 *
 	 * TODO: write more documentation
 	 */
-	public static function getDbStructure( $file ,$mode=MDB2_SCHEMA_DUMP_STRUCTURE) {
+	public static function getDbStructure( $file, $mode=MDB2_SCHEMA_DUMP_STRUCTURE) {
 		self::connectScheme();
 
 		// write the scheme
@@ -425,6 +516,9 @@ class OC_DB {
 		$CONFIG_DBTABLEPREFIX = OC_Config::getValue( "dbtableprefix", "oc_" );
 		$CONFIG_DBTYPE = OC_Config::getValue( "dbtype", "sqlite" );
 
+		// cleanup the cached queries
+		self::$preparedQueries = array();
+
 		self::connectScheme();
 
 		// read file
@@ -442,9 +536,10 @@ class OC_DB {
 		 * http://www.sqlite.org/lang_createtable.html
 		 * http://docs.oracle.com/cd/B19306_01/server.102/b14200/functions037.htm
 		 */
-		 if( $CONFIG_DBTYPE == 'pgsql' ) { //mysql support it too but sqlite doesn't
-				 $content = str_replace( '<default>0000-00-00 00:00:00</default>', '<default>CURRENT_TIMESTAMP</default>', $content );
-		 }
+		if( $CONFIG_DBTYPE == 'pgsql' ) { //mysql support it too but sqlite doesn't
+			$content = str_replace( '<default>0000-00-00 00:00:00</default>',
+				'<default>CURRENT_TIMESTAMP</default>', $content );
+		}
 
 		file_put_contents( $file2, $content );
 
@@ -471,7 +566,8 @@ class OC_DB {
 
 		// Die in case something went wrong
 		if( $ret instanceof MDB2_Error ) {
-			OC_Template::printErrorPage( self::$MDB2->getDebugOutput().' '.$ret->getMessage() . ': ' . $ret->getUserInfo() );
+			OC_Template::printErrorPage( self::$MDB2->getDebugOutput().' '.$ret->getMessage() . ': '
+				. $ret->getUserInfo() );
 		}
 
 		return true;
@@ -485,8 +581,13 @@ class OC_DB {
 	public static function updateDbFromStructure($file) {
 		$CONFIG_DBTABLEPREFIX = OC_Config::getValue( "dbtableprefix", "oc_" );
 		$CONFIG_DBTYPE = OC_Config::getValue( "dbtype", "sqlite" );
-		
+
 		self::connectScheme();
+		
+		if(OC_Config::getValue('dbtype', 'sqlite')==='oci') {
+			//set dbname, it is unset because oci uses 'service' to connect
+			self::$schema->db->database_name=self::$schema->db->dsn['username'];
+		}
 
 		// read file
 		$content = file_get_contents( $file );
@@ -495,8 +596,9 @@ class OC_DB {
 		if (PEAR::isError($previousSchema)) {
 			$error = $previousSchema->getMessage();
 			$detail = $previousSchema->getDebugInfo();
-			OC_Log::write('core', 'Failed to get existing database structure for upgrading ('.$error.', '.$detail.')', OC_Log::FATAL);
-			return false;
+			$message = 'Failed to get existing database structure for updating ('.$error.', '.$detail.')';
+			OC_Log::write('core', $message, OC_Log::FATAL);
+			throw new Exception($message);
 		}
 
 		// Make changes and save them to an in-memory file
@@ -512,7 +614,14 @@ class OC_DB {
 		 * http://docs.oracle.com/cd/B19306_01/server.102/b14200/functions037.htm
 		 */
 		if( $CONFIG_DBTYPE == 'pgsql' ) { //mysql support it too but sqlite doesn't
-			$content = str_replace( '<default>0000-00-00 00:00:00</default>', '<default>CURRENT_TIMESTAMP</default>', $content );
+			$content = str_replace( '<default>0000-00-00 00:00:00</default>',
+				'<default>CURRENT_TIMESTAMP</default>', $content );
+		}
+		if(OC_Config::getValue('dbtype', 'sqlite')==='oci') {
+			unset($previousSchema['charset']); //or MDB2 tries SHUTDOWN IMMEDIATE
+			$oldname = $previousSchema['name'];
+			$previousSchema['name']=OC_Config::getValue( "dbuser", $oldname );
+			//TODO check identifiers are at most 30 chars long
 		}
 		file_put_contents( $file2, $content );
 		$op = self::$schema->updateDatabase($file2, $previousSchema, array(), false);
@@ -523,8 +632,9 @@ class OC_DB {
 		if (PEAR::isError($op)) {
 			$error = $op->getMessage();
 			$detail = $op->getDebugInfo();
-			OC_Log::write('core', 'Failed to update database structure ('.$error.', '.$detail.')', OC_Log::FATAL);
-			return false;
+			$message = 'Failed to update database structure ('.$error.', '.$detail.')';
+			OC_Log::write('core', $message, OC_Log::FATAL);
+			throw new Exception($message);
 		}
 		return true;
 	}
@@ -550,6 +660,94 @@ class OC_DB {
 		return true;
 	}
 
+	/**
+	 * @brief Insert a row if a matching row doesn't exists.
+	 * @param string $table. The table to insert into in the form '*PREFIX*tableName'
+	 * @param array $input. An array of fieldname/value pairs
+	 * @returns int number of updated rows
+	 */
+	public static function insertIfNotExist($table, $input) {
+		self::connect();
+		$prefix = OC_Config::getValue( "dbtableprefix", "oc_" );
+		$table = str_replace( '*PREFIX*', $prefix, $table );
+
+		if(is_null(self::$type)) {
+			self::$type=OC_Config::getValue( "dbtype", "sqlite" );
+		}
+		$type = self::$type;
+
+		$query = '';
+		$inserts = array_values($input);
+		// differences in escaping of table names ('`' for mysql) and getting the current timestamp
+		if( $type == 'sqlite' || $type == 'sqlite3' ) {
+			// NOTE: For SQLite we have to use this clumsy approach
+			// otherwise all fieldnames used must have a unique key.
+			$query = 'SELECT * FROM `' . $table . '` WHERE ';
+			foreach($input as $key => $value) {
+				$query .= '`' . $key . '` = ? AND ';
+			}
+			$query = substr($query, 0, strlen($query) - 5);
+			try {
+				$stmt = self::prepare($query);
+				$result = $stmt->execute($inserts);
+				if (self::isError($result)) {
+					OC_Log::write('core', self::getErrorMessage($result), OC_Log::FATAL);
+					OC_Template::printErrorPage( $entry );
+				}
+
+			} catch(PDOException $e) {
+				$entry = 'DB Error: "'.$e->getMessage() . '"<br />';
+				$entry .= 'Offending command was: ' . $query . '<br />';
+				OC_Log::write('core', $entry, OC_Log::FATAL);
+				error_log('DB error: '.$entry);
+				OC_Template::printErrorPage( $entry );
+			}
+
+			if((int)$result->numRows() === 0) {
+				$query = 'INSERT INTO `' . $table . '` (`'
+					. implode('`,`', array_keys($input)) . '`) VALUES('
+					. str_repeat('?,', count($input)-1).'? ' . ')';
+			} else {
+				return 0;
+			}
+		} elseif( $type == 'pgsql' || $type == 'oci' || $type == 'mysql' || $type == 'mssql') {
+			$query = 'INSERT INTO `' .$table . '` (`'
+				. implode('`,`', array_keys($input)) . '`) SELECT '
+				. str_repeat('?,', count($input)-1).'? ' // Is there a prettier alternative?
+				. 'FROM `' . $table . '` WHERE ';
+
+			foreach($input as $key => $value) {
+				$query .= '`' . $key . '` = ? AND ';
+			}
+			$query = substr($query, 0, strlen($query) - 5);
+			$query .= ' HAVING COUNT(*) = 0';
+			$inserts = array_merge($inserts, $inserts);
+		}
+
+		try {
+			$stmt = self::prepare($query);
+			if (self::isError($stmt)) {
+				$msg = self::getErrorMessage($stmt);
+				OC_Log::write('core', $msg, OC_Log::FATAL);
+				OC_Template::printErrorPage( $msg );
+			}
+			$result = $stmt->execute($inserts);
+			if (self::isError($result)) {
+				$msg = self::getErrorMessage($result);
+				OC_Log::write('core', $msg, OC_Log::FATAL);
+				OC_Template::printErrorPage( $msg );
+			}
+		} catch(PDOException $e) {
+			$entry = 'DB Error: "'.$e->getMessage() . '"<br />';
+			$entry .= 'Offending command was: ' . $query.'<br />';
+			OC_Log::write('core', $entry, OC_Log::FATAL);
+			error_log('DB error: ' . $entry);
+			OC_Template::printErrorPage( $entry );
+		}
+
+		return $result;
+	}
+
 	/**
 	 * @brief does minor changes to query
 	 * @param string $query Query string
@@ -577,11 +775,21 @@ class OC_DB {
 			$query = str_ireplace( 'UNIX_TIMESTAMP()', 'strftime(\'%s\',\'now\')', $query );
 		}elseif( $type == 'pgsql' ) {
 			$query = str_replace( '`', '"', $query );
-			$query = str_ireplace( 'UNIX_TIMESTAMP()', 'cast(extract(epoch from current_timestamp) as integer)', $query );
+			$query = str_ireplace( 'UNIX_TIMESTAMP()', 'cast(extract(epoch from current_timestamp) as integer)',
+				$query );
 		}elseif( $type == 'oci'  ) {
 			$query = str_replace( '`', '"', $query );
 			$query = str_ireplace( 'NOW()', 'CURRENT_TIMESTAMP', $query );
-		}
+			$query = str_ireplace( 'UNIX_TIMESTAMP()', '((CAST(SYS_EXTRACT_UTC(systimestamp) AS DATE))-TO_DATE(\'1970101000000\',\'YYYYMMDDHH24MiSS\'))*24*3600', $query );
+		}elseif( $type == 'mssql' ) {
+			$query = preg_replace( "/\`(.*?)`/", "[$1]", $query );
+			$query = str_replace( 'NOW()', 'CURRENT_TIMESTAMP', $query );
+			$query = str_replace( 'now()', 'CURRENT_TIMESTAMP', $query );
+			$query = str_replace( 'LENGTH(', 'LEN(', $query );
+			$query = str_replace( 'SUBSTR(', 'SUBSTRING(', $query );
+            
+            $query = self::fixLimitClauseForMSSQL($query);
+        }
 
 		// replace table name prefix
 		$query = str_replace( '*PREFIX*', $prefix, $query );
@@ -589,6 +797,60 @@ class OC_DB {
 		return $query;
 	}
 
+    private static function fixLimitClauseForMSSQL($query) {
+        $limitLocation = stripos ($query, "LIMIT");
+        
+        if ( $limitLocation === false ) {
+            return $query;
+        } 
+        
+        // total == 0 means all results - not zero results
+        //
+        // First number is either total or offset, locate it by first space
+        //
+        $offset = substr ($query, $limitLocation + 5);
+        $offset = substr ($offset, 0, stripos ($offset, ' '));
+        $offset = trim ($offset);
+
+        // check for another parameter
+        if (stripos ($offset, ',') === false) {
+            // no more parameters
+            $offset = 0;
+            $total = intval ($offset);
+        } else {
+            // found another parameter
+            $offset = intval ($offset);
+
+            $total = substr ($query, $limitLocation + 5);
+            $total = substr ($total, stripos ($total, ','));
+
+            $total = substr ($total, 0, stripos ($total, ' '));
+            $total = intval ($total);
+        }
+
+        $query = trim (substr ($query, 0, $limitLocation));
+
+        if ($offset == 0 && $total !== 0) {
+            if (strpos($query, "SELECT") === false) {
+                $query = "TOP {$total} " . $query;
+            } else {
+                $query = preg_replace('/SELECT(\s*DISTINCT)?/Dsi', 'SELECT$1 TOP '.$total, $query);
+            }
+        } else if ($offset > 0) {
+            $query = preg_replace('/SELECT(\s*DISTINCT)?/Dsi', 'SELECT$1 TOP(10000000) ', $query);
+            $query = 'SELECT *
+                    FROM (SELECT sub2.*, ROW_NUMBER() OVER(ORDER BY sub2.line2) AS line3
+                    FROM (SELECT 1 AS line2, sub1.* FROM (' . $query . ') AS sub1) as sub2) AS sub3';
+
+            if ($total > 0) {
+                $query .= ' WHERE line3 BETWEEN ' . ($offset + 1) . ' AND ' . ($offset + $total);
+            } else {
+                $query .= ' WHERE line3 > ' . $offset;
+            }
+        }
+        return $query;
+    }
+    
 	/**
 	 * @brief drop a table
 	 * @param string $tableName the table to drop
@@ -684,15 +946,18 @@ class OC_DB {
 	 * @return bool
 	 */
 	public static function isError($result) {
-		if(!$result) {
+		//MDB2 returns an MDB2_Error object
+		if (class_exists('PEAR') === true && PEAR::isError($result)) {
 			return true;
-		}elseif(self::$backend==self::BACKEND_MDB2 and PEAR::isError($result)) {
-			return true;
-		}else{
-			return false;
 		}
+		//PDO returns false on error (and throws an exception)
+		if (self::$backend===self::BACKEND_PDO and $result === false) {
+			return true;
+		}
+
+		return false;
 	}
-	
+
 	/**
 	 * returns the error code and message as a string for logging
 	 * works with MDB2 and PDOException
@@ -720,6 +985,16 @@ class OC_DB {
 		}
 		return $msg;
 	}
+
+	/**
+	 * @param bool $enabled
+	 */
+	static public function enableCaching($enabled) {
+		if (!$enabled) {
+			self::$preparedQueries = array();
+		}
+		self::$cachingEnabled = $enabled;
+	}
 }
 
 /**
@@ -729,30 +1004,135 @@ class PDOStatementWrapper{
 	/**
 	 * @var PDOStatement
 	 */
-	private $statement=null;
-	private $lastArguments=array();
+	private $statement = null;
+	private $isManipulation = false;
+	private $lastArguments = array();
 
-	public function __construct($statement) {
-		$this->statement=$statement;
+	public function __construct($statement, $isManipulation = false) {
+		$this->statement = $statement;
+		$this->isManipulation = $isManipulation;
 	}
 
 	/**
-	 * make execute return the result instead of a bool
+	 * make execute return the result or updated row count instead of a bool
 	 */
 	public function execute($input=array()) {
-		$this->lastArguments=$input;
-		if(count($input)>0) {
-			$result=$this->statement->execute($input);
-		}else{
-			$result=$this->statement->execute();
+		$this->lastArguments = $input;
+		if (count($input) > 0) {
+
+			if (!isset($type)) {
+				$type = OC_Config::getValue( "dbtype", "sqlite" );
+			}
+
+			if ($type == 'mssql') {
+				$input = $this->tryFixSubstringLastArgumentDataForMSSQL($input);
+			}
+
+			$result = $this->statement->execute($input);
+		} else {
+			$result = $this->statement->execute();
 		}
-		if($result) {
-			return $this;
-		}else{
+		
+		if ($result === false) {
 			return false;
 		}
+		if ($this->isManipulation) {
+			return $this->statement->rowCount();
+		} else {
+			return $this;
+		}
 	}
 
+	private function tryFixSubstringLastArgumentDataForMSSQL($input) {
+		$query = $this->statement->queryString;
+		$pos = stripos ($query, 'SUBSTRING');
+
+		if ( $pos === false) {
+			return;
+		}
+
+		try {
+			$newQuery = '';
+
+			$cArg = 0;
+
+			$inSubstring = false;
+
+			// Create new query
+			for ($i = 0; $i < strlen ($query); $i++) {
+				if ($inSubstring == false) {
+					// Defines when we should start inserting values
+					if (substr ($query, $i, 9) == 'SUBSTRING') {
+						$inSubstring = true;
+					}
+				} else {
+					// Defines when we should stop inserting values
+					if (substr ($query, $i, 1) == ')') {
+						$inSubstring = false;
+					}
+				}
+
+				if (substr ($query, $i, 1) == '?') {
+					// We found a question mark
+					if ($inSubstring) {
+						$newQuery .= $input[$cArg];
+
+						//
+						// Remove from input array
+						//
+						array_splice ($input, $cArg, 1);
+					} else {
+						$newQuery .= substr ($query, $i, 1);
+						$cArg++;
+					}
+				} else {
+					$newQuery .= substr ($query, $i, 1);
+				}
+			}
+
+			// The global data we need
+			$name = OC_Config::getValue( "dbname", "owncloud" );
+			$host = OC_Config::getValue( "dbhost", "" );
+			$user = OC_Config::getValue( "dbuser", "" );
+			$pass = OC_Config::getValue( "dbpassword", "" );
+			if (strpos($host,':')) {
+				list($host, $port) = explode(':', $host, 2);
+			} else {
+				$port = false;
+			}
+			$opts = array();
+
+			if ($port) {
+				$dsn = 'sqlsrv:Server='.$host.','.$port.';Database='.$name;
+			} else {
+				$dsn = 'sqlsrv:Server='.$host.';Database='.$name;
+			}
+
+			$PDO = new PDO($dsn, $user, $pass, $opts);
+			$PDO->setAttribute(PDO::ATTR_DEFAULT_FETCH_MODE, PDO::FETCH_ASSOC);
+			$PDO->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);
+
+			$this->statement = $PDO->prepare($newQuery);
+
+			$this->lastArguments = $input;
+
+			return $input;
+		} catch (PDOException $e){
+			$entry = 'PDO DB Error: "'.$e->getMessage().'"<br />';
+			$entry .= 'Offending command was: '.$this->statement->queryString .'<br />';
+			$entry .= 'Input parameters: ' .print_r($input, true).'<br />';
+			$entry .= 'Stack trace: ' .$e->getTraceAsString().'<br />';
+			OC_Log::write('core', $entry, OC_Log::FATAL);
+			OC_User::setUserId(null);
+
+			// send http status 503
+			header('HTTP/1.1 503 Service Temporarily Unavailable');
+			header('Status: 503 Service Temporarily Unavailable');
+			OC_Template::printErrorPage('Failed to connect to database');
+			die ($entry);
+		}
+	}
+    
 	/**
 	 * provide numRows
 	 */
@@ -776,8 +1156,8 @@ class PDOStatementWrapper{
 	/**
 	 * pass all other function directly to the PDOStatement
 	 */
-	public function __call($name,$arguments) {
-		return call_user_func_array(array($this->statement,$name), $arguments);
+	public function __call($name, $arguments) {
+		return call_user_func_array(array($this->statement, $name), $arguments);
 	}
 
 	/**
