@@ -9,6 +9,7 @@
 "Files need to be downloaded one by one." => "Los fichièrs devan èsser avalcargats un per un.",
 "Back to Files" => "Torna cap als fichièrs",
 "Authentication error" => "Error d'autentificacion",
+"Files" => "Fichièrs",
 "seconds ago" => "segonda a",
 "1 minute ago" => "1 minuta a",
 "%d minutes ago" => "%d minutas a",
@@ -16,7 +17,6 @@
 "yesterday" => "ièr",
 "%d days ago" => "%d jorns a",
 "last month" => "mes passat",
-"months ago" => "meses  a",
 "last year" => "an passat",
 "years ago" => "ans a",
 "up to date" => "a jorn",
