@@ -32,14 +32,19 @@ class OC_Mail {
 	 * @param string $bcc
 	 * @throws Exception
 	 */
-	public static function send($toaddress,$toname,$subject,$mailtext,$fromaddress,$fromname,$html=0,$altbody='',$ccaddress='',$ccname='',$bcc='') {
+	public static function send($toaddress, $toname, $subject, $mailtext, $fromaddress, $fromname,
+		$html=0, $altbody='', $ccaddress='', $ccname='', $bcc='') {
 
 		$SMTPMODE = OC_Config::getValue( 'mail_smtpmode', 'sendmail' );
 		$SMTPHOST = OC_Config::getValue( 'mail_smtphost', '127.0.0.1' );
 		$SMTPPORT = OC_Config::getValue( 'mail_smtpport', 25 );
 		$SMTPAUTH = OC_Config::getValue( 'mail_smtpauth', false );
+		$SMTPAUTHTYPE = OC_Config::getValue( 'mail_smtpauthtype', 'LOGIN' );
 		$SMTPUSERNAME = OC_Config::getValue( 'mail_smtpname', '' );
 		$SMTPPASSWORD = OC_Config::getValue( 'mail_smtppassword', '' );
+		$SMTPDEBUG    = OC_Config::getValue( 'mail_smtpdebug', false );
+		$SMTPTIMEOUT  = OC_Config::getValue( 'mail_smtptimeout', 10 );
+		$SMTPSECURE   = OC_Config::getValue( 'mail_smtpsecure', '' );
 
 
 		$mailo = new PHPMailer(true);
@@ -57,19 +62,23 @@ class OC_Mail {
 		$mailo->Host = $SMTPHOST;
 		$mailo->Port = $SMTPPORT;
 		$mailo->SMTPAuth = $SMTPAUTH;
+		$mailo->SMTPDebug = $SMTPDEBUG;
+		$mailo->SMTPSecure = $SMTPSECURE;
+		$mailo->AuthType = $SMTPAUTHTYPE;
 		$mailo->Username = $SMTPUSERNAME;
 		$mailo->Password = $SMTPPASSWORD;
+		$mailo->Timeout  = $SMTPTIMEOUT;
 
-		$mailo->From =$fromaddress;
+		$mailo->From = $fromaddress;
 		$mailo->FromName = $fromname;;
-		$mailo->Sender =$fromaddress;
-		$a=explode(' ',$toaddress);
+		$mailo->Sender = $fromaddress;
+		$a=explode(' ', $toaddress);
 		try {
 			foreach($a as $ad) {
-				$mailo->AddAddress($ad,$toname);
+				$mailo->AddAddress($ad, $toname);
 			}
 
-			if($ccaddress<>'') $mailo->AddCC($ccaddress,$ccname);
+			if($ccaddress<>'') $mailo->AddCC($ccaddress, $ccname);
 			if($bcc<>'') $mailo->AddBCC($bcc);
 
 			$mailo->AddReplyTo($fromaddress, $fromname);
@@ -89,7 +98,9 @@ class OC_Mail {
 
 			$mailo->Send();
 			unset($mailo);
-			OC_Log::write('mail', 'Mail from '.$fromname.' ('.$fromaddress.')'.' to: '.$toname.'('.$toaddress.')'.' subject: '.$subject, OC_Log::DEBUG);
+			OC_Log::write('mail',
+				'Mail from '.$fromname.' ('.$fromaddress.')'.' to: '.$toname.'('.$toaddress.')'.' subject: '.$subject,
+				OC_Log::DEBUG);
 		} catch (Exception $exception) {
 			OC_Log::write('mail', $exception->getMessage(), OC_Log::ERROR);
 			throw($exception);
@@ -102,10 +113,20 @@ class OC_Mail {
 	 */
 	public static function getfooter() {
 
+		$defaults = new OC_Defaults();
+
 		$txt="\n--\n";
-		$txt.="ownCloud\n";
-		$txt.="Your Cloud, Your Data, Your Way!\n";
+		$txt.=$defaults->getName() . "\n";
+		$txt.=$defaults->getSlogan() . "\n";
 		return($txt);
 
 	}
+
+	/**
+	 * @param string $emailAddress a given email address to be validated
+	 * @return bool
+	 */
+	public static function ValidateAddress($emailAddress) {
+		return PHPMailer::ValidateAddress($emailAddress);
+	}
 }
