@@ -5,15 +5,14 @@
  * See the COPYING-README file.
  */
 
-// Init owncloud
-require_once '../../lib/base.php';
-
 OC_JSON::checkSubAdminUser();
 OCP\JSON::callCheck();
 
 $username = isset($_POST["username"])?$_POST["username"]:'';
 
-if(($username == '' && !OC_Group::inGroup(OC_User::getUser(), 'admin')) || (!OC_Group::inGroup(OC_User::getUser(), 'admin') && !OC_SubAdmin::isUserAccessible(OC_User::getUser(), $username))) {
+if(($username == '' && !OC_User::isAdminUser(OC_User::getUser()))
+	|| (!OC_User::isAdminUser(OC_User::getUser())
+		&& !OC_SubAdmin::isUserAccessible(OC_User::getUser(), $username))) {
 	$l = OC_L10N::get('core');
 	OC_JSON::error(array( 'data' => array( 'message' => $l->t('Authentication error') )));
 	exit();
@@ -23,11 +22,7 @@ if(($username == '' && !OC_Group::inGroup(OC_User::getUser(), 'admin')) || (!OC_
 $quota=$_POST["quota"];
 if($quota!='none' and $quota!='default') {
 	$quota= OC_Helper::computerFileSize($quota);
-	if($quota==0) {
-		$quota='default';
-	}else{
-		$quota=OC_Helper::humanFileSize($quota);
-	}
+	$quota=OC_Helper::humanFileSize($quota);
 }
 
 // Return Success story
@@ -39,5 +34,5 @@ if($username) {
 	}
 	OC_Appconfig::setValue('files', 'default_quota', $quota);
 }
-OC_JSON::success(array("data" => array( "username" => $username ,'quota' => $quota)));
+OC_JSON::success(array("data" => array( "username" => $username , 'quota' => $quota)));
 
