@@ -18,12 +18,25 @@ OC.Settings.Apps = OC.Settings.Apps || {
 			page.find('span.version').text('');
 		}
 		page.find('span.score').html(app.score);
-		page.find('p.description').html(app.description);
+		page.find('p.description').text(app.description);
 		page.find('img.preview').attr('src', app.preview);
+		if (app.preview && app.preview.length) {
+			page.find('img.preview').show();
+		} else {
+			page.find('img.preview').hide();
+		}
 		page.find('small.externalapp').attr('style', 'visibility:visible');
 		page.find('span.author').text(app.author);
 		page.find('span.licence').text(app.licence);
 
+		if (app.update != false) {
+			page.find('input.update').show();
+			page.find('input.update').data('appid', app.id);
+			page.find('input.update').attr('value',t('settings', 'Update to {appversion}', {appversion:app.update}));
+		} else {
+			page.find('input.update').hide();
+		}
+
 		page.find('input.enable').show();
 		page.find('input.enable').val((app.active) ? t('settings', 'Disable') : t('settings', 'Enable'));
 		page.find('input.enable').data('appid', app.id);
@@ -44,6 +57,7 @@ OC.Settings.Apps = OC.Settings.Apps || {
 		appData = appitem.data('app');
 		appData.active = !active;
 		appitem.data('app', appData);
+		element.val(t('settings','Please wait....'));
 		if(active) {
 			$.post(OC.filePath('settings','ajax','disableapp.php'),{appid:appid},function(result) {
 				if(!result || result.status!='success') {
@@ -51,6 +65,7 @@ OC.Settings.Apps = OC.Settings.Apps || {
 				}
 				else {
 					element.data('active',false);
+					OC.Settings.Apps.removeNavigation(appid);
 					element.val(t('settings','Enable'));
 				}
 			},'json');
@@ -61,13 +76,34 @@ OC.Settings.Apps = OC.Settings.Apps || {
 					OC.dialogs.alert('Error while enabling app','Error');
 				}
 				else {
+					OC.Settings.Apps.addNavigation(appid);
 					element.data('active',true);
 					element.val(t('settings','Disable'));
 				}
-			},'json');
+			},'json')
+			.fail(function() { 
+				OC.dialogs.alert('Error while enabling app','Error');
+				element.data('active',false);
+				OC.Settings.Apps.removeNavigation(appid);
+				element.val(t('settings','Enable'));
+			});
 			$('#leftcontent li[data-id="'+appid+'"]').addClass('active');
 		}
 	},
+	updateApp:function(appid, element) {
+		console.log('updateApp:', appid, element);
+		element.val(t('settings','Updating....'));
+		$.post(OC.filePath('settings','ajax','updateapp.php'),{appid:appid},function(result) {
+			if(!result || result.status!='success') {
+				OC.dialogs.alert(t('settings','Error while updating app'),t('settings','Error'));
+			}
+			else {
+				element.val(t('settings','Updated'));
+				element.hide();
+			}
+		},'json');
+	},
+
 	insertApp:function(appdata) {
 		var applist = $('#leftcontent li');
 		var app =
@@ -87,6 +123,44 @@ OC.Settings.Apps = OC.Settings.Apps || {
 			applist.last().after(app);
 		}
 		return app;
+	},
+	removeNavigation: function(appid){
+		$.getJSON(OC.filePath('settings', 'ajax', 'navigationdetect.php'), {app: appid}).done(function(response){
+			if(response.status === 'success'){
+				var navIds=response.nav_ids;
+				for(var i=0; i< navIds.length; i++){
+					$('#apps').children('li[data-id="'+navIds[i]+'"]').remove();
+				}
+			}
+		});
+	},
+	addNavigation: function(appid){
+		$.getJSON(OC.filePath('settings', 'ajax', 'navigationdetect.php'), {app: appid}).done(function(response){
+			if(response.status === 'success'){
+				var navEntries=response.nav_entries;
+				for(var i=0; i< navEntries.length; i++){
+					var entry = navEntries[i];
+					var container = $('#apps');
+
+					if(container.children('li[data-id="'+entry.id+'"]').length === 0){
+						var li=$('<li></li>');
+						li.attr('data-id', entry.id);
+						var img= $('<img class="icon"/>').attr({ src: entry.icon});
+						var a=$('<a></a>').attr('href', entry.href);
+						var filename=$('<span></span>');
+						filename.text(entry.name);
+						a.prepend(filename);
+						a.prepend(img);
+						li.append(a);
+						container.append(li);
+						if (!SVGSupport() && entry.icon.match(/\.svg$/i)) {
+							$(img).addClass('svg');
+							replaceSVG();
+						}
+					}
+				}
+			}
+		});
 	}
 };
 
@@ -120,6 +194,13 @@ $(document).ready(function(){
 			OC.Settings.Apps.enableApp(appid, active, element);
 		}
 	});
+	$('#rightcontent input.update').click(function(){
+		var element = $(this);
+		var appid=$(this).data('appid');
+		if(appid) {
+			OC.Settings.Apps.updateApp(appid, element);
+		}
+	});
 
 	if(appid) {
 		var item = $('#leftcontent li[data-id="'+appid+'"]');
