@@ -32,6 +32,36 @@ $(document).ready(function(){
 
 	});
 
+	$("#displaynamebutton").click( function(){
+		if ($('#displayName').val() != '' ) {
+			// Serialize the data
+			var post = $( "#displaynameform" ).serialize();
+			$('#displaynamechanged').hide();
+			$('#displaynemerror').hide();
+			// Ajax foo
+			$.post( 'ajax/changedisplayname.php', post, function(data){
+				if( data.status == "success" ){
+					$('#displaynamechanged').show();
+					$('#oldDisplayName').text($('#displayName').val());
+					// update displayName on the top right expand button
+					$('#expandDisplayName').text($('#displayName').val());
+				}
+				else{
+					$('#newdisplayname').val(data.data.displayName)
+					$('#displaynameerror').html( data.data.message );
+					$('#displaynameerror').show();
+				}
+			});
+			return false;
+		} else {
+			$('#displayName').val($('#oldDisplayName').val());
+			$('#displaynamechanged').hide();
+			$('#displaynameerror').show();
+			return false;
+		}
+
+	});
+
 	$('#lostpassword #email').blur(function(event){
 		if ($(this).val() == this.defaultValue){
 			return;
