@@ -1,48 +1,52 @@
 <?php $TRANSLATIONS = array(
 "Unable to load list from App Store" => "Lasting av liste fra App Store feilet.",
 "Authentication error" => "Autentikasjonsfeil",
+"Group already exists" => "Gruppen finnes allerede",
+"Unable to add group" => "Kan ikke legge til gruppe",
+"Could not enable app. " => "Kan ikke aktivere app.",
 "Email saved" => "Epost lagret",
 "Invalid email" => "Ugyldig epost",
-"OpenID Changed" => "OpenID endret",
-"Invalid request" => "Ugyldig forespørsel",
+"Unable to delete group" => "Kan ikke slette gruppe",
+"Unable to delete user" => "Kan ikke slette bruker",
 "Language changed" => "Språk endret",
+"Invalid request" => "Ugyldig forespørsel",
+"Unable to add user to group %s" => "Kan ikke legge bruker til gruppen %s",
+"Unable to remove user from group %s" => "Kan ikke slette bruker fra gruppen %s",
 "Disable" => "Slå avBehandle ",
 "Enable" => "Slå på",
+"Error" => "Feil",
 "Saving..." => "Lagrer...",
+"deleted" => "slettet",
+"undo" => "angre",
+"Groups" => "Grupper",
+"Group Admin" => "Gruppeadministrator",
+"Delete" => "Slett",
 "__language_name__" => "__language_name__",
 "Security Warning" => "Sikkerhetsadvarsel",
-"Cron" => "Cron",
-"Log" => "Logg",
 "More" => "Mer",
+"Version" => "Versjon",
 "Add your App" => "Legg til din App",
+"More Apps" => "Flere Apps",
 "Select an App" => "Velg en app",
 "See application page at apps.owncloud.com" => "Se applikasjonens side på apps.owncloud.org",
-"Documentation" => "Dokumentasjon",
-"Managing Big Files" => "Håndtere store filer",
-"Ask a question" => "Still et spørsmål",
-"Problems connecting to help database." => "Problemer med å koble til hjelp-databasen",
-"Go there manually." => "Gå dit manuelt",
-"Answer" => "Svar",
-"Desktop and Mobile Syncing Clients" => "Klienter for datamaskiner og mobile enheter",
-"Download" => "Last ned",
+"Update" => "Oppdater",
+"User Documentation" => "Brukerdokumentasjon",
+"Administrator Documentation" => "Administratordokumentasjon",
+"Commercial Support" => "Kommersiell støtte",
+"You have used <strong>%s</strong> of the available <strong>%s</strong>" => "Du har brukt <strong>%s</strong> av tilgjengelig <strong>%s</strong>",
+"Get the apps to sync your files" => "Få dine apps til å synkronisere dine filer",
+"Password" => "Passord",
+"Your password was changed" => "Passord har blitt endret",
 "Unable to change your password" => "Kunne ikke endre passordet ditt",
 "Current password" => "Nåværende passord",
 "New password" => "Nytt passord",
-"show" => "vis",
 "Change password" => "Endre passord",
 "Email" => "E-post",
 "Your email address" => "Din e-postadresse",
 "Fill in an email address to enable password recovery" => "Oppi epostadressen du vil tilbakestille passordet for",
 "Language" => "Språk",
 "Help translate" => "Bidra til oversettelsen",
-"use this address to connect to your ownCloud in your file manager" => "bruk denne adressen for å koble til din ownCloud gjennom filhåndtereren",
-"Name" => "Navn",
-"Password" => "Passord",
-"Groups" => "Grupper",
+"WebDAV" => "WebDAV",
 "Create" => "Opprett",
-"Default Quota" => "Standard Kvote",
-"Other" => "Annet",
-"Group Admin" => "Gruppeadministrator",
-"Quota" => "Kvote",
-"Delete" => "Slett"
+"Other" => "Annet"
 );
