@@ -6,67 +6,69 @@
 "Could not enable app. " => "ไม่สามารถเปิดใช้งานแอปได้",
 "Email saved" => "อีเมลถูกบันทึกแล้ว",
 "Invalid email" => "อีเมลไม่ถูกต้อง",
-"OpenID Changed" => "เปลี่ยนชื่อบัญชี OpenID แล้ว",
-"Invalid request" => "คำร้องขอไม่ถูกต้อง",
 "Unable to delete group" => "ไม่สามารถลบกลุ่มได้",
 "Unable to delete user" => "ไม่สามารถลบผู้ใช้งานได้",
 "Language changed" => "เปลี่ยนภาษาเรียบร้อยแล้ว",
+"Invalid request" => "คำร้องขอไม่ถูกต้อง",
+"Admins can't remove themself from the admin group" => "ผู้ดูแลระบบไม่สามารถลบตัวเองออกจากกลุ่มผู้ดูแลได้",
 "Unable to add user to group %s" => "ไม่สามารถเพิ่มผู้ใช้งานเข้าไปที่กลุ่ม %s ได้",
 "Unable to remove user from group %s" => "ไม่สามารถลบผู้ใช้งานออกจากกลุ่ม %s ได้",
+"Couldn't update app." => "ไม่สามารถอัพเดทแอปฯ",
+"Update to {appversion}" => "อัพเดทไปเป็นรุ่น {appversion}",
 "Disable" => "ปิดใช้งาน",
 "Enable" => "เปิดใช้งาน",
+"Please wait...." => "กรุณารอสักครู่...",
+"Updating...." => "กำลังอัพเดทข้อมูล...",
+"Error while updating app" => "เกิดข้อผิดพลาดในระหว่างการอัพเดทแอปฯ",
+"Error" => "ข้อผิดพลาด",
+"Updated" => "อัพเดทแล้ว",
 "Saving..." => "กำลังบันทึุกข้อมูล...",
+"deleted" => "ลบแล้ว",
+"undo" => "เลิกทำ",
+"Groups" => "กลุ่ม",
+"Group Admin" => "ผู้ดูแลกลุ่ม",
+"Delete" => "ลบ",
 "__language_name__" => "ภาษาไทย",
 "Security Warning" => "คำเตือนเกี่ยวกับความปลอดภัย",
 "Your data directory and your files are probably accessible from the internet. The .htaccess file that ownCloud provides is not working. We strongly suggest that you configure your webserver in a way that the data directory is no longer accessible or you move the data directory outside the webserver document root." => "ไดเร็กทอรี่ข้อมูลและไฟล์ของคุณสามารถเข้าถึงได้จากอินเทอร์เน็ต ไฟล์ .htaccess ที่ ownCloud มีให้ไม่สามารถทำงานได้อย่างเหมาะสม เราขอแนะนำให้คุณกำหนดค่าเว็บเซิร์ฟเวอร์ใหม่ในรูปแบบที่ไดเร็กทอรี่เก็บข้อมูลไม่สามารถเข้าถึงได้อีกต่อไป หรือคุณได้ย้ายไดเร็กทอรี่ที่ใช้เก็บข้อมูลไปอยู่ภายนอกตำแหน่ง root ของเว็บเซิร์ฟเวอร์แล้ว",
-"Cron" => "Cron",
-"Execute one task with each page loaded" => "ประมวลคำสั่งหนึ่งงานในแต่ละครั้งที่มีการโหลดหน้าเว็บ",
-"cron.php is registered at a webcron service. Call the cron.php page in the owncloud root once a minute over http." => "cron.php ได้รับการลงทะเบียนแล้วกับเว็บผู้ให้บริการ webcron เรียกหน้าเว็บ cron.php ที่ตำแหน่ง root ของ owncloud หลังจากนี้สักครู่ผ่านทาง http",
-"Use systems cron service. Call the cron.php file in the owncloud folder via a system cronjob once a minute." => "ใช้บริการ cron จากระบบ เรียกไฟล์ cron.php ในโฟลเดอร์ owncloud ผ่านทาง cronjob ของระบบหลังจากนี้สักครู่",
-"Sharing" => "การแชร์ข้อมูล",
-"Enable Share API" => "เปิดใช้งาน API สำหรับคุณสมบัติแชร์ข้อมูล",
-"Allow apps to use the Share API" => "อนุญาตให้แอปฯสามารถใช้ API สำหรับแชร์ข้อมูลได้",
-"Allow links" => "อนุญาตให้ใช้งานลิงก์ได้",
-"Allow users to share items to the public with links" => "อนุญาตให้ผู้ใช้งานสามารถแชร์ข้อมูลรายการต่างๆไปให้สาธารณะชนเป็นลิงก์ได้",
-"Allow resharing" => "อนุญาตให้แชร์ข้อมูลซ้ำใหม่ได้",
-"Allow users to share items shared with them again" => "อนุญาตให้ผู้ใช้งานแชร์ข้อมูลรายการต่างๆที่ถูกแชร์มาให้ตัวผู้ใช้งานได้เท่านั้น",
-"Allow users to share with anyone" => "อนุญาตให้ผู้ใช้งานแชร์ข้อมูลถึงใครก็ได้",
-"Allow users to only share with users in their groups" => "อนุญาตให้ผู้ใช้งานแชร์ข้อมูลได้เฉพาะกับผู้ใช้งานที่อยู่ในกลุ่มเดียวกันเท่านั้น",
-"Log" => "บันทึกการเปลี่ยนแปลง",
-"More" => "เพิ่มเติม",
+"More" => "มาก",
+"Version" => "รุ่น",
 "Developed by the <a href=\"http://ownCloud.org/contact\" target=\"_blank\">ownCloud community</a>, the <a href=\"https://github.com/owncloud\" target=\"_blank\">source code</a> is licensed under the <a href=\"http://www.gnu.org/licenses/agpl-3.0.html\" target=\"_blank\"><abbr title=\"Affero General Public License\">AGPL</abbr></a>." => "พัฒนาโดย the <a href=\"http://ownCloud.org/contact\" target=\"_blank\">ชุมชนผู้ใช้งาน ownCloud</a>, the <a href=\"https://github.com/owncloud\" target=\"_blank\">ซอร์สโค้ด</a>อยู่ภายใต้สัญญาอนุญาตของ <a href=\"http://www.gnu.org/licenses/agpl-3.0.html\" target=\"_blank\"><abbr title=\"Affero General Public License\">AGPL</abbr></a>.",
 "Add your App" => "เพิ่มแอปของคุณ",
+"More Apps" => "แอปฯอื่นเพิ่มเติม",
 "Select an App" => "เลือก App",
 "See application page at apps.owncloud.com" => "ดูหน้าแอพพลิเคชั่นที่ apps.owncloud.com",
 "<span class=\"licence\"></span>-licensed by <span class=\"author\"></span>" => "<span class=\"licence\"></span>-ลิขสิทธิ์การใช้งานโดย <span class=\"author\"></span>",
-"Documentation" => "เอกสารคู่มือการใช้งาน",
-"Managing Big Files" => "การจัดการไฟล์ขนาดใหญ่",
-"Ask a question" => "สอบถามข้อมูล",
-"Problems connecting to help database." => "เกิดปัญหาในการเชื่อมต่อกับฐานข้อมูลช่วยเหลือ",
-"Go there manually." => "ไปที่นั่นด้วยตนเอง",
-"Answer" => "คำตอบ",
-"You have used <strong>%s</strong> of the available <strong>%s<strong>" => "คุณได้ใช้ <strong>%s</strong> จากที่สามารถใช้ได้ <strong>%s<strong>",
-"Desktop and Mobile Syncing Clients" => "โปรแกรมเชื่อมข้อมูลไฟล์สำหรับเครื่องเดสก์ท็อปและมือถือ",
-"Download" => "ดาวน์โหลด",
+"Update" => "อัพเดท",
+"User Documentation" => "เอกสารคู่มือการใช้งานสำหรับผู้ใช้งาน",
+"Administrator Documentation" => "เอกสารคู่มือการใช้งานสำหรับผู้ดูแลระบบ",
+"Online Documentation" => "เอกสารคู่มือการใช้งานออนไลน์",
+"Forum" => "กระดานสนทนา",
+"Bugtracker" => "Bugtracker",
+"Commercial Support" => "บริการลูกค้าแบบเสียค่าใช้จ่าย",
+"You have used <strong>%s</strong> of the available <strong>%s</strong>" => "คุณได้ใช้งานไปแล้ว <strong>%s</strong> จากจำนวนที่สามารถใช้ได้ <strong>%s</strong>",
+"Show First Run Wizard again" => "แสดงหน้าจอวิซาร์ดนำทางครั้งแรกอีกครั้ง",
+"Password" => "รหัสผ่าน",
 "Your password was changed" => "รหัสผ่านของคุณถูกเปลี่ยนแล้ว",
 "Unable to change your password" => "ไม่สามารถเปลี่ยนรหัสผ่านของคุณได้",
 "Current password" => "รหัสผ่านปัจจุบัน",
 "New password" => "รหัสผ่านใหม่",
-"show" => "แสดง",
 "Change password" => "เปลี่ยนรหัสผ่าน",
+"Display Name" => "ชื่อที่ต้องการแสดง",
 "Email" => "อีเมล์",
 "Your email address" => "ที่อยู่อีเมล์ของคุณ",
 "Fill in an email address to enable password recovery" => "กรอกที่อยู่อีเมล์ของคุณเพื่อเปิดให้มีการกู้คืนรหัสผ่านได้",
 "Language" => "ภาษา",
 "Help translate" => "ช่วยกันแปล",
-"use this address to connect to your ownCloud in your file manager" => "ใช้ที่อยู่นี้ในการเชื่อมต่อกับบัญชี ownCloud ของคุณในเครื่องมือจัดการไฟล์ของคุณ",
-"Name" => "ชื่อ",
-"Password" => "รหัสผ่าน",
-"Groups" => "กลุ่ม",
+"WebDAV" => "WebDAV",
+"Use this address to connect to your ownCloud in your file manager" => "ใช้ที่อยู่นี้เพื่อเชื่อมต่อกับ ownCloud ในโปรแกรมจัดการไฟล์ของคุณ",
+"Login Name" => "ชื่อที่ใช้สำหรับเข้าสู่ระบบ",
 "Create" => "สร้าง",
-"Default Quota" => "โควต้าที่กำหนดไว้เริ่มต้น",
+"Default Storage" => "พื้นที่จำกัดข้อมูลเริ่มต้น",
+"Unlimited" => "ไม่จำกัดจำนวน",
 "Other" => "อื่นๆ",
-"Group Admin" => "ผู้ดูแลกลุ่ม",
-"Quota" => "พื้นที่",
-"Delete" => "ลบ"
+"Storage" => "พื้นที่จัดเก็บข้อมูล",
+"change display name" => "เปลี่ยนชื่อที่ต้องการให้แสดง",
+"set new password" => "ตั้งค่ารหัสผ่านใหม่",
+"Default" => "ค่าเริ่มต้น"
 );
