@@ -6,67 +6,59 @@
 "Could not enable app. " => "无法开启App",
 "Email saved" => "电子邮件已保存",
 "Invalid email" => "无效的电子邮件",
-"OpenID Changed" => "OpenID 已修改",
-"Invalid request" => "非法请求",
 "Unable to delete group" => "无法删除组",
 "Unable to delete user" => "无法删除用户",
 "Language changed" => "语言已修改",
+"Invalid request" => "非法请求",
+"Admins can't remove themself from the admin group" => "管理员不能将自己移出管理组。",
 "Unable to add user to group %s" => "无法把用户添加到组 %s",
 "Unable to remove user from group %s" => "无法从组%s中移除用户",
 "Disable" => "禁用",
 "Enable" => "启用",
+"Error" => "错误",
 "Saving..." => "正在保存",
+"deleted" => "已经删除",
+"undo" => "撤销",
+"Groups" => "组",
+"Group Admin" => "组管理员",
+"Delete" => "删除",
 "__language_name__" => "简体中文",
 "Security Warning" => "安全警告",
 "Your data directory and your files are probably accessible from the internet. The .htaccess file that ownCloud provides is not working. We strongly suggest that you configure your webserver in a way that the data directory is no longer accessible or you move the data directory outside the webserver document root." => "您的数据文件夹和文件可由互联网访问。OwnCloud提供的.htaccess文件未生效。我们强烈建议您配置服务器，以使数据文件夹不可被访问，或者将数据文件夹移到web服务器根目录以外。",
-"Cron" => "计划任务",
-"Execute one task with each page loaded" => "每次页面加载完成后执行任务",
-"cron.php is registered at a webcron service. Call the cron.php page in the owncloud root once a minute over http." => "cron.php已被注册到网络定时任务服务。通过http每分钟调用owncloud根目录的cron.php网页。",
-"Use systems cron service. Call the cron.php file in the owncloud folder via a system cronjob once a minute." => "使用系统定时任务服务。每分钟通过系统定时任务调用owncloud文件夹中的cron.php文件",
-"Sharing" => "分享",
-"Enable Share API" => "开启共享API",
-"Allow apps to use the Share API" => "允许 应用 使用共享API",
-"Allow links" => "允许连接",
-"Allow users to share items to the public with links" => "允许用户使用连接向公众共享",
-"Allow resharing" => "允许再次共享",
-"Allow users to share items shared with them again" => "允许用户将共享给他们的项目再次共享",
-"Allow users to share with anyone" => "允许用户向任何人共享",
-"Allow users to only share with users in their groups" => "允许用户只向同组用户共享",
-"Log" => "日志",
 "More" => "更多",
+"Version" => "版本",
 "Developed by the <a href=\"http://ownCloud.org/contact\" target=\"_blank\">ownCloud community</a>, the <a href=\"https://github.com/owncloud\" target=\"_blank\">source code</a> is licensed under the <a href=\"http://www.gnu.org/licenses/agpl-3.0.html\" target=\"_blank\"><abbr title=\"Affero General Public License\">AGPL</abbr></a>." => "由<a href=\"http://ownCloud.org/contact\" target=\"_blank\">ownCloud社区</a>开发，  <a href=\"https://github.com/owncloud\" target=\"_blank\">源代码</a>在<a href=\"http://www.gnu.org/licenses/agpl-3.0.html\" target=\"_blank\"><abbr title=\"Affero General Public License\">AGPL</abbr></a>许可证下发布。",
 "Add your App" => "添加应用",
+"More Apps" => "更多应用",
 "Select an App" => "选择一个应用",
 "See application page at apps.owncloud.com" => "查看在 app.owncloud.com 的应用程序页面",
 "<span class=\"licence\"></span>-licensed by <span class=\"author\"></span>" => "<span class=\"licence\"></span>-核准： <span class=\"author\"></span>",
-"Documentation" => "文档",
-"Managing Big Files" => "管理大文件",
-"Ask a question" => "提问",
-"Problems connecting to help database." => "连接帮助数据库错误 ",
-"Go there manually." => "手动访问",
-"Answer" => "回答",
-"You have used <strong>%s</strong> of the available <strong>%s<strong>" => "您已使用空间: <strong>%s</strong>，总空间: <strong>%s</strong>",
-"Desktop and Mobile Syncing Clients" => "桌面和移动设备同步程序",
-"Download" => "下载",
+"Update" => "更新",
+"User Documentation" => "用户文档",
+"Administrator Documentation" => "管理员文档",
+"Online Documentation" => "在线文档",
+"Forum" => "论坛",
+"Bugtracker" => "问题跟踪器",
+"Commercial Support" => "商业支持",
+"You have used <strong>%s</strong> of the available <strong>%s</strong>" => "你已使用 <strong>%s</strong>，有效空间 <strong>%s</strong>",
+"Get the apps to sync your files" => "安装应用进行文件同步",
+"Password" => "密码",
 "Your password was changed" => "密码已修改",
 "Unable to change your password" => "无法修改密码",
 "Current password" => "当前密码",
 "New password" => "新密码",
-"show" => "显示",
 "Change password" => "修改密码",
 "Email" => "电子邮件",
 "Your email address" => "您的电子邮件",
-"Fill in an email address to enable password recovery" => "填写电子邮件地址以启用密码恢复",
+"Fill in an email address to enable password recovery" => "填写电子邮件地址以启用密码恢复功能",
 "Language" => "语言",
 "Help translate" => "帮助翻译",
-"use this address to connect to your ownCloud in your file manager" => "您可在文件管理器中使用该地址连接到ownCloud",
-"Name" => "名称",
-"Password" => "密码",
-"Groups" => "组",
+"WebDAV" => "WebDAV",
+"Use this address to connect to your ownCloud in your file manager" => "用该地址来连接文件管理器中的 ownCloud",
 "Create" => "创建",
-"Default Quota" => "默认配额",
+"Default Storage" => "默认存储",
+"Unlimited" => "无限",
 "Other" => "其它",
-"Group Admin" => "组管理",
-"Quota" => "配额",
-"Delete" => "删除"
+"Storage" => "存储",
+"Default" => "默认"
 );
